@@ -4,6 +4,8 @@
 # toolkit was authored by (Someone claim this)[unknown]
 # moretools was authored by David Sesno(walker@shell.pcrealm.net)
 #
+# Copyright (C) 2002, 2003 Eggheads Development Team
+#
 # TG        ?????????: modified for 1.3.0 bots
 # Tothwolf  02May1999: rewritten and updated
 # guppy     02May1999: updated even more
@@ -17,8 +19,10 @@
 # Sup       02Apr2001: added matchbotattr
 # Tothwolf  13Jun2001: updated/modified several commands
 # Hanno     28Sep2001: fixed testip
+# guppy     03Mar2002: optimized
+# Souperman 05Nov2002: added ordnumber
 #
-# $Id: alltools.tcl,v 1.12 2001/11/28 23:51:16 guppy Exp $
+# $Id: alltools.tcl,v 1.15 2002/12/24 02:30:04 wcc Exp $
 #
 ########################################
 # Descriptions of available commands:
@@ -119,11 +123,17 @@
 #   if the given bot has all the given flags, return 1
 #   else return 0
 #
+# ordnumber <string>
+#   if the given string is a number, returns the
+#   "ordinal" version of that number, i.e. 1 -> "1st",
+#   2 -> "2nd", etc.
+#   else return <string>
+#
 ########################################
 
 # So scripts can see if allt is loaded.
 set alltools_loaded 1
-set allt_version 204
+set allt_version 205
 
 # For backward compatibility.
 set toolbox_revision 1007
@@ -155,28 +165,27 @@ proc putact {dest text} {
 #
 
 proc strlwr {string} {
-  return [string tolower $string]
+  string tolower $string
 }
 
 proc strupr {string} {
-  return [string toupper $string]
+  string toupper $string
 }
 
 proc strcmp {string1 string2} {
-  return [string compare $string1 $string2]
+  string compare $string1 $string2
 }
 
 proc stricmp {string1 string2} {
-  return [string compare [string tolower $string1] \
-          [string tolower $string2]]
+  string compare [string tolower $string1] [string tolower $string2]
 }
 
 proc strlen {string} {
-  return [string length $string]
+  string length $string
 }
 
 proc stridx {string index} {
-  return [string index $string $index]
+  string index $string $index
 }
 
 proc iscommand {command} {
@@ -205,7 +214,7 @@ proc utimerexists {command} {
 }
 
 proc inchain {bot} {
-  return [islinked $bot]
+  islinked $bot
 }
 
 proc randstring {length {chars abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789}} {
@@ -251,7 +260,7 @@ proc killdccbut {idx} {
 #
 
 proc iso {nick chan} {
-  return [matchattr [nick2hand $nick $chan] o|o $chan]
+  matchattr [nick2hand $nick $chan] o|o $chan
 }
 
 proc realtime {args} {
@@ -372,3 +381,21 @@ proc matchbotattr {bot flags} {
   }
   return 1
 }
+
+proc ordnumber {str} {
+  if {[isnumber $str]} {
+    set last1 [string range $str [expr [strlen $str]-1] end]
+    set last2 [string range $str [expr [strlen $str]-2] end]
+    if {$last1=="1"&&$last2!="11"} {
+      return "[expr $str]st"
+    } elseif {$last1=="2"&&$last2!="12"} {
+      return "[expr $str]nd"
+    } elseif {$last1=="3"&&$last2!="13"} {
+      return "[expr $str]rd"
+    } else {
+      return "[expr $str]th"
+    }
+  } else {
+    return "$str"
+  }
+}
