@@ -1,10 +1,10 @@
 /*
  * snprintf.c - a portable implementation of snprintf and vsnprintf
  *
- * $Id: snprintf.c,v 1.5 2002/01/02 03:46:36 guppy Exp $
+ * $Id: snprintf.c,v 1.17 2003/03/05 04:32:25 wcc Exp $
  */
 /*
- * Portions Copyright (C) 2000, 2001, 2002 Eggheads Development Team
+ * Portions Copyright (C) 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -98,37 +98,34 @@
 #      include <std_args.h>
 #    endif
 #  endif
-#  include <stdarg.h>
-#  define HAVE_STDARGS		/* let's hope that works everywhere (mj) */
-#  define VA_LOCAL_DECL	va_list ap
-#  define VA_START(f)	va_start(ap, f)
-#  define VA_SHIFT(v,t)	;	/* no-op for ANSI */
-#  define VA_END	va_end(ap)
+#  define HAVE_STDARGS          /* let's hope that works everywhere (mj) */
+#  define VA_LOCAL_DECL va_list ap
+#  define VA_START(f)   va_start(ap, f)
+#  define VA_SHIFT(v,t) ;       /* no-op for ANSI */
+#  define VA_END        va_end(ap)
 #else
 #  include <varargs.h>
 #  undef HAVE_STDARGS
-#  define VA_LOCAL_DECL	va_list ap
-#  define VA_START(f)	va_start(ap)	/* f is ignored! */
-#  define VA_SHIFT(v,t)	v = va_arg(ap,t)
-#  define VA_END	va_end(ap)
+#  define VA_LOCAL_DECL va_list ap
+#  define VA_START(f)   va_start(ap)    /* f is ignored! */
+#  define VA_SHIFT(v,t) v = va_arg(ap,t)
+#  define VA_END        va_end(ap)
 #endif
 
 #ifdef HAVE_LONG_DOUBLE
-#define LDOUBLE	long double
+#define LDOUBLE long double
 #else
-#define LDOUBLE	double
+#define LDOUBLE double
 #endif
 
-static void dopr(char *buffer, size_t maxlen, const char *format,
-		 va_list args);
-static void fmtstr(char *buffer, size_t * currlen, size_t maxlen,
-		   char *value, int flags, int min, int max);
-static void fmtint(char *buffer, size_t * currlen, size_t maxlen,
-		   long value, int base, int min, int max, int flags);
-static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
-		  LDOUBLE fvalue, int min, int max, int flags);
-static void dopr_outch(char *buffer, size_t * currlen, size_t maxlen,
-		       char c);
+static void dopr(char *buffer, size_t maxlen, const char *format, va_list args);
+static void fmtstr(char *buffer, size_t *currlen, size_t maxlen, char *value,
+                   int flags, int min, int max);
+static void fmtint(char *buffer, size_t *currlen, size_t maxlen, long value,
+                   int base, int min, int max, int flags);
+static void fmtfp(char *buffer, size_t *currlen, size_t maxlen, LDOUBLE fvalue,
+                  int min, int max, int flags);
+static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c);
 
 /*
  * dopr(): poor man's version of doprintf
@@ -145,13 +142,13 @@ static void dopr_outch(char *buffer, size_t * currlen, size_t maxlen,
 #define DP_S_DONE    7
 
 /* format flags - Bits */
-#define DP_F_MINUS 	(1 << 0)
-#define DP_F_PLUS  	(1 << 1)
-#define DP_F_SPACE 	(1 << 2)
-#define DP_F_NUM   	(1 << 3)
-#define DP_F_ZERO  	(1 << 4)
-#define DP_F_UP    	(1 << 5)
-#define DP_F_UNSIGNED 	(1 << 6)
+#define DP_F_MINUS      (1 << 0)
+#define DP_F_PLUS       (1 << 1)
+#define DP_F_SPACE      (1 << 2)
+#define DP_F_NUM        (1 << 3)
+#define DP_F_ZERO       (1 << 4)
+#define DP_F_UP         (1 << 5)
+#define DP_F_UNSIGNED   (1 << 6)
 
 /* Conversion Flags */
 #define DP_C_SHORT   1
@@ -161,8 +158,7 @@ static void dopr_outch(char *buffer, size_t * currlen, size_t maxlen,
 #define char_to_int(p) (p - '0')
 #define MAX(p,q) ((p >= q) ? p : q)
 
-static void dopr(char *buffer, size_t maxlen, const char *format,
-		 va_list args)
+static void dopr(char *buffer, size_t maxlen, const char *format, va_list args)
 {
   char ch;
   long value;
@@ -187,86 +183,88 @@ static void dopr(char *buffer, size_t maxlen, const char *format,
     switch (state) {
     case DP_S_DEFAULT:
       if (ch == '%')
-	state = DP_S_FLAGS;
+        state = DP_S_FLAGS;
       else
-	dopr_outch(buffer, &currlen, maxlen, ch);
+        dopr_outch(buffer, &currlen, maxlen, ch);
       ch = *format++;
       break;
     case DP_S_FLAGS:
       switch (ch) {
       case '-':
-	flags |= DP_F_MINUS;
-	ch = *format++;
-	break;
+        flags |= DP_F_MINUS;
+        ch = *format++;
+        break;
       case '+':
-	flags |= DP_F_PLUS;
-	ch = *format++;
-	break;
+        flags |= DP_F_PLUS;
+        ch = *format++;
+        break;
       case ' ':
-	flags |= DP_F_SPACE;
-	ch = *format++;
-	break;
+        flags |= DP_F_SPACE;
+        ch = *format++;
+        break;
       case '#':
-	flags |= DP_F_NUM;
-	ch = *format++;
-	break;
+        flags |= DP_F_NUM;
+        ch = *format++;
+        break;
       case '0':
-	flags |= DP_F_ZERO;
-	ch = *format++;
-	break;
+        flags |= DP_F_ZERO;
+        ch = *format++;
+        break;
       default:
-	state = DP_S_MIN;
-	break;
+        state = DP_S_MIN;
+        break;
       }
       break;
     case DP_S_MIN:
       if (isdigit(ch)) {
-	min = 10 * min + char_to_int(ch);
-	ch = *format++;
+        min = 10 * min + char_to_int(ch);
+        ch = *format++;
       } else if (ch == '*') {
-	min = va_arg(args, int);
-	ch = *format++;
-	state = DP_S_DOT;
+        min = va_arg(args, int);
+
+        ch = *format++;
+        state = DP_S_DOT;
       } else
-	state = DP_S_DOT;
+        state = DP_S_DOT;
       break;
     case DP_S_DOT:
       if (ch == '.') {
-	state = DP_S_MAX;
-	ch = *format++;
+        state = DP_S_MAX;
+        ch = *format++;
       } else
-	state = DP_S_MOD;
+        state = DP_S_MOD;
       break;
     case DP_S_MAX:
       if (isdigit(ch)) {
-	if (max < 0)
-	  max = 0;
-	max = 10 * max + char_to_int(ch);
-	ch = *format++;
+        if (max < 0)
+          max = 0;
+        max = 10 * max + char_to_int(ch);
+        ch = *format++;
       } else if (ch == '*') {
-	max = va_arg(args, int);
-	ch = *format++;
-	state = DP_S_MOD;
+        max = va_arg(args, int);
+
+        ch = *format++;
+        state = DP_S_MOD;
       } else
-	state = DP_S_MOD;
+        state = DP_S_MOD;
       break;
     case DP_S_MOD:
       /* Currently, we don't support Long Long, bummer */
       switch (ch) {
       case 'h':
-	cflags = DP_C_SHORT;
-	ch = *format++;
-	break;
+        cflags = DP_C_SHORT;
+        ch = *format++;
+        break;
       case 'l':
-	cflags = DP_C_LONG;
-	ch = *format++;
-	break;
+        cflags = DP_C_LONG;
+        ch = *format++;
+        break;
       case 'L':
-	cflags = DP_C_LDOUBLE;
-	ch = *format++;
-	break;
+        cflags = DP_C_LDOUBLE;
+        ch = *format++;
+        break;
       default:
-	break;
+        break;
       }
       state = DP_S_CONV;
       break;
@@ -274,109 +272,129 @@ static void dopr(char *buffer, size_t maxlen, const char *format,
       switch (ch) {
       case 'd':
       case 'i':
-	if (cflags == DP_C_SHORT)
-	  value = va_arg(args, short int);
-	else if (cflags == DP_C_LONG)
-	  value = va_arg(args, long int);
-	else
-	  value = va_arg(args, int);
-	fmtint(buffer, &currlen, maxlen, value, 10, min, max, flags);
-	break;
+        if (cflags == DP_C_SHORT)
+          value = va_arg(args, short int);
+
+        else if (cflags == DP_C_LONG)
+          value = va_arg(args, long int);
+
+        else
+          value = va_arg(args, int);
+
+        fmtint(buffer, &currlen, maxlen, value, 10, min, max, flags);
+        break;
       case 'o':
-	flags |= DP_F_UNSIGNED;
-	if (cflags == DP_C_SHORT)
-	  value = va_arg(args, unsigned short int);
-	else if (cflags == DP_C_LONG)
-	  value = va_arg(args, unsigned long int);
-	else
-	  value = va_arg(args, unsigned int);
-	fmtint(buffer, &currlen, maxlen, value, 8, min, max, flags);
-	break;
+        flags |= DP_F_UNSIGNED;
+        if (cflags == DP_C_SHORT)
+          value = va_arg(args, unsigned short int);
+
+        else if (cflags == DP_C_LONG)
+          value = va_arg(args, unsigned long int);
+
+        else
+          value = va_arg(args, unsigned int);
+
+        fmtint(buffer, &currlen, maxlen, value, 8, min, max, flags);
+        break;
       case 'u':
-	flags |= DP_F_UNSIGNED;
-	if (cflags == DP_C_SHORT)
-	  value = va_arg(args, unsigned short int);
-	else if (cflags == DP_C_LONG)
-	  value = va_arg(args, unsigned long int);
-	else
-	  value = va_arg(args, unsigned int);
-	fmtint(buffer, &currlen, maxlen, value, 10, min, max, flags);
-	break;
+        flags |= DP_F_UNSIGNED;
+        if (cflags == DP_C_SHORT)
+          value = va_arg(args, unsigned short int);
+
+        else if (cflags == DP_C_LONG)
+          value = va_arg(args, unsigned long int);
+
+        else
+          value = va_arg(args, unsigned int);
+
+        fmtint(buffer, &currlen, maxlen, value, 10, min, max, flags);
+        break;
       case 'X':
-	flags |= DP_F_UP;
+        flags |= DP_F_UP;
       case 'x':
-	flags |= DP_F_UNSIGNED;
-	if (cflags == DP_C_SHORT)
-	  value = va_arg(args, unsigned short int);
-	else if (cflags == DP_C_LONG)
-	  value = va_arg(args, unsigned long int);
-	else
-	  value = va_arg(args, unsigned int);
-	fmtint(buffer, &currlen, maxlen, value, 16, min, max, flags);
-	break;
+        flags |= DP_F_UNSIGNED;
+        if (cflags == DP_C_SHORT)
+          value = va_arg(args, unsigned short int);
+
+        else if (cflags == DP_C_LONG)
+          value = va_arg(args, unsigned long int);
+
+        else
+          value = va_arg(args, unsigned int);
+
+        fmtint(buffer, &currlen, maxlen, value, 16, min, max, flags);
+        break;
       case 'f':
-	if (cflags == DP_C_LDOUBLE)
-	  fvalue = va_arg(args, LDOUBLE);
-	else
-	  fvalue = va_arg(args, double);
-	/* um, floating point? */
-	fmtfp(buffer, &currlen, maxlen, fvalue, min, max, flags);
-	break;
+        if (cflags == DP_C_LDOUBLE)
+          fvalue = va_arg(args, LDOUBLE);
+        else
+          fvalue = va_arg(args, double);
+
+        /* um, floating point? */
+        fmtfp(buffer, &currlen, maxlen, fvalue, min, max, flags);
+        break;
       case 'E':
-	flags |= DP_F_UP;
+        flags |= DP_F_UP;
       case 'e':
-	if (cflags == DP_C_LDOUBLE)
-	  fvalue = va_arg(args, LDOUBLE);
-	else
-	  fvalue = va_arg(args, double);
-	break;
+        if (cflags == DP_C_LDOUBLE)
+          fvalue = va_arg(args, LDOUBLE);
+        else
+          fvalue = va_arg(args, double);
+
+        break;
       case 'G':
-	flags |= DP_F_UP;
+        flags |= DP_F_UP;
       case 'g':
-	if (cflags == DP_C_LDOUBLE)
-	  fvalue = va_arg(args, LDOUBLE);
-	else
-	  fvalue = va_arg(args, double);
-	break;
+        if (cflags == DP_C_LDOUBLE)
+          fvalue = va_arg(args, LDOUBLE);
+        else
+          fvalue = va_arg(args, double);
+
+        break;
       case 'c':
-	dopr_outch(buffer, &currlen, maxlen, va_arg(args, int));
-	break;
+        dopr_outch(buffer, &currlen, maxlen, va_arg(args, int));
+
+        break;
       case 's':
-	strvalue = va_arg(args, char *);
-	if (max < 0)
-	  max = maxlen;		/* ie, no max */
-	fmtstr(buffer, &currlen, maxlen, strvalue, flags, min, max);
-	break;
+        strvalue = va_arg(args, char *);
+
+        if (max < 0)
+          max = maxlen;         /* ie, no max */
+        fmtstr(buffer, &currlen, maxlen, strvalue, flags, min, max);
+        break;
       case 'p':
-	strvalue = va_arg(args, void *);
-	fmtint(buffer, &currlen, maxlen, (long) strvalue, 16, min, max,
-	       flags);
-	break;
+        strvalue = va_arg(args, void *);
+
+        fmtint(buffer, &currlen, maxlen, (long) strvalue, 16, min, max, flags);
+        break;
       case 'n':
-	if (cflags == DP_C_SHORT) {
-	  short int *num;
-	  num = va_arg(args, short int *);
-	  *num = currlen;
-	} else if (cflags == DP_C_LONG) {
-	  long int *num;
-	  num = va_arg(args, long int *);
-	  *num = currlen;
-	} else {
-	  int *num;
-	  num = va_arg(args, int *);
-	  *num = currlen;
-	}
-	break;
+        if (cflags == DP_C_SHORT) {
+          short int *num;
+          num = va_arg(args, short int *);
+
+          *num = currlen;
+        } else if (cflags == DP_C_LONG) {
+          long int *num;
+          num = va_arg(args, long int *);
+
+          *num = currlen;
+        } else {
+          int *num;
+          num = va_arg(args, int *);
+
+          *num = currlen;
+        }
+        break;
       case '%':
-	dopr_outch(buffer, &currlen, maxlen, ch);
-	break;
+        dopr_outch(buffer, &currlen, maxlen, ch);
+        break;
       case 'w':
-	/* not supported yet, treat as next char */
-	ch = *format++;
-	break;
+        /* not supported yet, treat as next char */
+        ch = *format++;
+        break;
       default:
-	/* Unknown, skip */
-	break;
+        /* Unknown, skip */
+        break;
       }
       ch = *format++;
       state = DP_S_DEFAULT;
@@ -387,7 +405,7 @@ static void dopr(char *buffer, size_t maxlen, const char *format,
       break;
     default:
       /* hmm? */
-      break;			/* some picky compilers need this */
+      break;                    /* some picky compilers need this */
     }
   }
   if (currlen < maxlen - 1)
@@ -396,23 +414,22 @@ static void dopr(char *buffer, size_t maxlen, const char *format,
     buffer[maxlen - 1] = '\0';
 }
 
-static void fmtstr(char *buffer, size_t * currlen, size_t maxlen,
-		   char *value, int flags, int min, int max)
+static void fmtstr(char *buffer, size_t *currlen, size_t maxlen,
+                   char *value, int flags, int min, int max)
 {
-  int padlen,
-      strln;			/* amount to pad */
+  int padlen, strln;            /* amount to pad */
   int cnt = 0;
 
   if (value == 0) {
     value = "<NULL>";
   }
 
-  for (strln = 0; value[strln]; ++strln);	/* strlen */
+  for (strln = 0; value[strln]; ++strln);       /* strlen */
   padlen = min - strln;
   if (padlen < 0)
     padlen = 0;
   if (flags & DP_F_MINUS)
-    padlen = -padlen;		/* Left Justify */
+    padlen = -padlen;           /* Left Justify */
 
   while ((padlen > 0) && (cnt < max)) {
     dopr_outch(buffer, currlen, maxlen, ' ');
@@ -432,15 +449,15 @@ static void fmtstr(char *buffer, size_t * currlen, size_t maxlen,
 
 /* Have to handle DP_F_NUM (ie 0x and 0 alternates) */
 
-static void fmtint(char *buffer, size_t * currlen, size_t maxlen,
-		   long value, int base, int min, int max, int flags)
+static void fmtint(char *buffer, size_t *currlen, size_t maxlen,
+                   long value, int base, int min, int max, int flags)
 {
   int signvalue = 0;
   unsigned long uvalue;
   char convert[20];
   int place = 0;
-  int spadlen = 0;		/* amount to space pad */
-  int zpadlen = 0;		/* amount to zero pad */
+  int spadlen = 0;              /* amount to space pad */
+  int zpadlen = 0;              /* amount to zero pad */
   int caps = 0;
 
   if (max < 0)
@@ -452,18 +469,18 @@ static void fmtint(char *buffer, size_t * currlen, size_t maxlen,
     if (value < 0) {
       signvalue = '-';
       uvalue = -value;
-    } else if (flags & DP_F_PLUS)	/* Do a sign (+/i) */
+    } else if (flags & DP_F_PLUS) /* Do a sign (+/i) */
       signvalue = '+';
     else if (flags & DP_F_SPACE)
       signvalue = ' ';
   }
 
   if (flags & DP_F_UP)
-    caps = 1;			/* Should characters be upper case? */
+    caps = 1;                   /* Should characters be upper case? */
 
   do {
     convert[place++] = (caps ? "0123456789ABCDEF" : "0123456789abcdef")
-	[uvalue % (unsigned) base];
+      [uvalue % (unsigned) base];
     uvalue = (uvalue / (unsigned) base);
   }
   while (uvalue && (place < 20));
@@ -482,12 +499,12 @@ static void fmtint(char *buffer, size_t * currlen, size_t maxlen,
     spadlen = 0;
   }
   if (flags & DP_F_MINUS)
-    spadlen = -spadlen;		/* Left Justifty */
+    spadlen = -spadlen;         /* Left Justifty */
 
 #ifdef DEBUG_SNPRINTF
   dprint(1,
-	 (debugfile, "zpad: %d, spad: %d, min: %d, max: %d, place: %d\n",
-	  zpadlen, spadlen, min, max, place));
+         (debugfile, "zpad: %d, spad: %d, min: %d, max: %d, place: %d\n",
+          zpadlen, spadlen, min, max, place));
 #endif
 
   /* Spaces */
@@ -553,8 +570,8 @@ static long round(LDOUBLE value)
   return intpart;
 }
 
-static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
-		  LDOUBLE fvalue, int min, int max, int flags)
+static void fmtfp(char *buffer, size_t *currlen, size_t maxlen,
+                  LDOUBLE fvalue, int min, int max, int flags)
 {
   int signvalue = 0;
   LDOUBLE ufvalue;
@@ -562,7 +579,7 @@ static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
   char fconvert[20];
   int iplace = 0;
   int fplace = 0;
-  int padlen = 0;		/* amount to pad */
+  int padlen = 0;               /* amount to pad */
   int zpadlen = 0;
   int caps = 0;
   long intpart;
@@ -579,14 +596,14 @@ static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
 
   if (fvalue < 0)
     signvalue = '-';
-  else if (flags & DP_F_PLUS)	/* Do a sign (+/i) */
+  else if (flags & DP_F_PLUS)   /* Do a sign (+/i) */
     signvalue = '+';
   else if (flags & DP_F_SPACE)
     signvalue = ' ';
 
 #if 0
   if (flags & DP_F_UP)
-    caps = 1;			/* Should characters be upper case? */
+    caps = 1;                   /* Should characters be upper case? */
 #endif
 
   intpart = ufvalue;
@@ -611,7 +628,7 @@ static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
   /* Convert integer part */
   do {
     iconvert[iplace++] =
-	(caps ? "0123456789ABCDEF" : "0123456789abcdef")[intpart % 10];
+      (caps ? "0123456789ABCDEF" : "0123456789abcdef")[intpart % 10];
     intpart = (intpart / 10);
   }
   while (intpart && (iplace < 20));
@@ -622,7 +639,7 @@ static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
   /* Convert fractional part */
   do {
     fconvert[fplace++] =
-	(caps ? "0123456789ABCDEF" : "0123456789abcdef")[fracpart % 10];
+      (caps ? "0123456789ABCDEF" : "0123456789abcdef")[fracpart % 10];
     fracpart = (fracpart / 10);
   }
   while (fracpart && (fplace < 20));
@@ -638,7 +655,7 @@ static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
   if (padlen < 0)
     padlen = 0;
   if (flags & DP_F_MINUS)
-    padlen = -padlen;		/* Left Justifty */
+    padlen = -padlen;           /* Left Justifty */
 
   if ((flags & DP_F_ZERO) && (padlen > 0)) {
     if (signvalue) {
@@ -683,8 +700,7 @@ static void fmtfp(char *buffer, size_t * currlen, size_t maxlen,
   }
 }
 
-static void dopr_outch(char *buffer, size_t * currlen, size_t maxlen,
-		       char c)
+static void dopr_outch(char *buffer, size_t *currlen, size_t maxlen, char c)
 {
   if (*currlen < maxlen)
     buffer[(*currlen)++] = c;
@@ -696,13 +712,14 @@ int egg_vsnprintf(char *str, size_t count, const char *fmt, va_list args)
   dopr(str, count, fmt, args);
   return (strlen(str));
 }
-#endif				/* !HAVE_VSNPRINTF */
+#endif /* !HAVE_VSNPRINTF */
 
 #ifndef HAVE_SNPRINTF
 #  ifdef HAVE_STDARGS
 int egg_snprintf(char *str, size_t count, const char *fmt, ...)
 #  else
-int egg_snprintf(va_alist) va_dcl
+int egg_snprintf(va_alist)
+va_dcl
 #  endif
 {
 #  ifndef HAVE_STDARGS
@@ -714,10 +731,12 @@ int egg_snprintf(va_alist) va_dcl
 
   VA_START(fmt);
   VA_SHIFT(str, char *);
+
   VA_SHIFT(count, size_t);
   VA_SHIFT(fmt, char *);
+
   (void) egg_vsnprintf(str, count, fmt, ap);
   VA_END;
   return (strlen(str));
 }
-#endif				/* !HAVE_SNPRINTF */
+#endif /* !HAVE_SNPRINTF */
