@@ -6,11 +6,11 @@
  *   memory management for dcc structures
  *   timeout checking for dcc connections
  *
- * $Id: dccutil.c,v 1.34 2002/01/02 03:46:35 guppy Exp $
+ * $Id: dccutil.c,v 1.48 2003/02/05 04:17:07 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,16 +34,16 @@
 #include "modules.h"
 #include "tandem.h"
 
-extern struct dcc_t	*dcc;
-extern int		 dcc_total, max_dcc, dcc_flood_thr, backgrd, MAXSOCKS;
-extern char		 botnetnick[], spaces[], version[];
-extern time_t		 now;
-extern sock_list	*socklist;
-extern Tcl_Interp	*interp;
+extern struct dcc_t *dcc;
+extern int dcc_total, max_dcc, dcc_flood_thr, backgrd, copy_to_tmp, MAXSOCKS;
+extern char botnetnick[], version[];
+extern time_t now;
+extern sock_list *socklist;
+extern Tcl_Interp *interp;
 
-char	motdfile[121] = "text/motd";	/* File where the motd is stored */
-int	connect_timeout = 15;		/* How long to wait before a telnet
-					   connection times out */
+char motdfile[121] = "text/motd";       /* File where the motd is stored */
+int connect_timeout = 15;       /* How long to wait before a telnet
+                                 * connection times out */
 
 int reserved_port_min = 0;
 int reserved_port_max = 0;
@@ -62,7 +62,7 @@ void init_dcc_max()
   MAXSOCKS = max_dcc + 10;
   if (socklist)
     socklist = (sock_list *) nrealloc((void *) socklist,
-				      sizeof(sock_list) * MAXSOCKS);
+               sizeof(sock_list) * MAXSOCKS);
   else
     socklist = (sock_list *) nmalloc(sizeof(sock_list) * MAXSOCKS);
   for (; osock < MAXSOCKS; osock++)
@@ -109,6 +109,7 @@ void dprintf EGG_VARARGS_DEF(int, arg1)
 
   idx = EGG_VARARGS_START(int, arg1, va);
   format = va_arg(va, char *);
+
   egg_vsnprintf(buf, 1023, format, va);
   va_end(va);
   /* We can not use the return value vsnprintf() to determine where
@@ -118,8 +119,8 @@ void dprintf EGG_VARARGS_DEF(int, arg1)
    */
   /* We actually can, since if it's < 0 or >= sizeof(buf), we know it wrote
    * sizeof(buf) bytes. But we're not doing that anyway.
-  */
-  buf[sizeof(buf)-1] = 0;
+   */
+  buf[sizeof(buf) - 1] = 0;
   len = strlen(buf);
 
   if (idx < 0) {
@@ -146,7 +147,7 @@ void dprintf EGG_VARARGS_DEF(int, arg1)
     }
     return;
   } else {
-    if (len > 500) {		/* Truncate to fit */
+    if (len > 500) {            /* Truncate to fit */
       buf[500] = 0;
       strcat(buf, "\n");
       len = 501;
@@ -155,9 +156,9 @@ void dprintf EGG_VARARGS_DEF(int, arg1)
       char *p = add_cr(buf);
 
       tputs(dcc[idx].sock, p, strlen(p));
-    } else if (dcc[idx].type && dcc[idx].type->output) {
+    } else if (dcc[idx].type && dcc[idx].type->output)
       dcc[idx].type->output(idx, buf, dcc[idx].u.other);
-    } else
+    else
       tputs(dcc[idx].sock, buf, len);
   }
 }
@@ -170,6 +171,7 @@ void chatout EGG_VARARGS_DEF(char *, arg1)
   va_list va;
 
   format = EGG_VARARGS_START(char *, arg1, va);
+
   egg_vsnprintf(s, 511, format, va);
   va_end(va);
   len = strlen(s);
@@ -196,6 +198,7 @@ void chanout_but EGG_VARARGS_DEF(int, arg1)
   x = EGG_VARARGS_START(int, arg1, va);
   chan = va_arg(va, int);
   format = va_arg(va, char *);
+
   egg_vsnprintf(s, 511, format, va);
   va_end(va);
   len = strlen(s);
@@ -213,7 +216,7 @@ void chanout_but EGG_VARARGS_DEF(int, arg1)
 void dcc_chatter(int idx)
 {
   int i, j;
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0 };
 
   get_user_flagrec(dcc[idx].user, &fr, NULL);
   show_motd(idx);
@@ -224,7 +227,7 @@ void dcc_chatter(int idx)
   check_tcl_chon(dcc[idx].nick, dcc[idx].sock);
   /* Still there? */
   if ((idx >= dcc_total) || (dcc[idx].sock != j))
-    return;			/* Nope */
+    return;                     /* Nope */
   /* Tcl script may have taken control */
   if (dcc[idx].type == &DCC_CHAT) {
     if (!strcmp(dcc[idx].u.chat->con_chan, "***"))
@@ -235,22 +238,45 @@ void dcc_chatter(int idx)
        * so dont bother sending them
        */
       if (i == -2)
-	i = 0;
+        i = 0;
       dcc[idx].u.chat->channel = i;
-      if (dcc[idx].u.chat->channel >= 0) {
-	if (dcc[idx].u.chat->channel < 100000) {
-	  botnet_send_join_idx(idx, -1);
-	}
-      }
+      if ((dcc[idx].u.chat->channel >= 0) &&
+          (dcc[idx].u.chat->channel < GLOBAL_CHANS))
+        botnet_send_join_idx(idx, -1);
       check_tcl_chjn(botnetnick, dcc[idx].nick, dcc[idx].u.chat->channel,
-		     geticon(idx), dcc[idx].sock, dcc[idx].host);
+                     geticon(idx), dcc[idx].sock, dcc[idx].host);
     }
     /* But *do* bother with sending it locally */
     if (!dcc[idx].u.chat->channel) {
       chanout_but(-1, 0, "*** %s joined the party line.\n", dcc[idx].nick);
     } else if (dcc[idx].u.chat->channel > 0) {
       chanout_but(-1, dcc[idx].u.chat->channel,
-		  "*** %s joined the channel.\n", dcc[idx].nick);
+                  "*** %s joined the channel.\n", dcc[idx].nick);
+    }
+  }
+}
+
+/* Closes an open FD for transfer sockets. */
+void killtransfer(int n)
+{
+  int i, ok = 1;
+
+  if (dcc[n].type->flags & DCT_FILETRAN) {
+    if (dcc[n].u.xfer->f) {
+      fclose(dcc[n].u.xfer->f);
+      dcc[n].u.xfer->f = NULL;
+    }
+    if (dcc[n].u.xfer->filename && copy_to_tmp) {
+      for (i = 0; i < dcc_total; i++) {
+        if ((i != n) && (dcc[i].type->flags & DCT_FILETRAN) &&
+            (dcc[i].u.xfer->filename) &&
+            (!strcmp(dcc[i].u.xfer->filename, dcc[n].u.xfer->filename))) {
+          ok = 0;
+          break;
+        }
+      }
+      if (ok)
+        unlink(dcc[n].u.xfer->filename);
     }
   }
 }
@@ -260,13 +286,17 @@ void dcc_chatter(int idx)
  */
 void lostdcc(int n)
 {
+  /* Make sure it's a valid dcc index. */
+  if (n < 0 || n >= max_dcc)
+    return;
+
   if (dcc[n].type && dcc[n].type->kill)
     dcc[n].type->kill(n, dcc[n].u.other);
   else if (dcc[n].u.other)
     nfree(dcc[n].u.other);
   egg_bzero(&dcc[n], sizeof(struct dcc_t));
 
-  dcc[n].sock = (-1);
+  dcc[n].sock = -1;
   dcc[n].type = &DCC_LOST;
 }
 
@@ -287,7 +317,7 @@ void removedcc(int n)
   if (n < dcc_total)
     egg_memcpy(&dcc[n], &dcc[dcc_total], sizeof(struct dcc_t));
   else
-    egg_bzero(&dcc[n], sizeof(struct dcc_t)); /* drummer */
+    egg_bzero(&dcc[n], sizeof(struct dcc_t));   /* drummer */
 }
 
 /* Clean up sockets that were just left for dead.
@@ -299,7 +329,7 @@ void dcc_remove_lost(void)
   for (i = 0; i < dcc_total; i++) {
     if (dcc[i].type == &DCC_LOST) {
       dcc[i].type = NULL;
-      dcc[i].sock = (-1);
+      dcc[i].sock = -1;
       removedcc(i);
       i--;
     }
@@ -311,15 +341,28 @@ void dcc_remove_lost(void)
  */
 void tell_dcc(int zidx)
 {
-  int i, j, k;
+  int i, j;
   char other[160];
+  char format[81];
+  int nicklen;
 
-  spaces[HANDLEN - 9] = 0;
-  dprintf(zidx, "SOCK ADDR     PORT  NICK     %s HOST              TYPE\n"
-	  ,spaces);
-  dprintf(zidx, "---- -------- ----- ---------%s ----------------- ----\n"
-	  ,spaces);
-  spaces[HANDLEN - 9] = ' ';
+  /* calculate max nicklen */
+  nicklen = 0;
+  for (i = 0; i < dcc_total; i++) {
+    if (strlen(dcc[i].nick) > nicklen)
+      nicklen = strlen(dcc[i].nick);
+  }
+  if (nicklen < 9)
+    nicklen = 9;
+
+  egg_snprintf(format, sizeof format, "%%-4s %%-8s %%-5s %%-%us %%-17s %%s\n",
+               nicklen);
+  dprintf(zidx, format, "SOCK", "ADDR", "PORT", "NICK", "HOST", "TYPE");
+  dprintf(zidx, format, "----", "--------", "-----", "---------",
+          "-----------------", "----");
+
+  egg_snprintf(format, sizeof format, "%%-4d %%08X %%5d %%-%us %%-17s %%s\n",
+               nicklen);
   /* Show server */
   for (i = 0; i < dcc_total; i++) {
     j = strlen(dcc[i].host);
@@ -333,11 +376,8 @@ void tell_dcc(int zidx)
       sprintf(other, "?:%lX  !! ERROR !!", (long) dcc[i].type);
       break;
     }
-    k = HANDLEN - strlen(dcc[i].nick);
-    spaces[k] = 0;
-    dprintf(zidx, "%-4d %08X %5d %s%s %-17s %s\n", dcc[i].sock, dcc[i].addr,
-	    dcc[i].port, dcc[i].nick, spaces, dcc[i].host + j, other);
-    spaces[k] = ' ';
+    dprintf(zidx, format, dcc[i].sock, dcc[i].addr, dcc[i].port, dcc[i].nick,
+            dcc[i].host + j, other);
   }
 }
 
@@ -351,8 +391,8 @@ void not_away(int idx)
   }
   if (dcc[idx].u.chat->channel >= 0) {
     chanout_but(-1, dcc[idx].u.chat->channel,
-		"*** %s is no longer away.\n", dcc[idx].nick);
-    if (dcc[idx].u.chat->channel < 100000) {
+                "*** %s is no longer away.\n", dcc[idx].nick);
+    if (dcc[idx].u.chat->channel < GLOBAL_CHANS) {
       botnet_send_away(-1, botnetnick, dcc[idx].sock, NULL, idx);
     }
   }
@@ -378,8 +418,8 @@ void set_away(int idx, char *s)
   strcpy(dcc[idx].u.chat->away, s);
   if (dcc[idx].u.chat->channel >= 0) {
     chanout_but(-1, dcc[idx].u.chat->channel,
-		"*** %s is now away: %s\n", dcc[idx].nick, s);
-    if (dcc[idx].u.chat->channel < 100000) {
+                "*** %s is now away: %s\n", dcc[idx].nick, s);
+    if (dcc[idx].u.chat->channel < GLOBAL_CHANS) {
       botnet_send_away(-1, botnetnick, dcc[idx].sock, s, idx);
     }
   }
@@ -392,6 +432,7 @@ void set_away(int idx, char *s)
 void *_get_data_ptr(int size, char *file, int line)
 {
   char *p;
+
 #ifdef DEBUG_MEM
   char x[1024];
 
@@ -475,7 +516,7 @@ void changeover_dcc(int i, struct dcc_table *type, int xtra_size)
   }
 }
 
-int detect_dcc_flood(time_t * timer, struct chat_info *chat, int idx)
+int detect_dcc_flood(time_t *timer, struct chat_info *chat, int idx)
 {
   time_t t;
 
@@ -491,24 +532,23 @@ int detect_dcc_flood(time_t * timer, struct chat_info *chat, int idx)
       /* FLOOD */
       dprintf(idx, "*** FLOOD: %s.\n", IRC_GOODBYE);
       /* Evil assumption here that flags&DCT_CHAT implies chat type */
-      if ((dcc[idx].type->flags & DCT_CHAT) && chat &&
-	  (chat->channel >= 0)) {
-	char x[1024];
+      if ((dcc[idx].type->flags & DCT_CHAT) && chat && (chat->channel >= 0)) {
+        char x[1024];
 
-	egg_snprintf(x, sizeof x, DCC_FLOODBOOT, dcc[idx].nick);
-	chanout_but(idx, chat->channel, "*** %s", x);
-	if (chat->channel < 100000)
-	  botnet_send_part_idx(idx, x);
+        egg_snprintf(x, sizeof x, DCC_FLOODBOOT, dcc[idx].nick);
+        chanout_but(idx, chat->channel, "*** %s", x);
+        if (chat->channel < GLOBAL_CHANS)
+          botnet_send_part_idx(idx, x);
       }
       check_tcl_chof(dcc[idx].nick, dcc[idx].sock);
       if ((dcc[idx].sock != STDOUT) || backgrd) {
-	killsock(dcc[idx].sock);
-	lostdcc(idx);
+        killsock(dcc[idx].sock);
+        lostdcc(idx);
       } else {
-	dprintf(DP_STDOUT, "\n### SIMULATION RESET ###\n\n");
-	dcc_chatter(idx);
+        dprintf(DP_STDOUT, "\n### SIMULATION RESET ###\n\n");
+        dcc_chatter(idx);
       }
-      return 1;			/* <- flood */
+      return 1;                 /* <- flood */
     }
   }
   return 0;
@@ -526,14 +566,13 @@ void do_boot(int idx, char *by, char *reason)
   /* If it's a partyliner (chatterer :) */
   /* Horrible assumption that DCT_CHAT using structure uses same format
    * as DCC_CHAT */
-  if ((dcc[idx].type->flags & DCT_CHAT) &&
-      (dcc[idx].u.chat->channel >= 0)) {
+  if ((dcc[idx].type->flags & DCT_CHAT) && (dcc[idx].u.chat->channel >= 0)) {
     char x[1024];
 
     egg_snprintf(x, sizeof x, DCC_BOOTED3, by, dcc[idx].nick,
-		 reason[0] ? ": " : "", reason);
+                 reason[0] ? ": " : "", reason);
     chanout_but(idx, dcc[idx].u.chat->channel, "*** %s.\n", x);
-    if (dcc[idx].u.chat->channel < 100000)
+    if (dcc[idx].u.chat->channel < GLOBAL_CHANS)
       botnet_send_part_idx(idx, x);
   }
   check_tcl_chof(dcc[idx].nick, dcc[idx].sock);
