@@ -2,11 +2,11 @@
  * flags.c -- handles:
  *   all the flag matching/conversion functions in one neat package :)
  *
- * $Id: flags.c,v 1.19 2002/01/02 03:46:35 guppy Exp $
+ * $Id: flags.c,v 1.25 2003/02/27 10:18:40 tothwolf Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,11 +26,8 @@
 #include "main.h"
 
 
-extern int		 use_console_r, debug_output, require_p, noshare,
-			 allow_dk_cmds;
-extern struct dcc_t	*dcc;
-
-int	use_console_r = 0;	/* Allow users to set their console +r	*/
+extern int raw_log, require_p, noshare, allow_dk_cmds;
+extern struct dcc_t *dcc;
 
 
 int logmodes(char *s)
@@ -70,7 +67,7 @@ int logmodes(char *s)
       break;
     case 'r':
     case 'R':
-      res |= use_console_r ? LOG_RAW : 0;
+      res |= raw_log ? LOG_RAW : 0;
       break;
     case 'w':
     case 'W':
@@ -90,15 +87,15 @@ int logmodes(char *s)
       break;
     case 'v':
     case 'V':
-      res |= debug_output ? LOG_SRVOUT : 0;
+      res |= raw_log ? LOG_SRVOUT : 0;
       break;
     case 't':
     case 'T':
-      res |= debug_output ? LOG_BOTNET : 0;
+      res |= raw_log ? LOG_BOTNET : 0;
       break;
     case 'h':
     case 'H':
-      res |= debug_output ? LOG_BOTSHARE : 0;
+      res |= raw_log ? LOG_BOTSHARE : 0;
       break;
     case '1':
       res |= LOG_LEV1;
@@ -133,7 +130,7 @@ int logmodes(char *s)
 
 char *masktype(int x)
 {
-  static char s[24];		/* Change this if you change the levels */
+  static char s[24];            /* Change this if you change the levels */
   char *p = s;
 
   if (x & LOG_MSGS)
@@ -150,7 +147,7 @@ char *masktype(int x)
     *p++ = 'o';
   if (x & LOG_BOTS)
     *p++ = 'b';
-  if ((x & LOG_RAW) && use_console_r)
+  if ((x & LOG_RAW) && raw_log)
     *p++ = 'r';
   if (x & LOG_FILES)
     *p++ = 'x';
@@ -160,11 +157,11 @@ char *masktype(int x)
     *p++ = 'd';
   if (x & LOG_WALL)
     *p++ = 'w';
-  if ((x & LOG_SRVOUT) && debug_output)
+  if ((x & LOG_SRVOUT) && raw_log)
     *p++ = 'v';
-  if ((x & LOG_BOTNET) && debug_output)
+  if ((x & LOG_BOTNET) && raw_log)
     *p++ = 't';
-  if ((x & LOG_BOTSHARE) && debug_output)
+  if ((x & LOG_BOTSHARE) && raw_log)
     *p++ = 'h';
   if (x & LOG_LEV1)
     *p++ = '1';
@@ -190,7 +187,7 @@ char *masktype(int x)
 
 char *maskname(int x)
 {
-  static char s[207];		/* Change this if you change the levels */
+  static char s[207];           /* Change this if you change the levels */
   int i = 0;
 
   s[0] = 0;
@@ -208,7 +205,7 @@ char *maskname(int x)
     i += my_strcpy(s + i, "misc, ");
   if (x & LOG_BOTS)
     i += my_strcpy(s + i, "bots, ");
-  if ((x & LOG_RAW) && use_console_r)
+  if ((x & LOG_RAW) && raw_log)
     i += my_strcpy(s + i, "raw, ");
   if (x & LOG_FILES)
     i += my_strcpy(s + i, "files, ");
@@ -218,11 +215,11 @@ char *maskname(int x)
     i += my_strcpy(s + i, "debug, ");
   if (x & LOG_WALL)
     i += my_strcpy(s + i, "wallops, ");
-  if ((x & LOG_SRVOUT) && debug_output)
+  if ((x & LOG_SRVOUT) && raw_log)
     i += my_strcpy(s + i, "server output, ");
-  if ((x & LOG_BOTNET) && debug_output)
+  if ((x & LOG_BOTNET) && raw_log)
     i += my_strcpy(s + i, "botnet traffic, ");
-  if ((x & LOG_BOTSHARE) && debug_output)
+  if ((x & LOG_BOTSHARE) && raw_log)
     i += my_strcpy(s + i, "share traffic, ");
   if (x & LOG_LEV1)
     i += my_strcpy(s + i, "level 1, ");
@@ -256,8 +253,12 @@ int sanity_check(int atr)
     atr &= ~(USER_PARTY | USER_MASTER | USER_COMMON | USER_OWNER);
   if ((atr & USER_OP) && (atr & USER_DEOP))
     atr &= ~(USER_OP | USER_DEOP);
+  if ((atr & USER_HALFOP) && (atr & USER_DEHALFOP))
+    atr &= ~(USER_HALFOP | USER_DEHALFOP);
   if ((atr & USER_AUTOOP) && (atr & USER_DEOP))
     atr &= ~(USER_AUTOOP | USER_DEOP);
+  if ((atr & USER_AUTOHALFOP) && (atr & USER_DEHALFOP))
+    atr &= ~(USER_AUTOHALFOP | USER_DEHALFOP);
   if ((atr & USER_VOICE) && (atr & USER_QUIET))
     atr &= ~(USER_VOICE | USER_QUIET);
   if ((atr & USER_GVOICE) && (atr & USER_QUIET))
@@ -283,8 +284,12 @@ int chan_sanity_check(int chatr, int atr)
 {
   if ((chatr & USER_OP) && (chatr & USER_DEOP))
     chatr &= ~(USER_OP | USER_DEOP);
+  if ((chatr & USER_HALFOP) && (chatr & USER_DEHALFOP))
+    chatr &= ~(USER_HALFOP | USER_DEHALFOP);
   if ((chatr & USER_AUTOOP) && (chatr & USER_DEOP))
     chatr &= ~(USER_AUTOOP | USER_DEOP);
+  if ((chatr & USER_AUTOHALFOP) && (chatr & USER_DEHALFOP))
+    chatr &= ~(USER_AUTOHALFOP | USER_DEHALFOP);
   if ((chatr & USER_VOICE) && (chatr & USER_QUIET))
     chatr &= ~(USER_VOICE | USER_QUIET);
   if ((chatr & USER_GVOICE) && (chatr & USER_QUIET))
@@ -294,7 +299,7 @@ int chan_sanity_check(int chatr, int atr)
     chatr |= USER_MASTER;
   /* Master implies op */
   if (chatr & USER_MASTER)
-    chatr |= USER_OP ;
+    chatr |= USER_OP;
   /* Can't be +s on chan unless you're a bot */
   if (!(atr & USER_BOT))
     chatr &= ~BOT_SHARE;
@@ -303,15 +308,16 @@ int chan_sanity_check(int chatr, int atr)
 
 /* Get icon symbol for a user (depending on access level)
  *
- * (*)owner on any channel
- * (+)master on any channel
+ * (*) owner on any channel
+ * (+) master on any channel
  * (%) botnet master
  * (@) op on any channel
+ * (^) halfop on any channel
  * (-) other
  */
 char geticon(int idx)
 {
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0 };
 
   if (!dcc[idx].user)
     return '-';
@@ -324,15 +330,17 @@ char geticon(int idx)
     return '%';
   if (chan_op(fr))
     return '@';
+  if (chan_halfop(fr))
+    return '^';
   return '-';
 }
 
 void break_down_flags(const char *string, struct flag_record *plus,
-		      struct flag_record *minus)
+                      struct flag_record *minus)
 {
-  struct flag_record	*which = plus;
-  int			 mode = 0;	/* 0 = glob, 1 = chan, 2 = bot */
-  int			 flags = plus->match;
+  struct flag_record *which = plus;
+  int mode = 0;                 /* 0 = glob, 1 = chan, 2 = bot */
+  int flags = plus->match;
 
   if (!(flags & FR_GLOBAL)) {
     if (flags & FR_BOT)
@@ -340,14 +348,14 @@ void break_down_flags(const char *string, struct flag_record *plus,
     else if (flags & FR_CHAN)
       mode = 1;
     else
-      return;			/* We dont actually want any..huh? */
+      return;                   /* We dont actually want any..huh? */
   }
   egg_bzero(plus, sizeof(struct flag_record));
 
   if (minus)
     egg_bzero(minus, sizeof(struct flag_record));
 
-  plus->match = FR_OR;		/* Default binding type OR */
+  plus->match = FR_OR;          /* Default binding type OR */
   while (*string) {
     switch (*string) {
     case '+':
@@ -359,53 +367,53 @@ void break_down_flags(const char *string, struct flag_record *plus,
     case '|':
     case '&':
       if (!mode) {
-	if (*string == '|')
-	  plus->match = FR_OR;
-	else
-	  plus->match = FR_AND;
+        if (*string == '|')
+          plus->match = FR_OR;
+        else
+          plus->match = FR_AND;
       }
       which = plus;
       mode++;
       if ((mode == 2) && !(flags & (FR_CHAN | FR_BOT)))
-	string = "";
+        string = "";
       else if (mode == 3)
-	mode = 1;
+        mode = 1;
       break;
     default:
       if ((*string >= 'a') && (*string <= 'z')) {
-	switch (mode) {
-	case 0:
-	  which->global |=1 << (*string - 'a');
+        switch (mode) {
+        case 0:
+          which->global |=1 << (*string - 'a');
 
-	  break;
-	case 1:
-	  which->chan |= 1 << (*string - 'a');
-	  break;
-	case 2:
-	  which->bot |= 1 << (*string - 'a');
-	}
+          break;
+        case 1:
+          which->chan |= 1 << (*string - 'a');
+          break;
+        case 2:
+          which->bot |= 1 << (*string - 'a');
+        }
       } else if ((*string >= 'A') && (*string <= 'Z')) {
-	switch (mode) {
-	case 0:
-	  which->udef_global |= 1 << (*string - 'A');
-	  break;
-	case 1:
-	  which->udef_chan |= 1 << (*string - 'A');
-	  break;
-	}
+        switch (mode) {
+        case 0:
+          which->udef_global |= 1 << (*string - 'A');
+          break;
+        case 1:
+          which->udef_chan |= 1 << (*string - 'A');
+          break;
+        }
       } else if ((*string >= '0') && (*string <= '9')) {
-	switch (mode) {
-	  /* Map 0->9 to A->K for glob/chan so they are not lost */
-	case 0:
-	  which->udef_global |= 1 << (*string - '0');
-	  break;
-	case 1:
-	  which->udef_chan |= 1 << (*string - '0');
-	  break;
-	case 2:
-	  which->bot |= BOT_FLAG0 << (*string - '0');
-	  break;
-	}
+        switch (mode) {
+          /* Map 0->9 to A->K for glob/chan so they are not lost */
+        case 0:
+          which->udef_global |= 1 << (*string - '0');
+          break;
+        case 1:
+          which->udef_chan |= 1 << (*string - '0');
+          break;
+        case 2:
+          which->bot |= BOT_FLAG0 << (*string - '0');
+          break;
+        }
       }
     }
     string++;
@@ -469,16 +477,16 @@ static int bot2str(char *string, int bot)
 }
 
 int build_flags(char *string, struct flag_record *plus,
-		struct flag_record *minus)
+                struct flag_record *minus)
 {
   char *old = string;
 
   if (plus->match & FR_GLOBAL) {
-    if (minus && (plus->global || plus->udef_global))
+    if (minus && (plus->global ||plus->udef_global))
       *string++ = '+';
     string += flag2str(string, plus->global, plus->udef_global);
 
-    if (minus && (minus->global || minus->udef_global)) {
+    if (minus && (minus->global ||minus->udef_global)) {
       *string++ = '-';
       string += flag2str(string, minus->global, minus->udef_global);
     }
@@ -521,24 +529,22 @@ int build_flags(char *string, struct flag_record *plus,
   return string - old;
 }
 
-int flagrec_ok(struct flag_record *req,
-	       struct flag_record *have)
+int flagrec_ok(struct flag_record *req, struct flag_record *have)
 {
-  if (req->match & FR_AND) {
+  if (req->match & FR_AND)
     return flagrec_eq(req, have);
-  } else if (req->match & FR_OR) {
+  else if (req->match & FR_OR) {
     int hav = have->global;
 
     /* Exception 1 - global +d/+k cant use -|-, unless they are +p */
-    if (!req->chan && !req->global && !req->udef_global &&
-	!req->udef_chan) {
+    if (!req->chan && !req->global &&!req->udef_global && !req->udef_chan) {
       if (!allow_dk_cmds) {
-	if (glob_party(*have))
-	  return 1;
-	if (glob_kick(*have) || chan_kick(*have))
-	  return 0;		/* +k cant use -|- commands */
-	if (glob_deop(*have) || chan_deop(*have))
-	  return 0;		/* neither can +d's */
+        if (glob_party(*have))
+          return 1;
+        if (glob_kick(*have) || chan_kick(*have))
+          return 0;             /* +k cant use -|- commands */
+        if (glob_deop(*have) || chan_deop(*have))
+          return 0;             /* neither can +d's */
       }
       return 1;
     }
@@ -557,7 +563,7 @@ int flagrec_ok(struct flag_record *req,
       return 1;
     return 0;
   }
-  return 0;			/* fr0k3 binding, dont pass it */
+  return 0;                     /* fr0k3 binding, dont pass it */
 }
 
 int flagrec_eq(struct flag_record *req, struct flag_record *have)
@@ -565,46 +571,46 @@ int flagrec_eq(struct flag_record *req, struct flag_record *have)
   if (req->match & FR_AND) {
     if (req->match & FR_GLOBAL) {
       if ((req->global &have->global) !=req->global)
-	return 0;
+        return 0;
       if ((req->udef_global & have->udef_global) != req->udef_global)
-	return 0;
+        return 0;
     }
     if (req->match & FR_BOT)
       if ((req->bot & have->bot) != req->bot)
-	return 0;
+        return 0;
     if (req->match & FR_CHAN) {
       if ((req->chan & have->chan) != req->chan)
-	return 0;
+        return 0;
       if ((req->udef_chan & have->udef_chan) != req->udef_chan)
-	return 0;
+        return 0;
     }
     return 1;
   } else if (req->match & FR_OR) {
-    if (!req->chan && !req->global && !req->udef_chan &&
-	!req->udef_global && !req->bot)
+    if (!req->chan && !req->global &&!req->udef_chan &&
+        !req->udef_global && !req->bot)
       return 1;
     if (req->match & FR_GLOBAL) {
       if (have->global &req->global)
-	return 1;
+        return 1;
       if (have->udef_global & req->udef_global)
-	return 1;
+        return 1;
     }
     if (req->match & FR_BOT)
       if (have->bot & req->bot)
-	return 1;
+        return 1;
     if (req->match & FR_CHAN) {
       if (have->chan & req->chan)
-	return 1;
+        return 1;
       if (have->udef_chan & req->udef_chan)
-	return 1;
+        return 1;
     }
     return 0;
   }
-  return 0;			/* fr0k3 binding, dont pass it */
+  return 0;                     /* fr0k3 binding, dont pass it */
 }
 
 void set_user_flagrec(struct userrec *u, struct flag_record *fr,
-		      const char *chname)
+                      const char *chname)
 {
   struct chanuserrec *cr = NULL;
   int oldflags = fr->match;
@@ -629,7 +635,7 @@ void set_user_flagrec(struct userrec *u, struct flag_record *fr,
   if ((oldflags & FR_CHAN) && chname) {
     for (cr = u->chanrec; cr; cr = cr->next)
       if (!rfc_casecmp(chname, cr->channel))
-	break;
+        break;
     ch = findchan_by_dname(chname);
     if (!cr && ch) {
       cr = user_malloc(sizeof(struct chanuserrec));
@@ -643,9 +649,9 @@ void set_user_flagrec(struct userrec *u, struct flag_record *fr,
       cr->flags = fr->chan;
       cr->flags_udef = fr->udef_chan;
       if (!noshare && !(u->flags & USER_UNSHARED) && channel_shared(ch)) {
-	fr->match = FR_CHAN;
-	build_flags(buffer, fr, NULL);
-	shareout(ch, "a %s %s %s\n", u->handle, buffer, chname);
+        fr->match = FR_CHAN;
+        build_flags(buffer, fr, NULL);
+        shareout(ch, "a %s %s %s\n", u->handle, buffer, chname);
       }
     }
   }
@@ -655,19 +661,22 @@ void set_user_flagrec(struct userrec *u, struct flag_record *fr,
 /* Always pass the dname (display name) to this function for chname <cybah>
  */
 void get_user_flagrec(struct userrec *u, struct flag_record *fr,
-		      const char *chname)
+                      const char *chname)
 {
   struct chanuserrec *cr = NULL;
 
   if (!u) {
     fr->global = fr->udef_global = fr->chan = fr->udef_chan = fr->bot = 0;
+
     return;
   }
   if (fr->match & FR_GLOBAL) {
     fr->global = u->flags;
+
     fr->udef_global = u->flags_udef;
   } else {
     fr->global = 0;
+
     fr->udef_global = 0;
   }
   if (fr->match & FR_BOT) {
@@ -679,21 +688,21 @@ void get_user_flagrec(struct userrec *u, struct flag_record *fr,
       fr->chan = u->flags;
       fr->udef_chan = u->flags_udef;
       for (cr = u->chanrec; cr; cr = cr->next)
-	if (findchan_by_dname(cr->channel)) {
-	  fr->chan |= cr->flags;
-	  fr->udef_chan |= cr->flags_udef;
-	}
+        if (findchan_by_dname(cr->channel)) {
+          fr->chan |= cr->flags;
+          fr->udef_chan |= cr->flags_udef;
+        }
     } else {
       if (chname)
-	for (cr = u->chanrec; cr; cr = cr->next)
-	  if (!rfc_casecmp(chname, cr->channel))
-	    break;
+        for (cr = u->chanrec; cr; cr = cr->next)
+          if (!rfc_casecmp(chname, cr->channel))
+            break;
       if (cr) {
-	fr->chan = cr->flags;
-	fr->udef_chan = cr->flags_udef;
+        fr->chan = cr->flags;
+        fr->udef_chan = cr->flags_udef;
       } else {
-	fr->chan = 0;
-	fr->udef_chan = 0;
+        fr->chan = 0;
+        fr->udef_chan = 0;
       }
     }
   }
@@ -701,7 +710,7 @@ void get_user_flagrec(struct userrec *u, struct flag_record *fr,
 
 static int botfl_unpack(struct userrec *u, struct user_entry *e)
 {
-  struct flag_record fr = {FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_BOT, 0, 0, 0, 0, 0 };
 
   break_down_flags(e->u.list->extra, &fr, NULL);
   list_type_kill(e->u.list);
@@ -712,12 +721,12 @@ static int botfl_unpack(struct userrec *u, struct user_entry *e)
 static int botfl_pack(struct userrec *u, struct user_entry *e)
 {
   char x[100];
-  struct flag_record fr = {FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_BOT, 0, 0, 0, 0, 0 };
 
   fr.bot = e->u.ulong;
   e->u.list = user_malloc(sizeof(struct list_type));
   e->u.list->next = NULL;
-  e->u.list->extra = user_malloc (build_flags (x, &fr, NULL) + 1);
+  e->u.list->extra = user_malloc(build_flags(x, &fr, NULL) + 1);
   strcpy(e->u.list->extra, x);
   return 1;
 }
@@ -729,10 +738,10 @@ static int botfl_kill(struct user_entry *e)
 }
 
 static int botfl_write_userfile(FILE *f, struct userrec *u,
-				struct user_entry *e)
+                                struct user_entry *e)
 {
   char x[100];
-  struct flag_record fr = {FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_BOT, 0, 0, 0, 0, 0 };
 
   fr.bot = e->u.ulong;
   build_flags(x, &fr, NULL);
@@ -746,8 +755,8 @@ static int botfl_set(struct userrec *u, struct user_entry *e, void *buf)
   register long atr = ((long) buf & BOT_VALID);
 
   if (!(u->flags & USER_BOT))
-    return 1;			/* Don't even bother trying to set the
-				   flags for a non-bot */
+    return 1;                   /* Don't even bother trying to set the
+                                 * flags for a non-bot */
 
   if ((atr & BOT_HUB) && (atr & BOT_ALT))
     atr &= ~BOT_ALT;
@@ -766,10 +775,10 @@ static int botfl_set(struct userrec *u, struct user_entry *e, void *buf)
 }
 
 static int botfl_tcl_get(Tcl_Interp *interp, struct userrec *u,
-			 struct user_entry *e, int argc, char **argv)
+                         struct user_entry *e, int argc, char **argv)
 {
   char x[100];
-  struct flag_record fr = {FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_BOT, 0, 0, 0, 0, 0 };
 
   fr.bot = e->u.ulong;
   build_flags(x, &fr, NULL);
@@ -778,11 +787,12 @@ static int botfl_tcl_get(Tcl_Interp *interp, struct userrec *u,
 }
 
 static int botfl_tcl_set(Tcl_Interp *irp, struct userrec *u,
-			 struct user_entry *e, int argc, char **argv)
+                         struct user_entry *e, int argc, char **argv)
 {
-  struct flag_record fr = {FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_BOT, 0, 0, 0, 0, 0 };
 
   BADARGS(4, 4, " handle BOTFL flags");
+
   if (u->flags & USER_BOT) {
     /* Silently ignore for users */
     break_down_flags(argv[3], &fr, NULL);
@@ -798,7 +808,7 @@ static int botfl_expmem(struct user_entry *e)
 
 static void botfl_display(int idx, struct user_entry *e)
 {
-  struct flag_record fr = {FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_BOT, 0, 0, 0, 0, 0 };
   char x[100];
 
   fr.bot = e->u.ulong;
@@ -806,9 +816,8 @@ static void botfl_display(int idx, struct user_entry *e)
   dprintf(idx, "  BOT FLAGS: %s\n", x);
 }
 
-struct user_entry_type USERENTRY_BOTFL =
-{
-  0,				/* always 0 ;) */
+struct user_entry_type USERENTRY_BOTFL = {
+  0,                            /* always 0 ;) */
   0,
   def_dupuser,
   botfl_unpack,
