@@ -7,11 +7,11 @@
  *   help system
  *   motd display and %var substitution
  *
- * $Id: misc.c,v 1.47 2002/01/02 03:46:35 guppy Exp $
+ * $Id: misc.c,v 1.64 2003/05/03 04:36:38 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,24 +40,24 @@
 #endif
 #include "stat.h"
 
-extern struct dcc_t	*dcc;
-extern struct chanset_t	*chanset;
-extern char		 helpdir[], version[], origbotname[], botname[],
-			 admin[], network[], motdfile[], ver[], botnetnick[],
-			 bannerfile[], logfile_suffix[], textdir[];
-extern int		 backgrd, con_chan, term_z, use_stderr, dcc_total,
-			 keep_all_logs, quick_logs, strict_host;
-extern time_t		 now;
-extern Tcl_Interp	*interp;
+extern struct dcc_t *dcc;
+extern struct chanset_t *chanset;
+extern char helpdir[], version[], origbotname[], botname[], admin[], network[],
+            motdfile[], ver[], botnetnick[], bannerfile[], logfile_suffix[],
+            textdir[];
+extern int backgrd, con_chan, term_z, use_stderr, dcc_total, keep_all_logs,
+           quick_logs, strict_host;
+extern time_t now;
+extern Tcl_Interp *interp;
 
 
-int	 shtime = 1;		/* Whether or not to display the time
-				   with console output */
-log_t	*logs = 0;		/* Logfiles */
-int	 max_logs = 5;		/* Current maximum log files */
-int	 max_logsize = 0;	/* Maximum logfile size, 0 for no limit */
-int	 conmask = LOG_MODES | LOG_CMDS | LOG_MISC; /* Console mask */
-int	 debug_output = 0;	/* Disply output to server to LOG_SERVEROUT */
+int shtime = 1;                 /* Whether or not to display the time
+                                 * with console output */
+log_t *logs = 0;                /* Logfiles */
+int max_logs = 5;               /* Current maximum log files */
+int max_logsize = 0;            /* Maximum logfile size, 0 for no limit */
+int conmask = LOG_MODES | LOG_CMDS | LOG_MISC;  /* Console mask */
+int raw_log = 0;                /* Disply output to server to LOG_SERVEROUT */
 
 struct help_list_t {
   struct help_list_t *next;
@@ -130,24 +130,24 @@ int is_file(const char *s)
   return 0;
 }
 
-/*	  This implementation wont overrun dst - 'max' is the max bytes that dst
- *	can be, including the null terminator. So if 'dst' is a 128 byte buffer,
- *	pass 128 as 'max'. The function will _always_ null-terminate 'dst'.
+/*  This implementation wont overrun dst - 'max' is the max bytes that dst
+ *  can be, including the null terminator. So if 'dst' is a 128 byte buffer,
+ *  pass 128 as 'max'. The function will _always_ null-terminate 'dst'.
  *
- *	Returns: The number of characters appended to 'dst'.
+ *  Returns: The number of characters appended to 'dst'.
  *
- *  Usage eg.
+ *  Usage example:
  *
- *		char 	buf[128];
- *		size_t	bufsize = sizeof(buf);
+ *    char buf[128];
+ *    size_t bufsize = sizeof(buf);
  *
- *		buf[0] = 0, bufsize--;
+ *    buf[0] = 0, bufsize--;
  *
- *		while (blah && bufsize) {
- *			bufsize -= egg_strcatn(buf, <some-long-string>, sizeof(buf));
- *		}
+ *    while (blah && bufsize) {
+ *      bufsize -= egg_strcatn(buf, <some-long-string>, sizeof(buf));
+ *    }
  *
- *	<Cybah>
+ *  <Cybah>
  */
 int egg_strcatn(char *dst, const char *src, size_t max)
 {
@@ -278,7 +278,7 @@ char *newsplit(char **rest)
  * or "abc!user@3ffe:604:2:b02e:6174:7265:6964:6573" into
  *    "*!user@3ffe:604:2:b02e:6174:7265:6964:*"
  */
-void maskhost(const char *s, char *nw)
+void _maskhost(const char *s, char *nw, int host)
 {
   register const char *p, *q, *e, *f;
   int i;
@@ -299,11 +299,13 @@ void maskhost(const char *s, char *nw)
     while (*p != '@') {
       if (!fl && strchr("~+-^=", *p)) {
         if (strict_host)
-	  nw[i] = '?';
-	else
-	  i--;
+          nw[i] = '?';
+        else if (!host)
+          nw[i] = '*';
+        else
+          i--;
       } else
-	nw[i] = *p;
+        nw[i] = *p;
       fl++;
       p++;
       i++;
@@ -323,15 +325,15 @@ void maskhost(const char *s, char *nw)
     /* TLD or 2 part host */
     strcpy(nw, q);
   else {
-    if (e == NULL) {		/* IPv6 address?		*/
+    if (e == NULL) {            /* IPv6 address?                */
       const char *mask_str;
 
       f = strrchr(q, ':');
-      if (strchr(f, '.')) {	/* IPv4 wrapped in an IPv6?	*/
-	f = strrchr(f, '.');
-	mask_str = ".*";
-      } else 			/* ... no, true IPv6.		*/
-	mask_str = ":*";
+      if (strchr(f, '.')) {     /* IPv4 wrapped in an IPv6?     */
+        f = strrchr(f, '.');
+        mask_str = ".*";
+      } else                      /* ... no, true IPv6.               */
+        mask_str = ":*";
       strncpy(nw, q, f - q);
       /* No need to nw[f-q] = 0 here, as the strcpy below will
        * terminate the string for us.
@@ -341,32 +343,32 @@ void maskhost(const char *s, char *nw)
     } else {
       for (f = e; *f; f++);
       f--;
-      if (*f >= '0' && *f <= '9') {	/* Numeric IP address */
-	while (*f != '.')
-	  f--;
-	strncpy(nw, q, f - q);
-	/* No need to nw[f-q] = 0 here, as the strcpy below will
-	 * terminate the string for us.
-	 */
-	nw += (f - q);
-	strcpy(nw, ".*");
-      } else {				/* Normal host >= 3 parts */
-	/*    a.b.c  -> *.b.c
-	 *    a.b.c.d ->  *.b.c.d if tld is a country (2 chars)
-	 *             OR   *.c.d if tld is com/edu/etc (3 chars)
-	 *    a.b.c.d.e -> *.c.d.e   etc
-	 */
-	const char *x = strchr(e + 1, '.');
+      if (*f >= '0' && *f <= '9') {     /* Numeric IP address */
+        while (*f != '.')
+          f--;
+        strncpy(nw, q, f - q);
+        /* No need to nw[f-q] = 0 here, as the strcpy below will
+         * terminate the string for us.
+         */
+        nw += (f - q);
+        strcpy(nw, ".*");
+      } else {                    /* Normal host >= 3 parts */
+        /*    a.b.c  -> *.b.c
+         *    a.b.c.d ->  *.b.c.d if tld is a country (2 chars)
+         *             OR   *.c.d if tld is com/edu/etc (3 chars)
+         *    a.b.c.d.e -> *.c.d.e   etc
+         */
+        const char *x = strchr(e + 1, '.');
 
-	if (!x)
-	  x = p;
-	else if (strchr(x + 1, '.'))
-	  x = e;
-	else if (strlen(x) == 3)
-	  x = p;
-	else
-	  x = e;
-	sprintf(nw, "*%s", x);
+        if (!x)
+          x = p;
+        else if (strchr(x + 1, '.'))
+          x = e;
+        else if (strlen(x) == 3)
+          x = p;
+        else
+          x = e;
+        sprintf(nw, "*%s", x);
       }
     }
   }
@@ -376,8 +378,8 @@ void maskhost(const char *s, char *nw)
  */
 void dumplots(int idx, const char *prefix, char *data)
 {
-  char		*p = data, *q, *n, c;
-  const int	 max_data_len = 500 - strlen(prefix);
+  char *p = data, *q, *n, c;
+  const int max_data_len = 500 - strlen(prefix);
 
   if (!*data) {
     dprintf(idx, "%s\n", prefix);
@@ -396,16 +398,16 @@ void dumplots(int idx, const char *prefix, char *data)
     } else {
       /* Search backwards for the last space */
       while (*q != ' ' && q != p)
-	q--;
+        q--;
       if (q == p)
-	q = p + max_data_len;
+        q = p + max_data_len;
       c = *q;
       *q = 0;
       dprintf(idx, "%s%s\n", prefix, p);
       *q = c;
       p = q;
       if (c == ' ')
-	p++;
+        p++;
     }
   }
   /* Last trailing bit: split by linefeeds if possible */
@@ -418,7 +420,7 @@ void dumplots(int idx, const char *prefix, char *data)
     n = strchr(p, '\n');
   }
   if (*p)
-    dprintf(idx, "%s%s\n", prefix, p);	/* Last trailing bit */
+    dprintf(idx, "%s%s\n", prefix, p);  /* Last trailing bit */
 }
 
 /* Convert an interval (in seconds) to one of:
@@ -481,105 +483,106 @@ void daysdur(time_t now, time_t then, char *out)
  */
 void putlog EGG_VARARGS_DEF(int, arg1)
 {
-  int i, type;
-  char *format, *chname, s[LOGLINELEN], s1[256], *out;
-  time_t tt;
-  char ct[81], *s2;
-  struct tm *t = localtime(&now);
+  int i, type, tsl = 0;
+  char *format, *chname, s[LOGLINELEN], s1[256], *out, ct[81], *s2, stamp[34];
   va_list va;
+  time_t now2 = time(NULL);
+  struct tm *t;
 
   type = EGG_VARARGS_START(int, arg1, va);
   chname = va_arg(va, char *);
   format = va_arg(va, char *);
 
-  /* Format log entry at offset 8, then i can prepend the timestamp */
-  out = &s[8];
+  /* Create the timestamp */
+  if (shtime) {
+    t = localtime(&now2);
+    egg_strftime(stamp, sizeof(stamp) - 2, LOG_TS, t);
+    strcat(stamp, " ");
+    tsl = strlen(stamp);
+  }
+
+  /* Format log entry at offset 'tsl,' then i can prepend the timestamp */
+  out = s+tsl;
   /* No need to check if out should be null-terminated here,
    * just do it! <cybah>
    */
-  egg_vsnprintf(out, LOGLINEMAX - 8, format, va);
-  out[LOGLINEMAX - 8] = 0;
-  tt = now;
+  egg_vsnprintf(out, LOGLINEMAX - tsl, format, va);
+  out[LOGLINEMAX - tsl] = 0;
   if (keep_all_logs) {
     if (!logfile_suffix[0])
-      egg_strftime(ct, 12, ".%d%b%Y", localtime(&tt));
+      egg_strftime(ct, 12, ".%d%b%Y", t);
     else {
-      egg_strftime(ct, 80, logfile_suffix, localtime(&tt));
+      egg_strftime(ct, 80, logfile_suffix, t);
       ct[80] = 0;
       s2 = ct;
       /* replace spaces by underscores */
       while (s2[0]) {
-	if (s2[0] == ' ')
-	  s2[0] = '_';
-	s2++;
+        if (s2[0] == ' ')
+          s2[0] = '_';
+        s2++;
       }
     }
   }
+  /* Place the timestamp in the string to be printed */
   if ((out[0]) && (shtime)) {
-    egg_strftime(s1, 9, "[%H:%M] ", localtime(&tt));
-    strncpy(&s[0], s1, 8);
+    strncpy(s, stamp, tsl);
     out = s;
   }
   strcat(out, "\n");
   if (!use_stderr) {
     for (i = 0; i < max_logs; i++) {
       if ((logs[i].filename != NULL) && (logs[i].mask & type) &&
-	  ((chname[0] == '*') || (logs[i].chname[0] == '*') ||
-	   (!rfc_casecmp(chname, logs[i].chname)))) {
-	if (logs[i].f == NULL) {
-	  /* Open this logfile */
-	  if (keep_all_logs) {
-	    egg_snprintf(s1, 256, "%s%s", logs[i].filename, ct);
-	    logs[i].f = fopen(s1, "a+");
-	  } else
-	    logs[i].f = fopen(logs[i].filename, "a+");
-	}
-	if (logs[i].f != NULL) {
-	  /* Check if this is the same as the last line added to
-	   * the log. <cybah>
-	   */
-	  if (!egg_strcasecmp(out + 8, logs[i].szlast)) {
-	    /* It is a repeat, so increment repeats */
-	    logs[i].repeats++;
-	  } else {
-	    /* Not a repeat, check if there were any repeat
-	     * lines previously...
-	     */
-	    if (logs[i].repeats > 0) {
-	      /* Yep.. so display 'last message repeated x times'
-	       * then reset repeats. We want the current time here,
-	       * so put that in the file first.
-	       */
-	      if (t) {
-		fprintf(logs[i].f, "[%2.2d:%2.2d] ", t->tm_hour, t->tm_min);
-		fprintf(logs[i].f, MISC_LOGREPEAT, logs[i].repeats);
-	      } else {
-		fprintf(logs[i].f, "[??:??] ");
-		fprintf(logs[i].f, MISC_LOGREPEAT, logs[i].repeats);
-	      }
-	      logs[i].repeats = 0;
-	      /* No need to reset logs[i].szlast here
-	       * because we update it later on...
-	       */
-	    }
-	    fputs(out, logs[i].f);
-	    strncpyz(logs[i].szlast, out + 8, LOGLINEMAX);
-	  }
-	}
+          ((chname[0] == '*') || (logs[i].chname[0] == '*') ||
+           (!rfc_casecmp(chname, logs[i].chname)))) {
+        if (logs[i].f == NULL) {
+          /* Open this logfile */
+          if (keep_all_logs) {
+            egg_snprintf(s1, 256, "%s%s", logs[i].filename, ct);
+            logs[i].f = fopen(s1, "a+");
+          } else
+            logs[i].f = fopen(logs[i].filename, "a+");
+        }
+        if (logs[i].f != NULL) {
+          /* Check if this is the same as the last line added to
+           * the log. <cybah>
+           */
+          if (!egg_strcasecmp(out + tsl, logs[i].szlast))
+            /* It is a repeat, so increment repeats */
+            logs[i].repeats++;
+          else {
+            /* Not a repeat, check if there were any repeat
+             * lines previously...
+             */
+            if (logs[i].repeats > 0) {
+              /* Yep.. so display 'last message repeated x times'
+               * then reset repeats. We want the current time here,
+               * so put that in the file first.
+               */
+              fprintf(logs[i].f, stamp);
+              fprintf(logs[i].f, MISC_LOGREPEAT, logs[i].repeats);
+              logs[i].repeats = 0;
+              /* No need to reset logs[i].szlast here
+               * because we update it later on...
+               */
+            }
+            fputs(out, logs[i].f);
+            strncpyz(logs[i].szlast, out + tsl, LOGLINEMAX);
+          }
+        }
       }
     }
   }
   for (i = 0; i < dcc_total; i++)
     if ((dcc[i].type == &DCC_CHAT) && (dcc[i].u.chat->con_flags & type)) {
       if ((chname[0] == '*') || (dcc[i].u.chat->con_chan[0] == '*') ||
-	  (!rfc_casecmp(chname, dcc[i].u.chat->con_chan)))
-	dprintf(i, "%s", out);
+          (!rfc_casecmp(chname, dcc[i].u.chat->con_chan)))
+        dprintf(i, "%s", out);
     }
   if ((!backgrd) && (!con_chan) && (!term_z))
     dprintf(DP_STDOUT, "%s", out);
   else if ((type & LOG_MISC) && use_stderr) {
     if (shtime)
-      out += 8;
+      out += tsl;
     dprintf(DP_STDERR, "%s", s);
   }
   va_end(va);
@@ -590,8 +593,12 @@ void putlog EGG_VARARGS_DEF(int, arg1)
  */
 void logsuffix_change(char *s)
 {
-  int	 i;
-  char	*s2 = logfile_suffix;
+  int i;
+  char *s2 = logfile_suffix;
+
+  /* If the suffix didn't really change, ignore. It's probably a rehash. */
+  if (s && s2 && !strcmp(s, s2))
+    return;
 
   debug0("Logfile suffix changed. Closing all open logs.");
   strcpy(logfile_suffix, s);
@@ -613,29 +620,30 @@ void check_logsize()
 {
   struct stat ss;
   int i;
+
 /* int x=1; */
-  char buf[1024];		/* Should be plenty */
+  char buf[1024];               /* Should be plenty */
 
   if (!keep_all_logs && max_logsize > 0) {
     for (i = 0; i < max_logs; i++) {
       if (logs[i].filename) {
-	if (stat(logs[i].filename, &ss) != 0) {
-	  break;
-	}
-	if ((ss.st_size >> 10) > max_logsize) {
-	  if (logs[i].f) {
-	    /* write to the log before closing it huh.. */
-	    putlog(LOG_MISC, "*", MISC_CLOGS, logs[i].filename, ss.st_size);
-	    fflush(logs[i].f);
-	    fclose(logs[i].f);
-	    logs[i].f = NULL;
-	  }
+        if (stat(logs[i].filename, &ss) != 0) {
+          break;
+        }
+        if ((ss.st_size >> 10) > max_logsize) {
+          if (logs[i].f) {
+            /* write to the log before closing it huh.. */
+            putlog(LOG_MISC, "*", MISC_CLOGS, logs[i].filename, ss.st_size);
+            fflush(logs[i].f);
+            fclose(logs[i].f);
+            logs[i].f = NULL;
+          }
 
-	  egg_snprintf(buf, sizeof buf, "%s.yesterday", logs[i].filename);
-	  buf[1023] = 0;
-	  unlink(buf);
-	  movefile(logs[i].filename, buf);
-	}
+          egg_snprintf(buf, sizeof buf, "%s.yesterday", logs[i].filename);
+          buf[1023] = 0;
+          unlink(buf);
+          movefile(logs[i].filename, buf);
+        }
       }
     }
   }
@@ -646,7 +654,6 @@ void check_logsize()
 void flushlogs()
 {
   int i;
-  struct tm *t = localtime(&now);
 
   /* Logs may not be initialised yet. */
   if (!logs)
@@ -657,19 +664,17 @@ void flushlogs()
    */
   for (i = 0; i < max_logs; i++) {
     if (logs[i].f != NULL) {
-       if ((logs[i].repeats > 0) && quick_logs) {
-         /* Repeat.. if quicklogs used then display 'last message
-          * repeated x times' and reset repeats.
-	  */
-	if (t) {
-	  fprintf(logs[i].f, "[%2.2d:%2.2d] ", t->tm_hour, t->tm_min);
-	  fprintf(logs[i].f, MISC_LOGREPEAT, logs[i].repeats);
-	} else {
-	  fprintf(logs[i].f, "[??:??] ");
-	  fprintf(logs[i].f, MISC_LOGREPEAT, logs[i].repeats);
-	}
-	/* Reset repeats */
-	logs[i].repeats = 0;
+      if ((logs[i].repeats > 0) && quick_logs) {
+        /* Repeat.. if quicklogs used then display 'last message
+         * repeated x times' and reset repeats.
+         */
+        char stamp[33];
+
+        egg_strftime(stamp, sizeof(stamp) - 1, LOG_TS, localtime(&now));
+        fprintf(logs[i].f, "%s ", stamp);
+        fprintf(logs[i].f, MISC_LOGREPEAT, logs[i].repeats);
+        /* Reset repeats */
+        logs[i].repeats = 0;
       }
       fflush(logs[i].f);
     }
@@ -681,11 +686,11 @@ void flushlogs()
  *     String substitution functions
  */
 
-static int	 cols = 0;
-static int	 colsofar = 0;
-static int	 blind = 0;
-static int	 subwidth = 70;
-static char	*colstr = NULL;
+static int cols = 0;
+static int colsofar = 0;
+static int blind = 0;
+static int subwidth = 70;
+static char *colstr = NULL;
 
 
 /* Add string to colstr
@@ -698,7 +703,7 @@ static void subst_addcol(char *s, char *newcol)
   if ((newcol[0]) && (newcol[0] != '\377'))
     colsofar++;
   colstr = nrealloc(colstr, strlen(colstr) + strlen(newcol) +
-		    (colstr[0] ? 2 : 1));
+                    (colstr[0] ? 2 : 1));
   if ((newcol[0]) && (newcol[0] != '\377')) {
     if (colstr[0])
       strcat(colstr, "\377");
@@ -714,7 +719,7 @@ static void subst_addcol(char *s, char *newcol)
       *p = 0;
       strcat(s, q);
       for (i = strlen(q); i < colwidth; i++)
-	strcat(s, " ");
+        strcat(s, " ");
       q = p + 1;
       p = strchr(q, '\377');
     }
@@ -750,13 +755,14 @@ static void subst_addcol(char *s, char *newcol)
 #define HELP_FLASH 8
 
 void help_subst(char *s, char *nick, struct flag_record *flags,
-		int isdcc, char *topic)
+                int isdcc, char *topic)
 {
   char xx[HELP_BUF_LEN + 1], sub[161], *current, *q, chr, *writeidx,
-  *readidx, *towrite;
+       *readidx, *towrite;
   struct chanset_t *chan;
   int i, j, center = 0;
   static int help_flags;
+
 #ifdef HAVE_UNAME
   struct utsname uname_info;
 #endif
@@ -794,71 +800,69 @@ void help_subst(char *s, char *nick, struct flag_record *flags,
     switch (chr) {
     case 'b':
       if (glob_hilite(*flags)) {
-	if (help_flags & HELP_IRC) {
-	  towrite = "\002";
-	} else if (help_flags & HELP_BOLD) {
-	  help_flags &= ~HELP_BOLD;
-	  towrite = "\033[0m";
-	} else {
-	  help_flags |= HELP_BOLD;
-	  towrite = "\033[1m";
-	}
+        if (help_flags & HELP_IRC) {
+          towrite = "\002";
+        } else if (help_flags & HELP_BOLD) {
+          help_flags &= ~HELP_BOLD;
+          towrite = "\033[0m";
+        } else {
+          help_flags |= HELP_BOLD;
+          towrite = "\033[1m";
+        }
       }
       break;
     case 'v':
       if (glob_hilite(*flags)) {
-	if (help_flags & HELP_IRC) {
-	  towrite = "\026";
-	} else if (help_flags & HELP_REV) {
-	  help_flags &= ~HELP_REV;
-	  towrite = "\033[0m";
-	} else {
-	  help_flags |= HELP_REV;
-	  towrite = "\033[7m";
-	}
+        if (help_flags & HELP_IRC) {
+          towrite = "\026";
+        } else if (help_flags & HELP_REV) {
+          help_flags &= ~HELP_REV;
+          towrite = "\033[0m";
+        } else {
+          help_flags |= HELP_REV;
+          towrite = "\033[7m";
+        }
       }
       break;
     case '_':
       if (glob_hilite(*flags)) {
-	if (help_flags & HELP_IRC) {
-	  towrite = "\037";
-	} else if (help_flags & HELP_UNDER) {
-	  help_flags &= ~HELP_UNDER;
-	  towrite = "\033[0m";
-	} else {
-	  help_flags |= HELP_UNDER;
-	  towrite = "\033[4m";
-	}
+        if (help_flags & HELP_IRC) {
+          towrite = "\037";
+        } else if (help_flags & HELP_UNDER) {
+          help_flags &= ~HELP_UNDER;
+          towrite = "\033[0m";
+        } else {
+          help_flags |= HELP_UNDER;
+          towrite = "\033[4m";
+        }
       }
       break;
     case 'f':
       if (glob_hilite(*flags)) {
-	if (help_flags & HELP_FLASH) {
-	  if (help_flags & HELP_IRC) {
-	    towrite = "\002\037";
-	  } else {
-	    towrite = "\033[0m";
-	  }
-	  help_flags &= ~HELP_FLASH;
-	} else {
-	  help_flags |= HELP_FLASH;
-	  if (help_flags & HELP_IRC) {
-	    towrite = "\037\002";
-	  } else {
-	    towrite = "\033[5m";
-	  }
-	}
+        if (help_flags & HELP_FLASH) {
+          if (help_flags & HELP_IRC)
+            towrite = "\002\037";
+          else
+            towrite = "\033[0m";
+          help_flags &= ~HELP_FLASH;
+        } else {
+          help_flags |= HELP_FLASH;
+          if (help_flags & HELP_IRC)
+            towrite = "\037\002";
+          else
+            towrite = "\033[5m";
+        }
       }
       break;
     case 'U':
 #ifdef HAVE_UNAME
-      if (!uname(&uname_info)) {
-	egg_snprintf(sub, sizeof sub, "%s %s", uname_info.sysname,
-		       uname_info.release);
-	towrite = sub;
+      if (uname(&uname_info) >= 0) {
+        egg_snprintf(sub, sizeof sub, "%s %s", uname_info.sysname,
+                     uname_info.release);
+        towrite = sub;
       } else
 #endif
-	towrite = "*UNKNOWN*";
+        towrite = "*UNKNOWN*";
       break;
     case 'B':
       towrite = (isdcc ? botnetnick : botname);
@@ -882,95 +886,93 @@ void help_subst(char *s, char *nick, struct flag_record *flags,
     case 'N':
       towrite = strchr(nick, ':');
       if (towrite)
-	towrite++;
+        towrite++;
       else
-	towrite = nick;
+        towrite = nick;
       break;
     case 'C':
       if (!blind)
-	for (chan = chanset; chan; chan = chan->next) {
-	  if ((strlen(chan->dname) + writeidx + 2) >=
-	      (s + HELP_BUF_LEN)) {
-	    strncpy(writeidx, chan->dname, (s + HELP_BUF_LEN) - writeidx);
-	    s[HELP_BUF_LEN] = 0;
-	    return;
-	  }
-	  writeidx += my_strcpy(writeidx, chan->dname);
-	  if (chan->next) {
-	    *writeidx++ = ',';
-	    *writeidx++ = ' ';
-	  }
-	}
+        for (chan = chanset; chan; chan = chan->next) {
+          if ((strlen(chan->dname) + writeidx + 2) >= (s + HELP_BUF_LEN)) {
+            strncpy(writeidx, chan->dname, (s + HELP_BUF_LEN) - writeidx);
+            s[HELP_BUF_LEN] = 0;
+            return;
+          }
+          writeidx += my_strcpy(writeidx, chan->dname);
+          if (chan->next) {
+            *writeidx++ = ',';
+            *writeidx++ = ' ';
+          }
+        }
       break;
     case '{':
       q = current;
       current++;
       while ((*current != '}') && (*current))
-	current++;
+        current++;
       if (*current) {
-	*current = 0;
-	current--;
-	q += 2;
-	/* Now q is the string and p is where the rest of the fcn expects */
-	if (!strncmp(q, "help=", 5)) {
-	  if (topic && egg_strcasecmp(q + 5, topic))
-	    blind |= 2;
-	  else
-	    blind &= ~2;
-	} else if (!(blind & 2)) {
-	  if (q[0] == '+') {
-	    struct flag_record fr =
-	    {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+        *current = 0;
+        current--;
+        q += 2;
+        /* Now q is the string and p is where the rest of the fcn expects */
+        if (!strncmp(q, "help=", 5)) {
+          if (topic && egg_strcasecmp(q + 5, topic))
+            blind |= 2;
+          else
+            blind &= ~2;
+        } else if (!(blind & 2)) {
+          if (q[0] == '+') {
+            struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
-	    break_down_flags(q + 1, &fr, NULL);
-	    if (!flagrec_ok(&fr, flags))
-	      blind |= 1;
-	    else
-	      blind &= ~1;
-	  } else if (q[0] == '-') {
-	    blind &= ~1;
-	  } else if (!egg_strcasecmp(q, "end")) {
-	    blind &= ~1;
-	    subwidth = 70;
-	    if (cols) {
-	      sub[0] = 0;
-	      subst_addcol(sub, "\377");
-	      nfree(colstr);
-	      colstr = NULL;
-	      cols = 0;
-	      towrite = sub;
-	    }
-	  } else if (!egg_strcasecmp(q, "center"))
-	    center = 1;
-	  else if (!strncmp(q, "cols=", 5)) {
-	    char *r;
+            break_down_flags(q + 1, &fr, NULL);
+            if (!flagrec_ok(&fr, flags))
+              blind |= 1;
+            else
+              blind &= ~1;
+          } else if (q[0] == '-')
+            blind &= ~1;
+          else if (!egg_strcasecmp(q, "end")) {
+            blind &= ~1;
+            subwidth = 70;
+            if (cols) {
+              sub[0] = 0;
+              subst_addcol(sub, "\377");
+              nfree(colstr);
+              colstr = NULL;
+              cols = 0;
+              towrite = sub;
+            }
+          } else if (!egg_strcasecmp(q, "center"))
+            center = 1;
+          else if (!strncmp(q, "cols=", 5)) {
+            char *r;
 
-	    cols = atoi(q + 5);
-	    colsofar = 0;
-	    colstr = (char *) nmalloc(1);
-	    colstr[0] = 0;
-	    r = strchr(q + 5, '/');
-	    if (r != NULL)
-	      subwidth = atoi(r + 1);
-	  }
-	}
+            cols = atoi(q + 5);
+            colsofar = 0;
+            colstr = (char *) nmalloc(1);
+            colstr[0] = 0;
+            r = strchr(q + 5, '/');
+            if (r != NULL)
+              subwidth = atoi(r + 1);
+          }
+        }
       } else
-	current = q;		/* no } so ignore */
+        current = q;            /* no } so ignore */
       break;
     default:
       if (!blind) {
-	*writeidx++ = chr;
-	if (writeidx >= (s + HELP_BUF_LEN)) {
-	  *writeidx = 0;
-	  return;
-	}
+        *writeidx++ = chr;
+        if (writeidx >= (s + HELP_BUF_LEN)) {
+          *writeidx = 0;
+          return;
+        }
       }
     }
     if (towrite && !blind) {
       if ((writeidx + strlen(towrite)) >= (s + HELP_BUF_LEN)) {
-	strncpy(writeidx, towrite, (s + HELP_BUF_LEN) - writeidx);
-	s[HELP_BUF_LEN] = 0;
-	return;
+        strncpy(writeidx, towrite, (s + HELP_BUF_LEN) - writeidx);
+        s[HELP_BUF_LEN] = 0;
+        return;
       }
       writeidx += my_strcpy(writeidx, towrite);
     }
@@ -998,7 +1000,7 @@ void help_subst(char *s, char *nick, struct flag_record *flags,
     if (i > 0) {
       s[0] = 0;
       for (j = 0; j < i; j++)
-	s[j] = ' ';
+        s[j] = ' ';
       strcpy(s + i, xx);
     }
   }
@@ -1019,22 +1021,22 @@ static void scan_help_file(struct help_ref *current, char *filename, int type)
     while (!feof(f)) {
       fgets(s, HELP_BUF_LEN, f);
       if (!feof(f)) {
-	p = s;
-	while ((q = strstr(p, "%{help="))) {
-	  q += 7;
-	  if ((p = strchr(q, '}'))) {
-	    *p = 0;
-	    list = nmalloc(sizeof(struct help_list_t));
+        p = s;
+        while ((q = strstr(p, "%{help="))) {
+          q += 7;
+          if ((p = strchr(q, '}'))) {
+            *p = 0;
+            list = nmalloc(sizeof(struct help_list_t));
 
-	    list->name = nmalloc(p - q + 1);
-	    strcpy(list->name, q);
-	    list->next = current->first;
-	    list->type = type;
-	    current->first = list;
-	    p++;
-	  } else
-	    p = "";
-	}
+            list->name = nmalloc(p - q + 1);
+            strcpy(list->name, q);
+            list->next = current->first;
+            list->type = type;
+            current->first = list;
+            p++;
+          } else
+            p = "";
+        }
       }
     }
     fclose(f);
@@ -1048,7 +1050,7 @@ void add_help_reference(char *file)
 
   for (current = help_list; current; current = current->next)
     if (!strcmp(current->name, file))
-      return;			/* Already exists, can't re-add :P */
+      return;                   /* Already exists, can't re-add :P */
   current = nmalloc(sizeof(struct help_ref));
 
   current->name = nmalloc(strlen(file) + 1);
@@ -1072,15 +1074,15 @@ void rem_help_reference(char *file)
   for (current = help_list; current; last = current, current = current->next)
     if (!strcmp(current->name, file)) {
       while ((item = current->first)) {
-	current->first = item->next;
-	nfree(item->name);
-	nfree(item);
+        current->first = item->next;
+        nfree(item->name);
+        nfree(item);
       }
       nfree(current->name);
       if (last)
-	last->next = current->next;
+        last->next = current->next;
       else
-	help_list = current->next;
+        help_list = current->next;
       nfree(current);
       return;
     }
@@ -1115,7 +1117,7 @@ void debug_help(int idx)
     dprintf(idx, "HELP FILE(S): %s\n", current->name);
     for (item = current->first; item; item = item->next) {
       dprintf(idx, "   %s (%s)\n", item->name, (item->type == 0) ? "msg/" :
-	      (item->type == 1) ? "" : "set/");
+              (item->type == 1) ? "" : "set/");
     }
   }
 }
@@ -1129,24 +1131,23 @@ FILE *resolve_help(int dcc, char *file)
   struct help_list_t *item;
 
   /* Somewhere here goes the eventual substituation */
-  if (!(dcc & HELP_TEXT))
-  {
+  if (!(dcc & HELP_TEXT)) {
     for (current = help_list; current; current = current->next)
       for (item = current->first; item; item = item->next)
-	if (!strcmp(item->name, file)) {
-	  if (!item->type && !dcc) {
-	    egg_snprintf(s, sizeof s, "%smsg/%s", helpdir, current->name);
-	    if ((f = fopen(s, "r")))
-	      return f;
-	  } else if (dcc && item->type) {
-	    if (item->type == 1)
-	      egg_snprintf(s, sizeof s, "%s%s", helpdir, current->name);
-	    else
-	      egg_snprintf(s, sizeof s, "%sset/%s", helpdir, current->name);
-	    if ((f = fopen(s, "r")))
-	      return f;
-	  }
-	}
+        if (!strcmp(item->name, file)) {
+          if (!item->type && !dcc) {
+            egg_snprintf(s, sizeof s, "%smsg/%s", helpdir, current->name);
+            if ((f = fopen(s, "r")))
+              return f;
+          } else if (dcc && item->type) {
+            if (item->type == 1)
+              egg_snprintf(s, sizeof s, "%s%s", helpdir, current->name);
+            else
+              egg_snprintf(s, sizeof s, "%sset/%s", helpdir, current->name);
+            if ((f = fopen(s, "r")))
+              return f;
+          }
+        }
     /* No match was found, so we better return NULL */
     return NULL;
   }
@@ -1165,19 +1166,19 @@ void showhelp(char *who, char *file, struct flag_record *flags, int fl)
   FILE *f = resolve_help(fl, file);
 
   if (f) {
-    help_subst(NULL, NULL, 0, HELP_IRC, NULL);	/* Clear flags */
+    help_subst(NULL, NULL, 0, HELP_IRC, NULL);  /* Clear flags */
     while (!feof(f)) {
       fgets(s, HELP_BUF_LEN, f);
       if (!feof(f)) {
-	if (s[strlen(s) - 1] == '\n')
-	  s[strlen(s) - 1] = 0;
-	if (!s[0])
-	  strcpy(s, " ");
-	help_subst(s, who, flags, 0, file);
-	if ((s[0]) && (strlen(s) > 1)) {
-	  dprintf(DP_HELP, "NOTICE %s :%s\n", who, s);
-	  lines++;
-	}
+        if (s[strlen(s) - 1] == '\n')
+          s[strlen(s) - 1] = 0;
+        if (!s[0])
+          strcpy(s, " ");
+        help_subst(s, who, flags, 0, file);
+        if ((s[0]) && (strlen(s) > 1)) {
+          dprintf(DP_HELP, "NOTICE %s :%s\n", who, s);
+          lines++;
+        }
       }
     }
     fclose(f);
@@ -1187,26 +1188,26 @@ void showhelp(char *who, char *file, struct flag_record *flags, int fl)
 }
 
 static int display_tellhelp(int idx, char *file, FILE *f,
-			    struct flag_record *flags)
+                            struct flag_record *flags)
 {
   char s[HELP_BUF_LEN + 1];
   int lines = 0;
 
   if (f) {
     help_subst(NULL, NULL, 0,
-	       (dcc[idx].status & STAT_TELNET) ? 0 : HELP_IRC, NULL);
+               (dcc[idx].status & STAT_TELNET) ? 0 : HELP_IRC, NULL);
     while (!feof(f)) {
       fgets(s, HELP_BUF_LEN, f);
       if (!feof(f)) {
-	if (s[strlen(s) - 1] == '\n')
-	  s[strlen(s) - 1] = 0;
-	if (!s[0])
-	  strcpy(s, " ");
-	help_subst(s, dcc[idx].nick, flags, 1, file);
-	if (s[0]) {
-	  dprintf(idx, "%s\n", s);
-	  lines++;
-	}
+        if (s[strlen(s) - 1] == '\n')
+          s[strlen(s) - 1] = 0;
+        if (!s[0])
+          strcpy(s, " ");
+        help_subst(s, dcc[idx].nick, flags, 1, file);
+        if (s[0]) {
+          dprintf(idx, "%s\n", s);
+          lines++;
+        }
       }
     }
     fclose(f);
@@ -1238,12 +1239,12 @@ void tellwildhelp(int idx, char *match, struct flag_record *flags)
   for (current = help_list; current; current = current->next)
     for (item = current->first; item; item = item->next)
       if (wild_match(match, item->name) && item->type) {
-	if (item->type == 1)
-	  egg_snprintf(s, sizeof s, "%s%s", helpdir, current->name);
-	else
-	  egg_snprintf(s, sizeof s, "%sset/%s", helpdir, current->name);
-	if ((f = fopen(s, "r")))
-	  display_tellhelp(idx, item->name, f, flags);
+        if (item->type == 1)
+          egg_snprintf(s, sizeof s, "%s%s", helpdir, current->name);
+        else
+          egg_snprintf(s, sizeof s, "%sset/%s", helpdir, current->name);
+        if ((f = fopen(s, "r")))
+          display_tellhelp(idx, item->name, f, flags);
       }
   if (!s[0])
     dprintf(idx, "%s\n", IRC_NOHELP2);
@@ -1263,12 +1264,12 @@ void tellallhelp(int idx, char *match, struct flag_record *flags)
     for (item = current->first; item; item = item->next)
       if (!strcmp(match, item->name) && item->type) {
 
-	if (item->type == 1)
-	  egg_snprintf(s, sizeof s, "%s%s", helpdir, current->name);
-	else
-	  egg_snprintf(s, sizeof s, "%sset/%s", helpdir, current->name);
-	if ((f = fopen(s, "r")))
-	  display_tellhelp(idx, item->name, f, flags);
+        if (item->type == 1)
+          egg_snprintf(s, sizeof s, "%s%s", helpdir, current->name);
+        else
+          egg_snprintf(s, sizeof s, "%sset/%s", helpdir, current->name);
+        if ((f = fopen(s, "r")))
+          display_tellhelp(idx, item->name, f, flags);
       }
   if (!s[0])
     dprintf(idx, "%s\n", IRC_NOHELP2);
@@ -1279,11 +1280,11 @@ void tellallhelp(int idx, char *match, struct flag_record *flags)
 void sub_lang(int idx, char *text)
 {
   char s[1024];
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   get_user_flagrec(dcc[idx].user, &fr, dcc[idx].u.chat->con_chan);
   help_subst(NULL, NULL, 0,
-	     (dcc[idx].status & STAT_TELNET) ? 0 : HELP_IRC, NULL);
+             (dcc[idx].status & STAT_TELNET) ? 0 : HELP_IRC, NULL);
   strncpyz(s, text, sizeof s);
   if (s[strlen(s) - 1] == '\n')
     s[strlen(s) - 1] = 0;
@@ -1301,6 +1302,7 @@ void sub_lang(int idx, char *text)
 char *extracthostname(char *hostmask)
 {
   char *p = strrchr(hostmask, '@');
+
   return p ? p + 1 : "";
 }
 
@@ -1310,7 +1312,7 @@ void show_motd(int idx)
 {
   FILE *vv;
   char s[1024];
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   if (!is_file(motdfile))
     return;
@@ -1323,17 +1325,17 @@ void show_motd(int idx)
   dprintf(idx, "\n");
   /* reset the help_subst variables to their defaults */
   help_subst(NULL, NULL, 0,
-	     (dcc[idx].status & STAT_TELNET) ? 0 : HELP_IRC, NULL);
+             (dcc[idx].status & STAT_TELNET) ? 0 : HELP_IRC, NULL);
   while (!feof(vv)) {
     fgets(s, 120, vv);
     if (!feof(vv)) {
       if (s[strlen(s) - 1] == '\n')
-	s[strlen(s) - 1] = 0;
+        s[strlen(s) - 1] = 0;
       if (!s[0])
-	strcpy(s, " ");
+        strcpy(s, " ");
       help_subst(s, dcc[idx].nick, &fr, 1, botnetnick);
       if (s[0])
-	dprintf(idx, "%s\n", s);
+        dprintf(idx, "%s\n", s);
     }
   }
   fclose(vv);
@@ -1342,10 +1344,11 @@ void show_motd(int idx)
 
 /* Show banner to telnet user 
  */
-void show_banner(int idx) {
+void show_banner(int idx)
+{
   FILE *vv;
   char s[1024];
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   if (!is_file(bannerfile))
     return;
@@ -1354,14 +1357,14 @@ void show_banner(int idx) {
   if (!vv)
     return;
 
-  get_user_flagrec(dcc[idx].user, &fr,dcc[idx].u.chat->con_chan);
+  get_user_flagrec(dcc[idx].user, &fr, dcc[idx].u.chat->con_chan);
   /* reset the help_subst variables to their defaults */
   help_subst(NULL, NULL, 0, 0, NULL);
-  while(!feof(vv)) {
+  while (!feof(vv)) {
     fgets(s, 120, vv);
     if (!feof(vv)) {
       if (!s[0])
-	strcpy(s, " \n");
+        strcpy(s, " \n");
       help_subst(s, dcc[idx].nick, &fr, 0, botnetnick);
       dprintf(idx, "%s", s);
     }
@@ -1408,10 +1411,10 @@ int oatoi(const char *octal)
  */
 char *str_escape(const char *str, const char div, const char mask)
 {
-  const int	 len = strlen(str);
-  int		 buflen = (2 * len), blen = 0;
-  char		*buf = nmalloc(buflen + 1), *b = buf;
-  const char	*s;
+  const int len = strlen(str);
+  int buflen = (2 * len), blen = 0;
+  char *buf = nmalloc(buflen + 1), *b = buf;
+  const char *s;
 
   if (!buf)
     return NULL;
@@ -1421,7 +1424,7 @@ char *str_escape(const char *str, const char div, const char mask)
       buflen = (buflen * 2);
       buf = nrealloc(buf, buflen + 1);
       if (!buf)
-	return NULL;
+        return NULL;
       b = buf + blen;
     }
 
@@ -1457,19 +1460,19 @@ char *str_escape(const char *str, const char div, const char mask)
  */
 char *strchr_unescape(char *str, const char div, register const char esc_char)
 {
-  char		 buf[3];
-  register char	*s, *p;
+  char buf[3];
+  register char *s, *p;
 
-  buf[3] = 0;
+  buf[2] = 0;
   for (s = p = str; *s; s++, p++) {
-    if (*s == esc_char) {	/* Found escape character.		*/
+    if (*s == esc_char) {       /* Found escape character.              */
       /* Convert code to character. */
       buf[0] = s[1], buf[1] = s[2];
       *p = (unsigned char) strtol(buf, NULL, 16);
       s += 2;
     } else if (*s == div) {
       *p = *s = 0;
-      return (s + 1);		/* Found searched for character.	*/
+      return (s + 1);           /* Found searched for character.        */
     } else
       *p = *s;
   }
