@@ -3,10 +3,10 @@
  *   saved console settings based on console.tcl
  *   by cmwagner/billyjoe/D. Senso
  *
- * $Id: console.c,v 1.22 2002/01/02 03:46:38 guppy Exp $
+ * $Id: console.c,v 1.29 2003/02/27 10:18:40 tothwolf Exp $
  */
 /*
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -79,9 +79,9 @@ static int console_pack(struct userrec *u, struct user_entry *e)
   ci = (struct console_info *) e->u.extra;
 
   l = simple_sprintf(work, "%s %s %s %d %d %d",
-		     ci->channel, masktype(ci->conflags),
-		     stripmasktype(ci->stripflags), ci->echoflags,
-		     ci->page, ci->conchan);
+                     ci->channel, masktype(ci->conflags),
+                     stripmasktype(ci->stripflags), ci->echoflags,
+                     ci->page, ci->conchan);
 
   e->u.list = user_malloc(sizeof(struct list_type));
   e->u.list->next = NULL;
@@ -104,14 +104,14 @@ static int console_kill(struct user_entry *e)
 }
 
 static int console_write_userfile(FILE *f, struct userrec *u,
-				  struct user_entry *e)
+                                  struct user_entry *e)
 {
   struct console_info *i = e->u.extra;
 
   if (fprintf(f, "--CONSOLE %s %s %s %d %d %d\n",
-	      i->channel, masktype(i->conflags),
-	      stripmasktype(i->stripflags), i->echoflags,
-	      i->page, i->conchan) == EOF)
+              i->channel, masktype(i->conflags),
+              stripmasktype(i->stripflags), i->echoflags,
+              i->page, i->conchan) == EOF)
     return 0;
   return 1;
 }
@@ -136,26 +136,27 @@ static int console_set(struct userrec *u, struct user_entry *e, void *buf)
 }
 
 static int console_tcl_get(Tcl_Interp *irp, struct userrec *u,
-			   struct user_entry *e, int argc, char **argv)
+                           struct user_entry *e, int argc, char **argv)
 {
   char work[1024];
   struct console_info *i = e->u.extra;
 
   simple_sprintf(work, "%s %s %s %d %d %d",
-		 i->channel, masktype(i->conflags),
-		 stripmasktype(i->stripflags), i->echoflags,
-		 i->page, i->conchan);
+                 i->channel, masktype(i->conflags),
+                 stripmasktype(i->stripflags), i->echoflags,
+                 i->page, i->conchan);
   Tcl_AppendResult(irp, work, NULL);
   return TCL_OK;
 }
 
 static int console_tcl_set(Tcl_Interp *irp, struct userrec *u,
-		    struct user_entry *e, int argc, char **argv)
+                           struct user_entry *e, int argc, char **argv)
 {
   struct console_info *i = e->u.extra;
   int l;
 
   BADARGS(4, 9, " handle CONSOLE channel flags strip echo page conchan");
+
   if (!i) {
     i = user_malloc(sizeof(struct console_info));
     egg_bzero(i, sizeof(struct console_info));
@@ -173,12 +174,12 @@ static int console_tcl_set(Tcl_Interp *irp, struct userrec *u,
     if (argc > 5) {
       i->stripflags = stripmodes(argv[5]);
       if (argc > 6) {
-	i->echoflags = (argv[6][0] == '1') ? 1 : 0;
-	if (argc > 7) {
-	  i->page = atoi(argv[7]);
-	  if (argc > 8)
-	    i->conchan = atoi(argv[8]);
-	}
+        i->echoflags = (argv[6][0] == '1') ? 1 : 0;
+        if (argc > 7) {
+          i->page = atoi(argv[7]);
+          if (argc > 8)
+            i->conchan = atoi(argv[8]);
+        }
       }
     }
   }
@@ -201,17 +202,17 @@ static void console_display(int idx, struct user_entry *e)
     dprintf(idx, "  %s\n", CONSOLE_SAVED_SETTINGS);
     dprintf(idx, "    %s %s\n", CONSOLE_CHANNEL, i->channel);
     dprintf(idx, "    %s %s, %s %s, %s %s\n", CONSOLE_FLAGS,
-    	masktype(i->conflags), CONSOLE_STRIPFLAGS,
-	    stripmasktype(i->stripflags), CONSOLE_ECHO,
-	    i->echoflags ? CONSOLE_YES : CONSOLE_NO);
+            masktype(i->conflags), CONSOLE_STRIPFLAGS,
+            stripmasktype(i->stripflags), CONSOLE_ECHO,
+            i->echoflags ? CONSOLE_YES : CONSOLE_NO);
     dprintf(idx, "    %s %d, %s %s%d\n", CONSOLE_PAGE_SETTING, i->page,
-            CONSOLE_CHANNEL2, (i->conchan < 100000) ? "" : "*",
-            i->conchan % 100000);
+            CONSOLE_CHANNEL2, (i->conchan < GLOBAL_CHANS) ? "" : "*",
+            i->conchan % GLOBAL_CHANS);
   }
 }
 
 static int console_dupuser(struct userrec *new, struct userrec *old,
-			   struct user_entry *e)
+                           struct user_entry *e)
 {
   struct console_info *i = e->u.extra, *j;
 
@@ -223,9 +224,8 @@ static int console_dupuser(struct userrec *new, struct userrec *old,
   return set_user(e->type, new, j);
 }
 
-static struct user_entry_type USERENTRY_CONSOLE =
-{
-  NULL,				/* always 0 ;) */
+static struct user_entry_type USERENTRY_CONSOLE = {
+  NULL,                         /* always 0 ;) */
   NULL,
   console_dupuser,
   console_unpack,
@@ -248,41 +248,40 @@ static int console_chon(char *handle, int idx)
   if (dcc[idx].type == &DCC_CHAT) {
     if (i) {
       if (i->channel && i->channel[0])
-	strcpy(dcc[idx].u.chat->con_chan, i->channel);
+        strcpy(dcc[idx].u.chat->con_chan, i->channel);
       dcc[idx].u.chat->con_flags = i->conflags;
       dcc[idx].u.chat->strip_flags = i->stripflags;
       if (i->echoflags)
-	dcc[idx].status |= STAT_ECHO;
+        dcc[idx].status |= STAT_ECHO;
       else
-	dcc[idx].status &= ~STAT_ECHO;
+        dcc[idx].status &= ~STAT_ECHO;
       if (i->page) {
-	dcc[idx].status |= STAT_PAGE;
-	dcc[idx].u.chat->max_line = i->page;
-	if (!dcc[idx].u.chat->line_count)
-	  dcc[idx].u.chat->current_lines = 0;
+        dcc[idx].status |= STAT_PAGE;
+        dcc[idx].u.chat->max_line = i->page;
+        if (!dcc[idx].u.chat->line_count)
+          dcc[idx].u.chat->current_lines = 0;
       }
       dcc[idx].u.chat->channel = i->conchan;
     } else if (force_channel > -1)
       dcc[idx].u.chat->channel = force_channel;
     if ((dcc[idx].u.chat->channel >= 0) &&
-	(dcc[idx].u.chat->channel < GLOBAL_CHANS)) {
+        (dcc[idx].u.chat->channel < GLOBAL_CHANS)) {
       botnet_send_join_idx(idx, -1);
       check_tcl_chjn(botnetnick, dcc[idx].nick, dcc[idx].u.chat->channel,
-		     geticon(idx), dcc[idx].sock, dcc[idx].host);
+                     geticon(idx), dcc[idx].sock, dcc[idx].host);
     }
     if (info_party) {
       char *p = get_user(&USERENTRY_INFO, dcc[idx].user);
 
       if (p) {
-	if (dcc[idx].u.chat->channel >= 0) {
-	    char x[1024];
+        if (dcc[idx].u.chat->channel >= 0) {
+          char x[1024];
 
-	    chanout_but(-1, dcc[idx].u.chat->channel,
-			"*** [%s] %s\n", dcc[idx].nick, p);
-	    simple_sprintf(x, "[%s] %s", dcc[idx].nick, p);
-	    botnet_send_chan(-1, botnetnick, NULL,
-			     dcc[idx].u.chat->channel, x);
-	}
+          chanout_but(-1, dcc[idx].u.chat->channel,
+                      "*** [%s] %s\n", dcc[idx].nick, p);
+          simple_sprintf(x, "[%s] %s", dcc[idx].nick, p);
+          botnet_send_chan(-1, botnetnick, NULL, dcc[idx].u.chat->channel, x);
+        }
       }
     }
   }
@@ -311,11 +310,11 @@ static int console_store(struct userrec *u, int idx, char *par)
   i->conchan = dcc[idx].u.chat->channel;
   if (par) {
     dprintf(idx, "%s\n", CONSOLE_SAVED_SETTINGS2);
-    dprintf(idx, "  %s %s\n", i->channel, CONSOLE_CHANNEL);
+    dprintf(idx, "  %s %s\n", CONSOLE_CHANNEL, i->channel);
     dprintf(idx, "  %s %s, %s %s, %s %s\n", CONSOLE_FLAGS,
-	    masktype(i->conflags), CONSOLE_STRIPFLAGS,
-	    stripmasktype(i->stripflags), CONSOLE_ECHO,
-	    i->echoflags ? CONSOLE_YES : CONSOLE_NO);
+            masktype(i->conflags), CONSOLE_STRIPFLAGS,
+            stripmasktype(i->stripflags), CONSOLE_ECHO,
+            i->echoflags ? CONSOLE_YES : CONSOLE_NO);
     dprintf(idx, "  %s %d, %s %d\n", CONSOLE_PAGE_SETTING, i->page,
             CONSOLE_CHANNEL2, i->conchan);
   }
@@ -331,24 +330,21 @@ static int console_dostore(int idx)
   return 0;
 }
 
-static tcl_ints myints[] =
-{
-  {"console-autosave",	&console_autosave,	0},
-  {"force-channel",	&force_channel,		0},
-  {"info-party",	&info_party,		0},
-  {NULL,		NULL,			0}
+static tcl_ints myints[] = {
+  {"console-autosave", &console_autosave, 0},
+  {"force-channel",    &force_channel,    0},
+  {"info-party",       &info_party,       0},
+  {NULL,               NULL,              0}
 };
 
-static cmd_t mychon[] =
-{
-  {"*",		"",	console_chon,		"console:chon"},
-  {NULL,	NULL,	NULL,			NULL}
+static cmd_t mychon[] = {
+  {"*",  "",   console_chon, "console:chon"},
+  {NULL, NULL, NULL,                   NULL}
 };
 
-static cmd_t mydcc[] =
-{
-  {"store",	"",	console_store,		NULL},
-  {NULL,	NULL,	NULL,			NULL}
+static cmd_t mydcc[] = {
+  {"store", "",   console_store, NULL},
+  {NULL,    NULL, NULL,          NULL}
 };
 
 static char *console_close()
@@ -365,8 +361,7 @@ static char *console_close()
 
 EXPORT_SCOPE char *console_start();
 
-static Function console_table[] =
-{
+static Function console_table[] = {
   (Function) console_start,
   (Function) console_close,
   (Function) NULL,
@@ -374,14 +369,14 @@ static Function console_table[] =
   (Function) console_dostore,
 };
 
-char *console_start(Function * global_funcs)
+char *console_start(Function *global_funcs)
 {
   global = global_funcs;
 
   module_register(MODULE_NAME, console_table, 1, 1);
   if (!module_depend(MODULE_NAME, "eggdrop", 106, 0)) {
     module_undepend(MODULE_NAME);
-    return "This module requires eggdrop1.6.0 or later";
+    return "This module requires Eggdrop 1.6.0 or later.";
   }
   add_builtins(H_chon, mychon);
   add_builtins(H_dcc, mydcc);
