@@ -4,11 +4,11 @@
  *
  * Rewritten by Fabian Knittel <fknittel@gmx.de>
  *
- * $Id: filedb3.c,v 1.21 2002/01/02 03:55:20 guppy Exp $
+ * $Id: filedb3.c,v 1.27 2003/03/12 08:42:00 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -76,7 +76,7 @@ static int count = 0;
 
 /* Frees a filedb entry and all it's elements.
  */
-static void free_fdbe(filedb_entry **fdbe)
+static void free_fdbe(filedb_entry ** fdbe)
 {
   if (!fdbe || !*fdbe)
     return;
@@ -105,7 +105,7 @@ static filedb_entry *_malloc_fdbe(char *file, int line)
   /* This is a hack to access the nmalloc function with
    * special file and line information
    */
-  fdbe = ((void *) (global[0] (sizeof(filedb_entry), MODULE_NAME, file, line)));
+  fdbe = (((void *(*)())global[0])(sizeof(filedb_entry),MODULE_NAME,file,line));
 #else
   fdbe = nmalloc(sizeof(filedb_entry));
 #endif
@@ -137,7 +137,7 @@ static void lockfile(FILE *fdb)
 
 /* Unlocks the file using fcntl.
  */
-static void unlockfile(FILE * f)
+static void unlockfile(FILE *f)
 {
   struct flock fl;
 
@@ -186,10 +186,10 @@ static int filedb_delfile(FILE *fdb, long pos)
 {
   filedb_header fdh;
 
-  fseek(fdb, pos, SEEK_SET);			/* Go to start of entry	*/
+  fseek(fdb, pos, SEEK_SET);    /* Go to start of entry */
   if (feof(fdb))
     return 0;
-  fread(&fdh, 1, sizeof(filedb_header), fdb);	/* Read header		*/
+  fread(&fdh, 1, sizeof(filedb_header), fdb);   /* Read header          */
   fdh.stat = FILE_UNUSED;
 
   /* Assign all available space to buffer. Simplifies
@@ -198,8 +198,8 @@ static int filedb_delfile(FILE *fdb, long pos)
   fdh.buffer_len += filedb_tot_dynspace(fdh);
   filedb_zero_dynspace(fdh);
 
-  fseek(fdb, pos, SEEK_SET);			/* Go back to start	*/
-  fwrite(&fdh, 1, sizeof(filedb_header), fdb);	/* Write new header	*/
+  fseek(fdb, pos, SEEK_SET);    /* Go back to start     */
+  fwrite(&fdh, 1, sizeof(filedb_header), fdb);  /* Write new header     */
   return 1;
 }
 
@@ -229,20 +229,20 @@ static filedb_entry *filedb_findempty(FILE *fdb, int tot)
        * more efficiently.
        */
       if (fdbe->buf_len > (tot + sizeof(filedb_header) + FILEDB_ESTDYN)) {
-	filedb_entry *fdbe_oe;
+        filedb_entry *fdbe_oe;
 
-	/* Create new entry containing the additional space */
-	fdbe_oe = malloc_fdbe();
-	fdbe_oe->stat = FILE_UNUSED;
-	fdbe_oe->pos = fdbe->pos + sizeof(filedb_header) + tot;
-	fdbe_oe->buf_len = fdbe->buf_len - tot - sizeof(filedb_header);
-	filedb_movefile(fdb, fdbe_oe->pos, fdbe_oe);
-	free_fdbe(&fdbe_oe);
+        /* Create new entry containing the additional space */
+        fdbe_oe = malloc_fdbe();
+        fdbe_oe->stat = FILE_UNUSED;
+        fdbe_oe->pos = fdbe->pos + sizeof(filedb_header) + tot;
+        fdbe_oe->buf_len = fdbe->buf_len - tot - sizeof(filedb_header);
+        filedb_movefile(fdb, fdbe_oe->pos, fdbe_oe);
+        free_fdbe(&fdbe_oe);
 
-	/* Cut down buf_len of entry as the rest is now used in the new
-	 * entry.
-	 */
-	fdbe->buf_len = tot;
+        /* Cut down buf_len of entry as the rest is now used in the new
+         * entry.
+         */
+        fdbe->buf_len = tot;
       }
       return fdbe;
     }
@@ -272,7 +272,7 @@ static filedb_entry *filedb_findempty(FILE *fdb, int tot)
  * entry.
  */
 static int _filedb_updatefile(FILE *fdb, long pos, filedb_entry *fdbe,
-			      int update, char *file, int line)
+                              int update, char *file, int line)
 {
   filedb_header fdh;
   int reposition = 0;
@@ -301,9 +301,9 @@ static int _filedb_updatefile(FILE *fdb, long pos, filedb_entry *fdbe,
   if (fdbe->sharelink)
     fdh.sharelink_len = strlen(fdbe->sharelink) + 1;
 
-  odyntot = fdbe->dyn_len;		/* Old length of dynamic data	*/
-  obuftot = fdbe->buf_len;		/* Old length of spare space	*/
-  ndyntot = filedb_tot_dynspace(fdh);	/* New length of dynamic data	*/
+  odyntot = fdbe->dyn_len;      /* Old length of dynamic data   */
+  obuftot = fdbe->buf_len;      /* Old length of spare space    */
+  ndyntot = filedb_tot_dynspace(fdh);   /* New length of dynamic data   */
   nbuftot = obuftot;
 
   if (fdbe->_type == TYPE_EXIST) {
@@ -322,24 +322,24 @@ static int _filedb_updatefile(FILE *fdb, long pos, filedb_entry *fdbe,
     } else {
       /* If we have a given/preferred position */
       if ((pos != POS_NEW) &&
-	 /* and if our new size is smaller than the old size, we
-	  * just adjust the buffer length and still use the same
-	  * position
-	  */
+          /* and if our new size is smaller than the old size, we
+           * just adjust the buffer length and still use the same
+           * position
+           */
           (ndyntot <= (odyntot + obuftot))) {
-	nbuftot = (odyntot + obuftot) - ndyntot;
+        nbuftot = (odyntot + obuftot) - ndyntot;
       } else {
-	/* If we have an existing position, but the new entry doesn't
-	 * fit into it's old home, we need to delete it before
-	 * repositioning.
-	 */
-	if (pos != POS_NEW)
+        /* If we have an existing position, but the new entry doesn't
+         * fit into it's old home, we need to delete it before
+         * repositioning.
+         */
+        if (pos != POS_NEW)
           filedb_delfile(fdb, pos);
-	reposition = 1;
+        reposition = 1;
       }
     }
   } else {
-    fdbe->_type = TYPE_EXIST;		/* Update type			*/
+    fdbe->_type = TYPE_EXIST;   /* Update type                  */
     reposition = 1;
   }
 
@@ -384,15 +384,15 @@ static int _filedb_updatefile(FILE *fdb, long pos, filedb_entry *fdbe,
     if (fdbe->sharelink)
       fwrite(fdbe->sharelink, 1, fdh.sharelink_len, fdb);
   } else
-    fseek(fdb, ndyntot, SEEK_CUR);	/* Skip over dynamic data */
-  fseek(fdb, nbuftot, SEEK_CUR);	/* Skip over buffer	  */
+    fseek(fdb, ndyntot, SEEK_CUR);      /* Skip over dynamic data */
+  fseek(fdb, nbuftot, SEEK_CUR);        /* Skip over buffer       */
   return 0;
 }
 
 /* Moves an existing file entry, saved in fdbe to a new position.
  */
 static int _filedb_movefile(FILE *fdb, long pos, filedb_entry *fdbe,
-			    char *file, int line)
+                            char *file, int line)
 {
   fdbe->_type = TYPE_EXIST;
   _filedb_updatefile(fdb, pos, fdbe, UPDATE_ALL, file, line);
@@ -411,12 +411,12 @@ static int _filedb_addfile(FILE *fdb, filedb_entry *fdbe, char *file, int line)
 /* Short-cut macro to read an entry from disc to memory. Only
  * useful for filedb_getfile().
  */
-#define filedb_read(fdb, entry, len)	\
-{					\
-  if ((len) > 0) {			\
-    (entry) = nmalloc((len));		\
-    fread((entry), 1, (len), (fdb));	\
-  }					\
+#define filedb_read(fdb, entry, len)    \
+{                                       \
+  if ((len) > 0) {                      \
+    (entry) = nmalloc((len));           \
+    fread((entry), 1, (len), (fdb));    \
+  }                                     \
 }
 
 /* Reads an entry from the fildb at the specified position. The
@@ -425,7 +425,7 @@ static int _filedb_addfile(FILE *fdb, filedb_entry *fdbe, char *file, int line)
  * the entry.
  */
 static filedb_entry *_filedb_getfile(FILE *fdb, long pos, int get,
-				     char *file, int line)
+                                     char *file, int line)
 {
   filedb_entry *fdbe;
   filedb_header fdh;
@@ -447,8 +447,8 @@ static filedb_entry *_filedb_getfile(FILE *fdb, long pos, int get,
 
   fdbe->buf_len = fdh.buffer_len;
   fdbe->dyn_len = filedb_tot_dynspace(fdh);
-  fdbe->pos = pos;			/* Save position		*/
-  fdbe->_type = TYPE_EXIST;		/* Entry exists in DB		*/
+  fdbe->pos = pos;              /* Save position                */
+  fdbe->_type = TYPE_EXIST;     /* Entry exists in DB           */
 
   /* This is useful for cases where we don't read the rest of the
    * data, but need to know whether the file is a link.
@@ -472,29 +472,27 @@ static filedb_entry *_filedb_getfile(FILE *fdb, long pos, int get,
     filedb_read(fdb, fdbe->flags_req, fdh.flags_req_len);
     filedb_read(fdb, fdbe->sharelink, fdh.sharelink_len);
   }
-  fseek(fdb, fdh.buffer_len, SEEK_CUR);	/* Skip buffer			*/
-  return fdbe;				/* Return the ready structure	*/
+  fseek(fdb, fdh.buffer_len, SEEK_CUR); /* Skip buffer                  */
+  return fdbe;                  /* Return the ready structure   */
 }
 
 /* Searches the filedb for a file matching the specified mask, starting
  * at position 'pos'. The first matching file is returned.
  */
 static filedb_entry *_filedb_matchfile(FILE *fdb, long pos, char *match,
-				       char *file, int line)
+                                       char *file, int line)
 {
   filedb_entry *fdbe = NULL;
 
   fseek(fdb, pos, SEEK_SET);
-  while (!feof(fdb))
-  {
+  while (!feof(fdb)) {
     pos = ftell(fdb);
     fdbe = filedb_getfile(fdb, pos, GET_FILENAME);
     if (fdbe) {
-      if (!(fdbe->stat & FILE_UNUSED) &&	    /* Not unused?	   */
-	  wild_match_file(match, fdbe->filename)) { /* Matches our mask?   */
+      if (!(fdbe->stat & FILE_UNUSED) &&        /* Not unused?         */
+          wild_match_file(match, fdbe->filename)) {     /* Matches our mask?   */
         free_fdbe(&fdbe);
-        fdbe = _filedb_getfile(fdb, pos, GET_FULL,
-			       file, line);	    /* Save all data now   */
+        fdbe = _filedb_getfile(fdb, pos, GET_FULL, file, line); /* Save all data now   */
         return fdbe;
       }
       free_fdbe(&fdbe);
@@ -511,35 +509,34 @@ static void filedb_cleanup(FILE *fdb)
   long oldpos, newpos, temppos;
   filedb_entry *fdbe = NULL;
 
-  filedb_readtop(fdb, NULL);				/* Skip DB header  */
+  filedb_readtop(fdb, NULL);    /* Skip DB header  */
   newpos = temppos = oldpos = ftell(fdb);
-  fseek(fdb, oldpos, SEEK_SET);				/* Go to beginning */
-  while (!feof(fdb))					/* Loop until EOF  */
-  {
-    fdbe = filedb_getfile(fdb, oldpos, GET_HEADER);	/* Read header	   */
+  fseek(fdb, oldpos, SEEK_SET); /* Go to beginning */
+  while (!feof(fdb)) {          /* Loop until EOF  */
+    fdbe = filedb_getfile(fdb, oldpos, GET_HEADER);     /* Read header     */
     if (fdbe) {
-      if (fdbe->stat & FILE_UNUSED) {			/* Found dirt!	   */
+      if (fdbe->stat & FILE_UNUSED) {   /* Found dirt!     */
         free_fdbe(&fdbe);
-	while (!feof(fdb)) {				/* Loop until EOF  */
-	  newpos = ftell(fdb);
-	  fdbe = filedb_getfile(fdb, newpos, GET_FULL);	/* Read next entry */
-	  if (!fdbe)
-	    break;
-	  if (!(fdbe->stat & FILE_UNUSED)) {		/* Not unused?	   */
-	    temppos = ftell(fdb);
-	    filedb_movefile(fdb, oldpos, fdbe);		/* Move to top	   */
-	    oldpos = ftell(fdb);
-	    fseek(fdb, temppos, SEEK_SET);
-	  }
-	  free_fdbe(&fdbe);
-	}
+        while (!feof(fdb)) {    /* Loop until EOF  */
+          newpos = ftell(fdb);
+          fdbe = filedb_getfile(fdb, newpos, GET_FULL); /* Read next entry */
+          if (!fdbe)
+            break;
+          if (!(fdbe->stat & FILE_UNUSED)) {    /* Not unused?     */
+            temppos = ftell(fdb);
+            filedb_movefile(fdb, oldpos, fdbe); /* Move to top     */
+            oldpos = ftell(fdb);
+            fseek(fdb, temppos, SEEK_SET);
+          }
+          free_fdbe(&fdbe);
+        }
       } else {
         free_fdbe(&fdbe);
-	oldpos = ftell(fdb);
+        oldpos = ftell(fdb);
       }
     }
   }
-  ftruncate(fileno(fdb), oldpos);			/* Shorten file	   */
+  ftruncate(fileno(fdb), oldpos);       /* Shorten file    */
 }
 
 /* Merges empty entries to one big entry, if they directly
@@ -553,41 +550,40 @@ static void filedb_mergeempty(FILE *fdb)
   int modified;
 
   filedb_readtop(fdb, NULL);
-  while (!feof(fdb))
-  {
+  while (!feof(fdb)) {
     fdbe_t = filedb_getfile(fdb, ftell(fdb), GET_HEADER);
     if (fdbe_t) {
       if (fdbe_t->stat & FILE_UNUSED) {
-	modified = 0;
-	fdbe_i = filedb_getfile(fdb, ftell(fdb), GET_HEADER);
-	while (fdbe_i) {
-	  /* Is this entry in use? */
-	  if (!(fdbe_i->stat & FILE_UNUSED))
-	    break;	/* It is, exit loop. */
+        modified = 0;
+        fdbe_i = filedb_getfile(fdb, ftell(fdb), GET_HEADER);
+        while (fdbe_i) {
+          /* Is this entry in use? */
+          if (!(fdbe_i->stat & FILE_UNUSED))
+            break;              /* It is, exit loop. */
 
-	  /* Woohoo, found an empty entry. Append it's space to
-	   * our target entry's buffer space.
-	   */
-	  fdbe_t->buf_len += sizeof(filedb_header) + fdbe_i->buf_len;
-	  modified++;
-	  free_fdbe(&fdbe_i);
-	  /* Get next file entry */
-	  fdbe_i = filedb_getfile(fdb, ftell(fdb), GET_HEADER);
-	}
+          /* Woohoo, found an empty entry. Append it's space to
+           * our target entry's buffer space.
+           */
+          fdbe_t->buf_len += sizeof(filedb_header) + fdbe_i->buf_len;
+          modified++;
+          free_fdbe(&fdbe_i);
+          /* Get next file entry */
+          fdbe_i = filedb_getfile(fdb, ftell(fdb), GET_HEADER);
+        }
 
-	/* Did we exit the loop because of a used entry? */
-	if (fdbe_i) {
-	  free_fdbe(&fdbe_i);
-	  /* Did we find any empty entries before? */
-	  if (modified)
-	    filedb_updatefile(fdb, fdbe_t->pos, fdbe_t, UPDATE_SIZE);
-	/* ... or because we hit EOF? */
-	} else {
-	  /* Truncate trailing empty entries and exit. */
-	  ftruncate(fileno(fdb), fdbe_t->pos);
-	  free_fdbe(&fdbe_t);
-	  return;
-	}
+        /* Did we exit the loop because of a used entry? */
+        if (fdbe_i) {
+          free_fdbe(&fdbe_i);
+          /* Did we find any empty entries before? */
+          if (modified)
+            filedb_updatefile(fdb, fdbe_t->pos, fdbe_t, UPDATE_SIZE);
+          /* ... or because we hit EOF? */
+        } else {
+          /* Truncate trailing empty entries and exit. */
+          ftruncate(fileno(fdb), fdbe_t->pos);
+          free_fdbe(&fdbe_t);
+          return;
+        }
       }
       free_fdbe(&fdbe_t);
     }
@@ -622,7 +618,7 @@ static void filedb_initdb(FILE *fdb)
   filedb_writetop(fdb, &fdbt);
 }
 
-static void filedb_timestamp(FILE * fdb)
+static void filedb_timestamp(FILE *fdb)
 {
   filedb_top fdbt;
 
@@ -665,19 +661,19 @@ static void filedb_update(char *path, FILE *fdb, int sort)
       filedb_readtop(fdb, NULL);
       fdbe = filedb_matchfile(fdb, ftell(fdb), name);
       if (!fdbe) {
-	/* new file! */
-	fdbe = malloc_fdbe();
-	malloc_strcpy(fdbe->filename, name);
-	malloc_strcpy(fdbe->uploader, botnetnick);
-	fdbe->uploaded = now;
-	fdbe->size = st.st_size;
-	if (S_ISDIR(st.st_mode))
-	  fdbe->stat |= FILE_DIR;
-	filedb_addfile(fdb, fdbe);
+        /* new file! */
+        fdbe = malloc_fdbe();
+        malloc_strcpy(fdbe->filename, name);
+        malloc_strcpy(fdbe->uploader, botnetnick);
+        fdbe->uploaded = now;
+        fdbe->size = st.st_size;
+        if (S_ISDIR(st.st_mode))
+          fdbe->stat |= FILE_DIR;
+        filedb_addfile(fdb, fdbe);
       } else if (fdbe->size != st.st_size) {
-	/* update size if needed */
-	fdbe->size = st.st_size;
-	filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_HEADER);
+        /* update size if needed */
+        fdbe->size = st.st_size;
+        filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_HEADER);
       }
       free_fdbe(&fdbe);
     }
@@ -695,12 +691,12 @@ static void filedb_update(char *path, FILE *fdb, int sort)
   while (fdbe) {
     where = ftell(fdb);
     if (!(fdbe->stat & FILE_UNUSED) && !(fdbe->stat & FILE_ISLINK) &&
-	fdbe->filename) {
+        fdbe->filename) {
       s = nmalloc(strlen(path) + 1 + strlen(fdbe->filename) + 1);
       sprintf(s, "%s/%s", path, fdbe->filename);
       if (stat(s, &st) != 0)
-	/* gone file */
-	filedb_delfile(fdb, fdbe->pos);
+        /* gone file */
+        filedb_delfile(fdb, fdbe->pos);
       my_free(s);
     }
     free_fdbe(&fdbe);
@@ -714,8 +710,8 @@ static void filedb_update(char *path, FILE *fdb, int sort)
    * done on-the-fly when we display the file list.
    */
   if (sort)
-    filedb_cleanup(fdb);			/* Cleanup DB		*/
-  filedb_timestamp(fdb);			/* Write new timestamp	*/
+    filedb_cleanup(fdb);        /* Cleanup DB           */
+  filedb_timestamp(fdb);        /* Write new timestamp  */
 }
 
 /* Converts all slashes to dots. Returns an allocated buffer, so
@@ -723,16 +719,16 @@ static void filedb_update(char *path, FILE *fdb, int sort)
  */
 static char *make_point_path(char *path)
 {
-    char *s2 = NULL, *p = NULL;
+  char *s2 = NULL, *p = NULL;
 
-    malloc_strcpy(s2, path);
-    if (s2[strlen(s2) - 1] == '/')
-      s2[strlen(s2) - 1] = 0;		/* remove trailing '/' */
-    p = s2;
-    while (*p++)
-      if (*p == '/')
-	*p = '.';
-    return s2;
+  malloc_strcpy(s2, path);
+  if (s2[strlen(s2) - 1] == '/')
+    s2[strlen(s2) - 1] = 0;     /* remove trailing '/' */
+  p = s2;
+  while (*p++)
+    if (*p == '/')
+      *p = '.';
+  return s2;
 }
 
 /* Opens the filedb responsible to the specified directory.
@@ -765,9 +761,9 @@ static FILE *filedb_open(char *path, int sort)
     if (convert_old_files(npath, s)) {
       fdb = fopen(s, "r+b");
       if (fdb == NULL) {
-	putlog(LOG_MISC, "*", FILES_NOCONVERT, npath);
-	my_free(s);
-	my_free(npath);
+        putlog(LOG_MISC, "*", FILES_NOCONVERT, npath);
+        my_free(s);
+        my_free(npath);
         return NULL;
       }
       lockfile(fdb);
@@ -782,9 +778,9 @@ static FILE *filedb_open(char *path, int sort)
       /* Create new database and fix it up */
       fdb = fopen(s, "w+b");
       if (!fdb) {
-	my_free(s);
-	my_free(npath);
-	return NULL;
+        my_free(s);
+        my_free(npath);
+        return NULL;
       }
       lockfile(fdb);
       fdbt.version = FILEDB_NEWEST_VER;
@@ -798,7 +794,7 @@ static FILE *filedb_open(char *path, int sort)
     }
   }
 
-  lockfile(fdb);			/* Lock it from other bots */
+  lockfile(fdb);                /* Lock it from other bots */
   filedb_readtop(fdb, &fdbt);
   if (fdbt.version < FILEDB_NEWEST_VER) {
     if (!convert_old_db(&fdb, s)) {
@@ -821,8 +817,7 @@ static FILE *filedb_open(char *path, int sort)
    * (6 hours may be a bit often)
    */
   if (sort || ((now - fdbt.timestamp) > (6 * 3600)) ||
-      (fdbt.timestamp < st.st_mtime) ||
-      (fdbt.timestamp < st.st_ctime))
+      (fdbt.timestamp < st.st_mtime) || (fdbt.timestamp < st.st_ctime))
     /* File database isn't up-to-date! */
     filedb_update(npath, fdb, sort & 1);
   else if ((now - fdbt.timestamp) > 300)
@@ -837,7 +832,7 @@ static FILE *filedb_open(char *path, int sort)
 /* Closes the filedb. Also removes the lock and updates the
  * timestamp.
  */
-static void filedb_close(FILE * fdb)
+static void filedb_close(FILE *fdb)
 {
   filedb_timestamp(fdb);
   fseek(fdb, 0L, SEEK_END);
@@ -850,7 +845,7 @@ static void filedb_close(FILE * fdb)
  * is misleading, as the file is added in filedb_open() and we
  * only add information in here.
  */
-static void filedb_add(FILE * fdb, char *filename, char *nick)
+static void filedb_add(FILE *fdb, char *filename, char *nick)
 {
   filedb_entry *fdbe = NULL;
 
@@ -871,11 +866,11 @@ static void filedb_add(FILE * fdb, char *filename, char *nick)
  */
 static void filedb_ls(FILE *fdb, int idx, char *mask, int showall)
 {
-  int  ok = 0, cnt = 0, is = 0;
+  int ok = 0, cnt = 0, is = 0;
   char s1[81], *p = NULL;
-  struct flag_record user  = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
-  filedb_entry *fdbe  = NULL;
-  filelist_t   *flist = NULL;
+  struct flag_record user = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
+  filedb_entry *fdbe = NULL;
+  filelist_t *flist = NULL;
 
   flist = filelist_new();
   filedb_readtop(fdb, NULL);
@@ -886,12 +881,12 @@ static void filedb_ls(FILE *fdb, int idx, char *mask, int showall)
       ok = 0;
     if (ok && (fdbe->stat & FILE_DIR) && fdbe->flags_req) {
       /* Check permissions */
-      struct flag_record req = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+      struct flag_record req = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
       break_down_flags(fdbe->flags_req, &req, NULL);
       get_user_flagrec(dcc[idx].user, &user, dcc[idx].u.file->chat->con_chan);
       if (!flagrec_ok(&req, &user)) {
-	ok = 0;
+        ok = 0;
       }
     }
     if (ok)
@@ -903,109 +898,108 @@ static void filedb_ls(FILE *fdb, int idx, char *mask, int showall)
     if (ok) {
       /* Display it! */
       if (cnt == 0) {
-	dprintf(idx, FILES_LSHEAD1);
-	dprintf(idx, FILES_LSHEAD2);
+        dprintf(idx, FILES_LSHEAD1);
+        dprintf(idx, FILES_LSHEAD2);
       }
       filelist_add(flist, fdbe->filename);
       if (fdbe->stat & FILE_DIR) {
-	char *s2 = NULL, *s3 = NULL;
+        char *s2 = NULL, *s3 = NULL;
 
-	/* Too long? */
-	if (strlen(fdbe->filename) > 45) {
-	  /* Display the filename on its own line. */
-	  s2 = nmalloc(strlen(fdbe->filename) + 3);
-	  sprintf(s2, "%s/\n", fdbe->filename);
-	  filelist_addout(flist, s2);
-	  my_free(s2);
-	} else {
-	  s2 = nmalloc(strlen(fdbe->filename) + 2);
-	  sprintf(s2, "%s/", fdbe->filename);
-	}
-	/* Note: You have to keep the sprintf and the nmalloc statements
-	 *       in sync, i.e. always check that you allocate enough
-	 *       memory.
-	 */
-	if ((fdbe->flags_req) &&
-	    (user.global &(USER_MASTER | USER_JANITOR))) {
-	  s3 = nmalloc(42 + strlen(s2 ? s2 : "") + 6 +
-		       strlen(FILES_REQUIRES) + strlen(fdbe->flags_req) + 1 +
-		       strlen(fdbe->chan ? fdbe->chan : "") + 1);
-	  sprintf(s3, "%-30s <DIR%s>  (%s %s%s%s)\n", s2,
-		  fdbe->stat & FILE_SHARE ?
-		  " SHARE" : "", FILES_REQUIRES, fdbe->flags_req,
-		  fdbe->chan ? " " : "", fdbe->chan ? fdbe->chan : "");
-	} else {
-	  s3 = nmalloc(38 + strlen(s2 ? s2 : ""));
-	  sprintf(s3, "%-30s <DIR>\n", s2 ? s2 : "");
-	}
-	if (s2)
-	  my_free(s2);
-	filelist_addout(flist, s3);
-	my_free(s3);
+        /* Too long? */
+        if (strlen(fdbe->filename) > 45) {
+          /* Display the filename on its own line. */
+          s2 = nmalloc(strlen(fdbe->filename) + 3);
+          sprintf(s2, "%s/\n", fdbe->filename);
+          filelist_addout(flist, s2);
+          my_free(s2);
+        } else {
+          s2 = nmalloc(strlen(fdbe->filename) + 2);
+          sprintf(s2, "%s/", fdbe->filename);
+        }
+        /* Note: You have to keep the sprintf and the nmalloc statements
+         *       in sync, i.e. always check that you allocate enough
+         *       memory.
+         */
+        if ((fdbe->flags_req) && (user.global &(USER_MASTER | USER_JANITOR))) {
+          s3 = nmalloc(42 + strlen(s2 ? s2 : "") + 6 +
+                       strlen(FILES_REQUIRES) + strlen(fdbe->flags_req) + 1 +
+                       strlen(fdbe->chan ? fdbe->chan : "") + 1);
+          sprintf(s3, "%-30s <DIR%s>  (%s %s%s%s)\n", s2,
+                  fdbe->stat & FILE_SHARE ?
+                  " SHARE" : "", FILES_REQUIRES, fdbe->flags_req,
+                  fdbe->chan ? " " : "", fdbe->chan ? fdbe->chan : "");
+        } else {
+          s3 = nmalloc(38 + strlen(s2 ? s2 : ""));
+          sprintf(s3, "%-30s <DIR>\n", s2 ? s2 : "");
+        }
+        if (s2)
+          my_free(s2);
+        filelist_addout(flist, s3);
+        my_free(s3);
       } else {
-	char s2[41], t[50], *s3 = NULL, *s4;
+        char s2[41], t[50], *s3 = NULL, *s4;
 
-	s2[0] = 0;
-	if (showall) {
-	  if (fdbe->stat & FILE_SHARE)
-	    strcat(s2, " (shr)");
-	  if (fdbe->stat & FILE_HIDDEN)
-	    strcat(s2, " (hid)");
-	}
-	egg_strftime(t, 10, "%d%b%Y", localtime(&fdbe->uploaded));
-	if (fdbe->size < 1024)
-	  sprintf(s1, "%5d", fdbe->size);
-	else
-	  sprintf(s1, "%4dk", (int) (fdbe->size / 1024));
-	if (fdbe->sharelink)
-	  strcpy(s1, "     ");
-	/* Too long? */
-	if (strlen(fdbe->filename) > 30) {
-	  s3 = nmalloc(strlen(fdbe->filename) + 2);
-	  sprintf(s3, "%s\n", fdbe->filename);
-	  filelist_addout(flist, s3);
-	  my_free(s3);
-	  /* Causes filename to be displayed on its own line */
-	} else
-	  malloc_strcpy(s3, fdbe->filename);
-	s4 = nmalloc(69 + strlen(s3 ? s3 : "") + strlen(s1) +
-		     strlen(fdbe->uploader) + strlen(t) + strlen(s2));
-	sprintf(s4, "%-30s %s  %-9s (%s)  %6d%s\n", s3 ? s3 : "", s1,
-		fdbe->uploader, t, fdbe->gots, s2);
-	if (s3)
-	  my_free(s3);
-	filelist_addout(flist, s4);
-	my_free(s4);
-	if (fdbe->sharelink) {
-	  s4 = nmalloc(9 + strlen(fdbe->sharelink));
-	  sprintf(s4, "   --> %s\n", fdbe->sharelink);
-	  filelist_addout(flist, s4);
-	  my_free(s4);
-	}
+        s2[0] = 0;
+        if (showall) {
+          if (fdbe->stat & FILE_SHARE)
+            strcat(s2, " (shr)");
+          if (fdbe->stat & FILE_HIDDEN)
+            strcat(s2, " (hid)");
+        }
+        egg_strftime(t, 10, "%d%b%Y", localtime(&fdbe->uploaded));
+        if (fdbe->size < 1024)
+          sprintf(s1, "%5d", fdbe->size);
+        else
+          sprintf(s1, "%4dk", (int) (fdbe->size / 1024));
+        if (fdbe->sharelink)
+          strcpy(s1, "     ");
+        /* Too long? */
+        if (strlen(fdbe->filename) > 30) {
+          s3 = nmalloc(strlen(fdbe->filename) + 2);
+          sprintf(s3, "%s\n", fdbe->filename);
+          filelist_addout(flist, s3);
+          my_free(s3);
+          /* Causes filename to be displayed on its own line */
+        } else
+          malloc_strcpy(s3, fdbe->filename);
+        s4 = nmalloc(69 + strlen(s3 ? s3 : "") + strlen(s1) +
+                     strlen(fdbe->uploader) + strlen(t) + strlen(s2));
+        sprintf(s4, "%-30s %s  %-9s (%s)  %6d%s\n", s3 ? s3 : "", s1,
+                fdbe->uploader, t, fdbe->gots, s2);
+        if (s3)
+          my_free(s3);
+        filelist_addout(flist, s4);
+        my_free(s4);
+        if (fdbe->sharelink) {
+          s4 = nmalloc(9 + strlen(fdbe->sharelink));
+          sprintf(s4, "   --> %s\n", fdbe->sharelink);
+          filelist_addout(flist, s4);
+          my_free(s4);
+        }
       }
       if (fdbe->desc) {
-	p = strchr(fdbe->desc, '\n');
-	while (p != NULL) {
-	  *p = 0;
-	  if ((fdbe->desc)[0]) {
-	    char *sd;
+        p = strchr(fdbe->desc, '\n');
+        while (p != NULL) {
+          *p = 0;
+          if ((fdbe->desc)[0]) {
+            char *sd;
 
-	    sd = nmalloc(strlen(fdbe->desc) + 5);
-	    sprintf(sd, "   %s\n", fdbe->desc);
-	    filelist_addout(flist, sd);
-	    my_free(sd);
-	  }
-	  strcpy(fdbe->desc, p + 1);
-	  p = strchr(fdbe->desc, '\n');
-	}
-	if ((fdbe->desc)[0]) {
-	  char *sd;
+            sd = nmalloc(strlen(fdbe->desc) + 5);
+            sprintf(sd, "   %s\n", fdbe->desc);
+            filelist_addout(flist, sd);
+            my_free(sd);
+          }
+          strcpy(fdbe->desc, p + 1);
+          p = strchr(fdbe->desc, '\n');
+        }
+        if ((fdbe->desc)[0]) {
+          char *sd;
 
-	  sd = nmalloc(strlen(fdbe->desc) + 5);
-	  sprintf(sd, "   %s\n", fdbe->desc);
-	  filelist_addout(flist, sd);
-	  my_free(sd);
-	}
+          sd = nmalloc(strlen(fdbe->desc) + 5);
+          sprintf(sd, "   %s\n", fdbe->desc);
+          filelist_addout(flist, sd);
+          my_free(sd);
+        }
       }
       cnt++;
     }
@@ -1026,10 +1020,10 @@ static void filedb_ls(FILE *fdb, int idx, char *mask, int showall)
 
 static void remote_filereq(int idx, char *from, char *file)
 {
-  char *p   = NULL, *what   = NULL, *dir = NULL,
-       *s1  = NULL, *reject = NULL, *s   = NULL;
+  char *p = NULL, *what = NULL, *dir = NULL,
+    *s1 = NULL, *reject = NULL, *s = NULL;
   FILE *fdb = NULL;
-  int	i   = 0;
+  int i = 0;
   filedb_entry *fdbe = NULL;
 
   malloc_strcpy(what, file);
@@ -1052,26 +1046,26 @@ static void remote_filereq(int idx, char *from, char *file)
       reject = FILES_FILEDNE;
     } else {
       if ((!(fdbe->stat & FILE_SHARE)) ||
-	  (fdbe->stat & (FILE_HIDDEN | FILE_DIR)))
-	reject = FILES_NOSHARE;
+          (fdbe->stat & (FILE_HIDDEN | FILE_DIR)))
+        reject = FILES_NOSHARE;
       else {
-	s1 = nmalloc(strlen(dccdir) + strlen(dir) + strlen(what) + 2);
-	/* Copy to /tmp if needed */
-	sprintf(s1, "%s%s%s%s", dccdir, dir, dir[0] ? "/" : "", what);
-	if (copy_to_tmp) {
-	  s = nmalloc(strlen(tempdir) + strlen(what) + 1);
-	  sprintf(s, "%s%s", tempdir, what);
-	  copyfile(s1, s);
-	} else
-	  s = s1;
-	i = raw_dcc_send(s, "*remote", FILES_REMOTE, s);
-	if (i > 0) {
-	  wipe_tmp_filename(s, -1);
-	  reject = FILES_SENDERR;
-	}
-	if (s1 != s)
-	  my_free(s);
-	my_free(s1);
+        s1 = nmalloc(strlen(dccdir) + strlen(dir) + strlen(what) + 2);
+        /* Copy to /tmp if needed */
+        sprintf(s1, "%s%s%s%s", dccdir, dir, dir[0] ? "/" : "", what);
+        if (copy_to_tmp) {
+          s = nmalloc(strlen(tempdir) + strlen(what) + 1);
+          sprintf(s, "%s%s", tempdir, what);
+          copyfile(s1, s);
+        } else
+          s = s1;
+        i = raw_dcc_send(s, "*remote", FILES_REMOTE, s);
+        if (i > 0) {
+          wipe_tmp_filename(s, -1);
+          reject = FILES_SENDERR;
+        }
+        if (s1 != s)
+          my_free(s);
+        my_free(s1);
       }
       free_fdbe(&fdbe);
     }
@@ -1087,9 +1081,9 @@ static void remote_filereq(int idx, char *from, char *file)
   }
   /* Grab info from dcc struct and bounce real request across net */
   i = dcc_total - 1;
-  s = nmalloc(40);	/* Enough? */
+  s = nmalloc(40);              /* Enough? */
   simple_sprintf(s, "%d %u %d", iptolong(getmyip()), dcc[i].port,
-		dcc[i].u.xfer->length);
+                 dcc[i].u.xfer->length);
   botnet_send_filesend(idx, s1, from, s);
   putlog(LOG_FILES, "*", FILES_REMOTEREQ, dir, dir[0] ? "/" : "", what);
   my_free(s1);
@@ -1132,7 +1126,7 @@ static void filedb_getowner(char *dir, char *fn, char **owner)
 static int filedb_getgots(char *dir, char *fn)
 {
   filedb_entry *fdbe = NULL;
-  int	        gots = 0;
+  int gots = 0;
 
   fdbe = filedb_getentry(dir, fn);
   if (fdbe) {
@@ -1145,7 +1139,7 @@ static int filedb_getgots(char *dir, char *fn)
 static void filedb_setdesc(char *dir, char *fn, char *desc)
 {
   filedb_entry *fdbe = NULL;
-  FILE         *fdb  = NULL;
+  FILE *fdb = NULL;
 
   fdb = filedb_open(dir, 0);
   if (!fdb)
@@ -1164,7 +1158,7 @@ static void filedb_setdesc(char *dir, char *fn, char *desc)
 static void filedb_setowner(char *dir, char *fn, char *owner)
 {
   filedb_entry *fdbe = NULL;
-  FILE         *fdb  = NULL;
+  FILE *fdb = NULL;
 
   fdb = filedb_open(dir, 0);
   if (!fdb)
@@ -1183,7 +1177,7 @@ static void filedb_setowner(char *dir, char *fn, char *owner)
 static void filedb_setlink(char *dir, char *fn, char *link)
 {
   filedb_entry *fdbe = NULL;
-  FILE	       *fdb  = NULL;
+  FILE *fdb = NULL;
 
   fdb = filedb_open(dir, 0);
   if (!fdb)
@@ -1229,7 +1223,7 @@ static void filedb_getlink(char *dir, char *fn, char **link)
   return;
 }
 
-static void filedb_getfiles(Tcl_Interp * irp, char *dir)
+static void filedb_getfiles(Tcl_Interp *irp, char *dir)
 {
   FILE *fdb;
   filedb_entry *fdbe;
@@ -1242,14 +1236,14 @@ static void filedb_getfiles(Tcl_Interp * irp, char *dir)
     fdbe = filedb_getfile(fdb, ftell(fdb), GET_FILENAME);
     if (fdbe) {
       if (!(fdbe->stat & (FILE_DIR | FILE_UNUSED)))
-	Tcl_AppendElement(irp, fdbe->filename);
+        Tcl_AppendElement(irp, fdbe->filename);
       free_fdbe(&fdbe);
     }
   }
   filedb_close(fdb);
 }
 
-static void filedb_getdirs(Tcl_Interp * irp, char *dir)
+static void filedb_getdirs(Tcl_Interp *irp, char *dir)
 {
   FILE *fdb;
   filedb_entry *fdbe;
@@ -1262,7 +1256,7 @@ static void filedb_getdirs(Tcl_Interp * irp, char *dir)
     fdbe = filedb_getfile(fdb, ftell(fdb), GET_FILENAME);
     if (fdbe) {
       if ((!(fdbe->stat & FILE_UNUSED)) && (fdbe->stat & FILE_DIR))
-	Tcl_AppendElement(irp, fdbe->filename);
+        Tcl_AppendElement(irp, fdbe->filename);
       free_fdbe(&fdbe);
     }
   }
@@ -1284,11 +1278,11 @@ static void filedb_change(char *dir, char *fn, int what)
     if (!(fdbe->stat & FILE_DIR)) {
       switch (what) {
       case FILEDB_SHARE:
-	fdbe->stat |= FILE_SHARE;
-	break;
+        fdbe->stat |= FILE_SHARE;
+        break;
       case FILEDB_UNSHARE:
-	fdbe->stat &= ~FILE_SHARE;
-	break;
+        fdbe->stat &= ~FILE_SHARE;
+        break;
       }
       changed = 1;
     }
