@@ -2,11 +2,11 @@
  * files.c - part of filesys.mod
  *   handles all file system commands
  *
- * $Id: files.c,v 1.30 2002/01/02 03:46:38 guppy Exp $
+ * $Id: files.c,v 1.44 2003/03/16 21:41:29 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,13 +75,13 @@ static void add_file(char *dir, char *file, char *nick)
 
 static int welcome_to_files(int idx)
 {
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
   FILE *f;
   char *p = get_user(&USERENTRY_DCCDIR, dcc[idx].user);
 
   dprintf(idx, "\n");
-  if (fr.global & USER_JANITOR)
-    fr.global |= USER_MASTER;
+  if (fr.global &USER_JANITOR)
+    fr.global |=USER_MASTER;
 
   /* Show motd if the user went straight here without going thru the
    * party line.
@@ -105,10 +105,9 @@ static int welcome_to_files(int idx)
       dprintf(idx, "\n\n");
       dccdir[0] = 0;
       chanout_but(-1, dcc[idx].u.file->chat->channel,
-		  "*** %s rejoined the party line.\n",
-		  dcc[idx].nick);
+                  "*** %s rejoined the party line.\n", dcc[idx].nick);
       botnet_send_join_idx(idx, dcc[idx].u.file->chat->channel);
-      return 0;			/* failed */
+      return 0;                 /* failed */
     }
   }
   filedb_close(f);
@@ -120,7 +119,7 @@ static void cmd_optimize(int idx, char *par)
 {
   struct userrec *u = get_user_by_handle(userlist, dcc[idx].nick);
   FILE *fdb = NULL;
-  char *p   = NULL;
+  char *p = NULL;
 
   putlog(LOG_FILES, "*", "files: #%s# optimize", dcc[idx].nick);
   p = get_user(&USERENTRY_DCCDIR, u);
@@ -150,17 +149,17 @@ static void cmd_optimize(int idx, char *par)
 static int resolve_dir(char *current, char *change, char **real, int idx)
 {
   char *elem = NULL, *s = NULL, *new = NULL, *work = NULL, *p = NULL;
-  FILE *fdb  = NULL;
-  DIR  *dir  = NULL;
+  FILE *fdb = NULL;
+  DIR *dir = NULL;
   filedb_entry *fdbe = NULL;
-  struct flag_record user = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0},
-		     req  = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record user = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 },
+                     req = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   *real = NULL;
   malloc_strcpy(*real, current);
   if (!change[0])
-    return 1;				/* No change? */
-  new = nmalloc(strlen(change) + 2);	/* Add 2, because we add '/' below */
+    return 1;                   /* No change? */
+  new = nmalloc(strlen(change) + 2);    /* Add 2, because we add '/' below */
   strcpy(new, change);
   if (new[0] == '/') {
     /* EVERYONE has access here */
@@ -175,70 +174,76 @@ static int resolve_dir(char *current, char *change, char **real, int idx)
     p++;
     malloc_strcpy(elem, new);
     strcpy(new, p);
-    if (!(strcmp(elem, ".")) || (!elem[0])) {	/* Do nothing */
-    } else if (!strcmp(elem, "..")) {	/* Go back */
+    if (!elem[0] || !strcmp(elem, ".")) {
+      p = strchr(new, '/');
+      continue;
+    } else if (!strcmp(elem, "..")) {
       /* Always allowed */
       p = strrchr(*real, '/');
       if (p == NULL) {
-	/* Can't go back from here? */
-	if (!(*real)[0]) {
-	  my_free(elem);
-	  my_free(new);
-	  malloc_strcpy(*real, current);
-	  return 0;
-	}
-	(*real)[0] = 0;
+        /* Can't go back from here? */
+        if (!(*real)[0]) {
+          my_free(elem);
+          my_free(new);
+          malloc_strcpy(*real, current);
+          return 0;
+        }
+        (*real)[0] = 0;
       } else
-	*p = 0;
+        *p = 0;
     } else {
       /* Allowed access here? */
       fdb = filedb_open(*real, 0);
       if (!fdb) {
-	/* Non-existent starting point! */
-	my_free(elem);
-	my_free(new);
-	malloc_strcpy(*real, current);
-	return 0;
+        /* Non-existent starting point! */
+        my_free(elem);
+        my_free(new);
+        malloc_strcpy(*real, current);
+        return 0;
       }
       filedb_readtop(fdb, NULL);
       fdbe = filedb_matchfile(fdb, ftell(fdb), elem);
       filedb_close(fdb);
       if (!fdbe) {
-	/* Non-existent */
-	my_free(elem);
-	my_free(new);
-	malloc_strcpy(*real, current);
-	return 0;
+        /* Non-existent */
+        my_free(elem);
+        my_free(new);
+        my_free(s);
+        malloc_strcpy(*real, current);
+        return 0;
       }
       if (!(fdbe->stat & FILE_DIR) || fdbe->sharelink) {
-	/* Not a dir */
-	free_fdbe(&fdbe);
-	my_free(elem);
-	my_free(new);
-	malloc_strcpy(*real, current);
-	return 0;
+        /* Not a dir */
+        free_fdbe(&fdbe);
+        my_free(elem);
+        my_free(new);
+        my_free(s);
+        malloc_strcpy(*real, current);
+        return 0;
       }
       if (idx >= 0)
-	get_user_flagrec(dcc[idx].user, &user, fdbe->chan);
+        get_user_flagrec(dcc[idx].user, &user, fdbe->chan);
       else
-	user.global = USER_OWNER | USER_BOT | USER_MASTER | USER_OP |
-		      USER_FRIEND;
+        user.global = USER_OWNER | USER_BOT | USER_MASTER | USER_OP |
+                      USER_FRIEND;
 
       if (fdbe->flags_req) {
         break_down_flags(fdbe->flags_req, &req, NULL);
         if (!flagrec_ok(&req, &user)) {
-	  free_fdbe(&fdbe);
-	  my_free(elem);
-	  my_free(new);
-	  malloc_strcpy(*real, current);
-	  return 0;
-	}
+          free_fdbe(&fdbe);
+          my_free(elem);
+          my_free(new);
+          my_free(s);
+          malloc_strcpy(*real, current);
+          return 0;
+        }
       }
       free_fdbe(&fdbe);
       malloc_strcpy(s, *real);
-      if (s[0])
-	if (s[strlen(s) - 1] != '/')
-	  strcat(s, "/");
+      if (s[0] && s[strlen(s) - 1] != '/') {
+          s = nrealloc(s, strlen(s) + 2);
+          strcat(s, "/");
+      }
       work = nmalloc(strlen(s) + strlen(elem) + 1);
       sprintf(work, "%s%s", s, elem);
       malloc_strcpy(*real, work);
@@ -290,7 +295,7 @@ static void incr_file_gots(char *ppath)
     my_free(path);
     my_free(destdir);
     my_free(fn);
-    return;			/* Not my concern, then */
+    return;                     /* Not my concern, then */
   }
   my_free(path);
   my_free(destdir);
@@ -331,7 +336,7 @@ static void cmd_cancel(int idx, char *par)
 
 static void cmd_chdir(int idx, char *msg)
 {
-  char *s;
+  char *s = NULL;
 
   if (!msg[0]) {
     dprintf(idx, "%s: cd <new-dir>\n", MISC_USAGE);
@@ -347,7 +352,7 @@ static void cmd_chdir(int idx, char *msg)
   dcc[idx].u.file->dir[160] = 0;
   set_user(&USERENTRY_DCCDIR, dcc[idx].user, dcc[idx].u.file->dir);
   putlog(LOG_FILES, "*", "files: #%s# cd /%s", dcc[idx].nick,
-	 dcc[idx].u.file->dir);
+         dcc[idx].u.file->dir);
   dprintf(idx, "%s: /%s\n", FILES_NEWCURDIR, dcc[idx].u.file->dir);
 }
 
@@ -364,11 +369,11 @@ static void files_ls(int idx, char *par, int showall)
       malloc_strcpy(s, par);
       malloc_strcpy(mask, p + 1);
       if (!resolve_dir(dcc[idx].u.file->dir, s, &destdir, idx)) {
-	dprintf(idx, FILES_ILLDIR);
-	my_free(s);
-	my_free(mask);
-	my_free(destdir);
-	return;
+        dprintf(idx, FILES_ILLDIR);
+        my_free(s);
+        my_free(mask);
+        my_free(destdir);
+        return;
       }
       my_free(s);
     } else {
@@ -428,11 +433,11 @@ static void cmd_reget_get(int idx, char *par, int resend)
     module_entry *me = module_find("server", 1, 1);
 
     if (me && me->funcs)
-      nicklen = (int) me->funcs[SERVER_NICKLEN];
+      nicklen = (*(int *)me->funcs[SERVER_NICKLEN]);
   }
   if (!par[0]) {
     dprintf(idx, "%s: %sget <file(s)> [nickname]\n", MISC_USAGE,
-	    resend ? "re" : "");
+            resend ? "re" : "");
     return;
   }
   what = newsplit(&par);
@@ -471,37 +476,37 @@ static void cmd_reget_get(int idx, char *par, int resend)
     if (!(fdbe->stat & (FILE_HIDDEN | FILE_DIR))) {
       ok = 1;
       if (fdbe->sharelink) {
-	char *bot, *whoto = NULL;
+        char *bot, *whoto = NULL;
 
-	/* This is a link to a file on another bot... */
-	bot = nmalloc(strlen(fdbe->sharelink) + 1);
-	splitc(bot, fdbe->sharelink, ':');
-	if (!egg_strcasecmp(bot, botnetnick)) {
-	  dprintf(idx, "Can't get that file, it's linked to this bot!\n");
-	} else if (!in_chain(bot)) {
-	  dprintf(idx, FILES_NOTAVAIL, fdbe->filename);
-	} else {
-	  i = nextbot(bot);
-	  malloc_strcpy(whoto, par);
-	  if (!whoto[0])
-	    malloc_strcpy(whoto, dcc[idx].nick);
-	  s = nmalloc(strlen(whoto) + strlen(botnetnick) + 13);
-	  simple_sprintf(s, "%d:%s@%s", dcc[idx].sock, whoto, botnetnick);
-	  botnet_send_filereq(i, s, bot, fdbe->sharelink);
-	  dprintf(idx, FILES_REQUESTED, fdbe->sharelink, bot);
-	  /* Increase got count now (or never) */
-	  fdbe->gots++;
-	  s = nrealloc(s, strlen(bot) + strlen(fdbe->sharelink) + 2);
-	  sprintf(s, "%s:%s", bot, fdbe->sharelink);
-	  malloc_strcpy(fdbe->sharelink, s);
-	  filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_ALL);
-	  my_free(whoto);
-	  my_free(s);
-	}
-	my_free(bot);
+        /* This is a link to a file on another bot... */
+        bot = nmalloc(strlen(fdbe->sharelink) + 1);
+        splitc(bot, fdbe->sharelink, ':');
+        if (!egg_strcasecmp(bot, botnetnick))
+          dprintf(idx, "Can't get that file, it's linked to this bot!\n");
+        else if (!in_chain(bot))
+          dprintf(idx, FILES_NOTAVAIL, fdbe->filename);
+        else {
+          i = nextbot(bot);
+          malloc_strcpy(whoto, par);
+          if (!whoto[0])
+            malloc_strcpy(whoto, dcc[idx].nick);
+          s = nmalloc(strlen(whoto) + strlen(botnetnick) + 13);
+          simple_sprintf(s, "%d:%s@%s", dcc[idx].sock, whoto, botnetnick);
+          botnet_send_filereq(i, s, bot, fdbe->sharelink);
+          dprintf(idx, FILES_REQUESTED, fdbe->sharelink, bot);
+          /* Increase got count now (or never) */
+          fdbe->gots++;
+          s = nrealloc(s, strlen(bot) + strlen(fdbe->sharelink) + 2);
+          sprintf(s, "%s:%s", bot, fdbe->sharelink);
+          malloc_strcpy(fdbe->sharelink, s);
+          filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_ALL);
+          my_free(whoto);
+          my_free(s);
+        }
+        my_free(bot);
       } else {
-	do_dcc_send(idx, destdir, fdbe->filename, par, resend);
-	/* Don't increase got count till later */
+        do_dcc_send(idx, destdir, fdbe->filename, par, resend);
+        /* Don't increase got count till later */
       }
     }
     free_fdbe(&fdbe);
@@ -513,7 +518,7 @@ static void cmd_reget_get(int idx, char *par, int resend)
     dprintf(idx, FILES_NOMATCH);
   else
     putlog(LOG_FILES, "*", "files: #%s# %sget %s %s", dcc[idx].nick,
-	   resend ? "re" : "", what, par);
+           resend ? "re" : "", what, par);
 }
 
 static void cmd_reget(int idx, char *par)
@@ -529,7 +534,7 @@ static void cmd_get(int idx, char *par)
 static void cmd_file_help(int idx, char *par)
 {
   char *s;
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   get_user_flagrec(dcc[idx].user, &fr, dcc[idx].u.file->chat->con_chan);
   if (par[0]) {
@@ -695,7 +700,7 @@ static void cmd_unshare(int idx, char *par)
   while (fdbe) {
     where = ftell(fdb);
     if ((fdbe->stat & FILE_SHARE) &&
-	!(fdbe->stat & (FILE_DIR | FILE_HIDDEN))) {
+        !(fdbe->stat & (FILE_DIR | FILE_HIDDEN))) {
       fdbe->stat &= ~FILE_SHARE;
       ok++;
       dprintf(idx, "%s: %s\n", FILES_UNSHARED, fdbe->filename);
@@ -710,8 +715,7 @@ static void cmd_unshare(int idx, char *par)
   else {
     putlog(LOG_FILES, "*", "files: #%s# unshare %s", dcc[idx].nick, par);
     if (ok > 1)
-      dprintf(idx, "%s %d file%s.\n", FILES_UNSHARED, ok,
-	      ok == 1 ? "" : "s");
+      dprintf(idx, "%s %d file%s.\n", FILES_UNSHARED, ok, ok == 1 ? "" : "s");
   }
 }
 
@@ -736,10 +740,10 @@ static void cmd_ln(int idx, char *par)
       *p = 0;
       malloc_strcpy(newfn, p + 1);
       if (!resolve_dir(dcc[idx].u.file->dir, par, &newpath, idx)) {
-	dprintf(idx, FILES_NOSUCHDIR);
-	my_free(newfn);
-	my_free(newpath);
-	return;
+        dprintf(idx, FILES_NOSUCHDIR);
+        my_free(newfn);
+        my_free(newpath);
+        return;
       }
     } else {
       malloc_strcpy(newpath, dcc[idx].u.file->dir);
@@ -755,15 +759,15 @@ static void cmd_ln(int idx, char *par)
     fdbe = filedb_matchfile(fdb, ftell(fdb), newfn);
     if (fdbe) {
       if (!fdbe->sharelink) {
-	dprintf(idx, FILES_NORMAL, newfn);
-	filedb_close(fdb);
+        dprintf(idx, FILES_NORMAL, newfn);
+        filedb_close(fdb);
       } else {
-	malloc_strcpy(fdbe->sharelink, share);
-	filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_ALL);
-	filedb_close(fdb);
-	dprintf(idx, FILES_CHGLINK, share);
-	putlog(LOG_FILES, "*", "files: #%s# ln %s %s",
-	       dcc[idx].nick, par, share);
+        malloc_strcpy(fdbe->sharelink, share);
+        filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_ALL);
+        filedb_close(fdb);
+        dprintf(idx, FILES_CHGLINK, share);
+        putlog(LOG_FILES, "*", "files: #%s# ln %s %s",
+               dcc[idx].nick, par, share);
       }
     } else {
       /* New entry */
@@ -776,7 +780,7 @@ static void cmd_ln(int idx, char *par)
       filedb_close(fdb);
       dprintf(idx, "%s %s -> %s\n", FILES_ADDLINK, fdbe->filename, share);
       putlog(LOG_FILES, "*", "files: #%s# ln /%s%s%s %s", dcc[idx].nick,
-	     newpath, newpath[0] ? "/" : "", newfn, share);
+             newpath, newpath[0] ? "/" : "", newfn, share);
     }
     free_fdbe(&fdbe);
     my_free(newpath);
@@ -805,7 +809,7 @@ static void cmd_desc(int idx, char *par)
   lin = 0;
   q = desc;
   while ((*q <= 32) && (*q))
-    strcpy(q, &q[1]);		/* Zapf leading spaces */
+    strcpy(q, &q[1]);           /* Zapf leading spaces */
   p = strchr(q, '|');
   while (p != NULL) {
     /* Check length */
@@ -815,12 +819,12 @@ static void cmd_desc(int idx, char *par)
       *p = '|';
       p = q + 60;
       while ((*p != ' ') && (p != q))
-	p--;
+        p--;
       if (p == q)
-	*(q + 60) = '|';	/* No space, so truncate it */
+        *(q + 60) = '|';        /* No space, so truncate it */
       else
-	*p = '|';
-      p = strchr(q, '|');	/* Go back, find my place, and continue */
+        *p = '|';
+      p = strchr(q, '|');       /* Go back, find my place, and continue */
     }
     *p = '\n';
     q = p + 1;
@@ -853,27 +857,27 @@ static void cmd_desc(int idx, char *par)
     if (!(fdbe->stat & FILE_HIDDEN)) {
       ok = 1;
       if ((!(dcc[idx].user->flags & USER_JANITOR)) &&
-	  (egg_strcasecmp(fdbe->uploader, dcc[idx].nick)))
-	dprintf(idx, FILES_NOTOWNER, fdbe->filename);
+          (egg_strcasecmp(fdbe->uploader, dcc[idx].nick)))
+        dprintf(idx, FILES_NOTOWNER, fdbe->filename);
       else {
-	if (desc[0]) {
-	  /* If the current description is the same as the new
-	   * one, don't change anything.
-	   */
-	  if (fdbe->desc && !strcmp(fdbe->desc, desc)) {
-	    free_fdbe(&fdbe);
-	    fdbe = filedb_matchfile(fdb, where, fn);
-	    continue;
-	  }
-	  malloc_strcpy(fdbe->desc, desc);
-	} else if (fdbe->desc) {
-	  my_free(fdbe->desc);
-	}
-	filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_ALL);
-	if (par[0])
-	  dprintf(idx, "%s: %s\n", FILES_CHANGED, fdbe->filename);
-	else
-	  dprintf(idx, "%s: %s\n", FILES_BLANKED, fdbe->filename);
+        if (desc[0]) {
+          /* If the current description is the same as the new
+           * one, don't change anything.
+           */
+          if (fdbe->desc && !strcmp(fdbe->desc, desc)) {
+            free_fdbe(&fdbe);
+            fdbe = filedb_matchfile(fdb, where, fn);
+            continue;
+          }
+          malloc_strcpy(fdbe->desc, desc);
+        } else if (fdbe->desc) {
+          my_free(fdbe->desc);
+        }
+        filedb_updatefile(fdb, fdbe->pos, fdbe, UPDATE_ALL);
+        if (par[0])
+          dprintf(idx, "%s: %s\n", FILES_CHANGED, fdbe->filename);
+        else
+          dprintf(idx, "%s: %s\n", FILES_BLANKED, fdbe->filename);
       }
     }
     free_fdbe(&fdbe);
@@ -913,13 +917,13 @@ static void cmd_rm(int idx, char *par)
     where = ftell(fdb);
     if (!(fdbe->stat & (FILE_HIDDEN | FILE_DIR))) {
       s = nmalloc(strlen(dccdir) + strlen(dcc[idx].u.file->dir)
-		  + strlen(fdbe->filename) + 2);
+                  + strlen(fdbe->filename) + 2);
       sprintf(s, "%s%s/%s", dccdir, dcc[idx].u.file->dir, fdbe->filename);
       ok++;
       filedb_delfile(fdb, fdbe->pos);
       /* Shared file links won't be able to be unlinked */
       if (!(fdbe->sharelink))
-	unlink(s);
+        unlink(s);
       dprintf(idx, "%s: %s\n", FILES_ERASED, fdbe->filename);
       my_free(s);
     }
@@ -942,7 +946,7 @@ static void cmd_mkdir(int idx, char *par)
   FILE *fdb;
   filedb_entry *fdbe;
   int ret;
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   if (!par[0]) {
     dprintf(idx, "%s: mkdir <dir> [required-flags] [channel]\n", MISC_USAGE);
@@ -963,15 +967,15 @@ static void cmd_mkdir(int idx, char *par)
       /* Need some extra checking here to makesure we dont mix up
        * the flags with a +channel. <cybah>
        */
-      if(!findchan(flags) && flags[0] != '+') {
-	dprintf(idx, "Invalid channel!\n");
-	return;
-      } else if(findchan(flags)) {
-	/* Flags is a channel. */
-	chan = flags;
-	flags = par;
-      }	/* (else) Couldn't find the channel and flags[0] is a '+', these
-	 * are flags. */
+      if (!findchan(flags) && flags[0] != '+') {
+        dprintf(idx, "Invalid channel!\n");
+        return;
+      } else if (findchan(flags)) {
+        /* Flags is a channel. */
+        chan = flags;
+        flags = par;
+      }                         /* (else) Couldn't find the channel and flags[0] is a '+', these
+                                 * are flags. */
     }
     if (chan[0] && !findchan(chan)) {
       dprintf(idx, "Invalid channel!\n");
@@ -984,13 +988,13 @@ static void cmd_mkdir(int idx, char *par)
     fdbe = filedb_matchfile(fdb, ftell(fdb), name);
     if (!fdbe) {
       s = nmalloc(strlen(dccdir) + strlen(dcc[idx].u.file->dir)
-		  + strlen(name) + 2);
+                  + strlen(name) + 2);
       sprintf(s, "%s%s/%s", dccdir, dcc[idx].u.file->dir, name);
       if (mkdir(s, 0755) != 0) {
-	dprintf(idx, MISC_FAILED);
-	filedb_close(fdb);
-	my_free(s);
-	return;
+        dprintf(idx, MISC_FAILED);
+        filedb_close(fdb);
+        my_free(s);
+        return;
       }
       my_free(s);
       fdbe = malloc_fdbe();
@@ -998,7 +1002,7 @@ static void cmd_mkdir(int idx, char *par)
       malloc_strcpy(fdbe->filename, name);
       fdbe->uploaded = now;
       dprintf(idx, "%s /%s%s%s\n", FILES_CREADIR, dcc[idx].u.file->dir,
-	      dcc[idx].u.file->dir[0] ? "/" : "", name);
+              dcc[idx].u.file->dir[0] ? "/" : "", name);
     } else if (!(fdbe->stat & FILE_DIR)) {
       dprintf(idx, FILES_NOSUCHDIR);
       free_fdbe(&fdbe);
@@ -1066,7 +1070,7 @@ static void cmd_rmdir(int idx, char *par)
     }
     /* Erase '.filedb' and '.files' if they exist */
     s = nmalloc(strlen(dccdir) + strlen(dcc[idx].u.file->dir)
-		+ strlen(name) + 10);
+                + strlen(name) + 10);
     sprintf(s, "%s%s/%s/.filedb", dccdir, dcc[idx].u.file->dir, name);
     unlink(s);
     sprintf(s, "%s%s/%s/.files", dccdir, dcc[idx].u.file->dir, name);
@@ -1074,7 +1078,7 @@ static void cmd_rmdir(int idx, char *par)
     sprintf(s, "%s%s/%s", dccdir, dcc[idx].u.file->dir, name);
     if (rmdir(s) == 0) {
       dprintf(idx, "%s /%s%s%s\n", FILES_REMDIR, dcc[idx].u.file->dir,
-	      dcc[idx].u.file->dir[0] ? "/" : "", name);
+              dcc[idx].u.file->dir[0] ? "/" : "", name);
       filedb_delfile(fdb, fdbe->pos);
       filedb_close(fdb);
       free_fdbe(&fdbe);
@@ -1095,7 +1099,7 @@ static void cmd_mv_cp(int idx, char *par, int copy)
 {
   char *p, *fn, *oldpath = NULL, *s = NULL, *s1, *newfn = NULL;
   char *newpath = NULL;
-  int   ok = 0, only_first = 0, skip_this = 0;
+  int ok = 0, only_first = 0, skip_this = 0;
   FILE *fdb_old = NULL, *fdb_new = NULL;
   filedb_entry *fdbe_old = NULL, *fdbe_new = NULL;
   long where = 0;
@@ -1103,7 +1107,7 @@ static void cmd_mv_cp(int idx, char *par, int copy)
   fn = newsplit(&par);
   if (!par[0]) {
     dprintf(idx, "%s: %s <oldfilepath> <newfilepath>\n",
-	    MISC_USAGE, copy ? "cp" : "mv");
+            MISC_USAGE, copy ? "cp" : "mv");
     return;
   }
   p = strrchr(fn, '/');
@@ -1122,6 +1126,7 @@ static void cmd_mv_cp(int idx, char *par, int copy)
     malloc_strcpy(oldpath, dcc[idx].u.file->dir);
   malloc_strcpy(s, par);
   if (!resolve_dir(dcc[idx].u.file->dir, s, &newpath, idx)) {
+    my_free(newpath);
     /* Destination is not just a directory */
     p = strrchr(s, '/');
     if (p == NULL) {
@@ -1143,8 +1148,7 @@ static void cmd_mv_cp(int idx, char *par, int copy)
     malloc_strcpy(newfn, "");
   my_free(s);
   /* Stupidness checks */
-  if ((!strcmp(oldpath, newpath)) &&
-      ((!newfn[0]) || (!strcmp(newfn, fn)))) {
+  if ((!strcmp(oldpath, newpath)) && ((!newfn[0]) || (!strcmp(newfn, fn)))) {
     dprintf(idx, FILES_STUPID, copy ? FILES_COPY : FILES_MOVE);
     my_free(oldpath);
     my_free(newpath);
@@ -1185,63 +1189,60 @@ static void cmd_mv_cp(int idx, char *par, int copy)
     skip_this = 0;
     if (!(fdbe_old->stat & (FILE_HIDDEN | FILE_DIR))) {
       s = nmalloc(strlen(dccdir) + strlen(oldpath)
-		  + strlen(fdbe_old->filename) + 2);
+                  + strlen(fdbe_old->filename) + 2);
       s1 = nmalloc(strlen(dccdir) + strlen(newpath)
-		   + strlen(newfn[0] ? newfn : fdbe_old->filename) + 2);
+                   + strlen(newfn[0] ? newfn : fdbe_old->filename) + 2);
       sprintf(s, "%s%s%s%s", dccdir, oldpath,
-	      oldpath[0] ? "/" : "", fdbe_old->filename);
+              oldpath[0] ? "/" : "", fdbe_old->filename);
       sprintf(s1, "%s%s%s%s", dccdir, newpath,
-	      newpath[0] ? "/" : "", newfn[0] ? newfn : fdbe_old->filename);
+              newpath[0] ? "/" : "", newfn[0] ? newfn : fdbe_old->filename);
       if (!strcmp(s, s1)) {
-	dprintf(idx, "%s /%s%s%s %s\n", FILES_SKIPSTUPID,
-	        copy ? FILES_COPY : FILES_MOVE, newpath,
-	        newpath[0] ? "/" : "", newfn[0] ? newfn : fdbe_old->filename);
-	skip_this = 1;
+        dprintf(idx, "%s /%s%s%s %s\n", FILES_SKIPSTUPID,
+                copy ? FILES_COPY : FILES_MOVE, newpath,
+                newpath[0] ? "/" : "", newfn[0] ? newfn : fdbe_old->filename);
+        skip_this = 1;
       }
       /* Check for existence of file with same name in new dir */
       filedb_readtop(fdb_new, NULL);
       fdbe_new = filedb_matchfile(fdb_new, ftell(fdb_new),
-				  newfn[0] ? newfn : fdbe_old->filename);
+                                  newfn[0] ? newfn : fdbe_old->filename);
       if (fdbe_new) {
-	/* It's ok if the entry in the new dir is a normal file (we'll
-	 * just scrap the old entry and overwrite the file) -- but if
-	 * it's a directory, this file has to be skipped.
-	 */
-	if (fdbe_new->stat & FILE_DIR) {
-	  /* Skip */
-	  skip_this = 1;
-	} else {
-	  filedb_delfile(fdb_new, fdbe_new->pos);
-	}
-	free_fdbe(&fdbe_new);
+        /* It's ok if the entry in the new dir is a normal file (we'll
+         * just scrap the old entry and overwrite the file) -- but if
+         * it's a directory, this file has to be skipped.
+         */
+        if (fdbe_new->stat & FILE_DIR)
+          skip_this = 1;
+        else
+          filedb_delfile(fdb_new, fdbe_new->pos);
+        free_fdbe(&fdbe_new);
       }
       if (!skip_this) {
-	if ((fdbe_old->sharelink) || (copyfile(s, s1) == 0)) {
-	  /* Raw file moved okay: create new entry for it */
-	  ok++;
-	  fdbe_new = malloc_fdbe();
-	  fdbe_new->stat = fdbe_old->stat;
-	  /* We don't have to worry about any entries to be
-	   * NULL, because malloc_strcpy takes care of that.
-	   */
-	  malloc_strcpy(fdbe_new->flags_req, fdbe_old->flags_req);
-	  malloc_strcpy(fdbe_new->chan, fdbe_old->chan);
-	  malloc_strcpy(fdbe_new->filename, fdbe_old->filename);
-	  malloc_strcpy(fdbe_new->desc, fdbe_old->desc);
-	  if (newfn[0])
-	    malloc_strcpy(fdbe_new->filename, newfn);
-	  malloc_strcpy(fdbe_new->uploader, fdbe_old->uploader);
-	  fdbe_new->uploaded = fdbe_old->uploaded;
-	  fdbe_new->size = fdbe_old->size;
-	  fdbe_new->gots = fdbe_old->gots;
-	  malloc_strcpy(fdbe_new->sharelink, fdbe_old->sharelink);
-	  filedb_addfile(fdb_new, fdbe_new);
-	  if (!copy) {
-	    unlink(s);
-	    filedb_delfile(fdb_old, fdbe_old->pos);
-	  }
-	  free_fdbe(&fdbe_new);
-	}
+        if ((fdbe_old->sharelink) ||
+            ((copy ? copyfile(s, s1) : movefile(s, s1)) == 0)) {
+          /* Raw file moved okay: create new entry for it */
+          ok++;
+          fdbe_new = malloc_fdbe();
+          fdbe_new->stat = fdbe_old->stat;
+          /* We don't have to worry about any entries to be
+           * NULL, because malloc_strcpy takes care of that.
+           */
+          malloc_strcpy(fdbe_new->flags_req, fdbe_old->flags_req);
+          malloc_strcpy(fdbe_new->chan, fdbe_old->chan);
+          malloc_strcpy(fdbe_new->filename, fdbe_old->filename);
+          malloc_strcpy(fdbe_new->desc, fdbe_old->desc);
+          if (newfn[0])
+            malloc_strcpy(fdbe_new->filename, newfn);
+          malloc_strcpy(fdbe_new->uploader, fdbe_old->uploader);
+          fdbe_new->uploaded = fdbe_old->uploaded;
+          fdbe_new->size = fdbe_old->size;
+          fdbe_new->gots = fdbe_old->gots;
+          malloc_strcpy(fdbe_new->sharelink, fdbe_old->sharelink);
+          filedb_addfile(fdb_new, fdbe_new);
+          if (!copy)
+            filedb_delfile(fdb_old, fdbe_old->pos);
+          free_fdbe(&fdbe_new);
+        }
       }
       my_free(s);
       my_free(s1);
@@ -1258,10 +1259,10 @@ static void cmd_mv_cp(int idx, char *par, int copy)
     dprintf(idx, FILES_NOMATCH);
   else {
     putlog(LOG_FILES, "*", "files: #%s# %s %s%s%s %s", dcc[idx].nick,
-	   copy ? "cp" : "mv", oldpath, oldpath[0] ? "/" : "", fn, par);
+           copy ? "cp" : "mv", oldpath, oldpath[0] ? "/" : "", fn, par);
     if (ok > 1)
       dprintf(idx, "%s %d file%s.\n",
-	      copy ? FILES_COPIED : FILES_MOVED, ok, ok == 1 ? "" : "s");
+              copy ? FILES_COPIED : FILES_MOVED, ok, ok == 1 ? "" : "s");
   }
   my_free(oldpath);
   my_free(newpath);
@@ -1301,8 +1302,8 @@ static int cmd_filestats(int idx, char *par)
   else if (!(u = get_user_by_handle(userlist, nick)))
     dprintf(idx, "No such user.\n");
   else if (!strcmp(par, "clear") && dcc[idx].user &&
-	   (dcc[idx].user->flags & USER_JANITOR)) {
-    set_user (&USERENTRY_FSTAT, u, NULL);
+           (dcc[idx].user->flags & USER_JANITOR)) {
+    set_user(&USERENTRY_FSTAT, u, NULL);
     dprintf(idx, "Cleared filestats for %s.\n", nick);
   } else
     tell_file_stats(idx, nick);
@@ -1321,45 +1322,43 @@ static void filesys_note(int idx, char *par)
     Function f = me->funcs[NOTES_CMD_NOTE];
 
     (f) (u, idx, par);
-  } else {
+  } else
     dprintf(idx, "Sending of notes is not supported.\n");
-  }
 }
 
-static cmd_t myfiles[] =
-{
-  {"cancel",	"",	(Function) cmd_cancel,		NULL},
-  {"cd",	"",	(Function) cmd_chdir,		NULL},
-  {"chdir",	"",	(Function) cmd_chdir,		NULL},
-  {"cp",	"j",	(Function) cmd_cp,		NULL},
-  {"desc",	"",	(Function) cmd_desc,		NULL},
-  {"filestats",	"j",	(Function) cmd_filestats,	NULL},
-  {"get",	"",	(Function) cmd_get,		NULL},
-  {"reget",	"",	(Function) cmd_reget,		NULL},
-  {"help",	"",	(Function) cmd_file_help,	NULL},
-  {"hide",	"j",	(Function) cmd_hide,		NULL},
-  {"ln",	"j",	(Function) cmd_ln,		NULL},
-  {"ls",	"",	(Function) cmd_ls,		NULL},
-  {"lsa",	"j",	(Function) cmd_lsa,		NULL},
-  {"mkdir",	"j",	(Function) cmd_mkdir,		NULL},
-  {"mv",	"j",	(Function) cmd_mv,		NULL},
-  {"note",	"",	(Function) filesys_note,	NULL},
-  {"pending",	"",	(Function) cmd_pending,		NULL},
-  {"pwd",	"",	(Function) cmd_pwd,		NULL},
-  {"quit",	"",	(Function) CMD_LEAVE,		NULL},
-  {"rm",	"j",	(Function) cmd_rm,		NULL},
-  {"rmdir",	"j",	(Function) cmd_rmdir,		NULL},
-  {"share",	"j",	(Function) cmd_share,		NULL},
+static cmd_t myfiles[] = {
+  {"cancel",    "",   (Function) cmd_cancel,    NULL},
+  {"cd",        "",   (Function) cmd_chdir,     NULL},
+  {"chdir",     "",   (Function) cmd_chdir,     NULL},
+  {"cp",        "j",  (Function) cmd_cp,        NULL},
+  {"desc",      "",   (Function) cmd_desc,      NULL},
+  {"filestats", "j",  (Function) cmd_filestats, NULL},
+  {"get",       "",   (Function) cmd_get,       NULL},
+  {"reget",     "",   (Function) cmd_reget,     NULL},
+  {"help",      "",   (Function) cmd_file_help, NULL},
+  {"hide",      "j",  (Function) cmd_hide,      NULL},
+  {"ln",        "j",  (Function) cmd_ln,        NULL},
+  {"ls",        "",   (Function) cmd_ls,        NULL},
+  {"lsa",       "j",  (Function) cmd_lsa,       NULL},
+  {"mkdir",     "j",  (Function) cmd_mkdir,     NULL},
+  {"mv",        "j",  (Function) cmd_mv,        NULL},
+  {"note",      "",   (Function) filesys_note,  NULL},
+  {"pending",   "",   (Function) cmd_pending,   NULL},
+  {"pwd",       "",   (Function) cmd_pwd,       NULL},
+  {"quit",      "",   (Function) CMD_LEAVE,     NULL},
+  {"rm",        "j",  (Function) cmd_rm,        NULL},
+  {"rmdir",     "j",  (Function) cmd_rmdir,     NULL},
+  {"share",     "j",  (Function) cmd_share,     NULL},
 /* Since we have spelt optimize wrong for so many years, we will
  * keep the old spelling around for the command name for now to
  * avoid problems with people typing .optimise and wondering 
  * where it went (guppy:28Nov2001) */
-  {"optimise",	"j",	(Function) cmd_optimize,	NULL},
-  {"optimize",	"j",	(Function) cmd_optimize,	NULL},
-  {"stats",	"",	(Function) cmd_stats,		NULL},
-  {"unhide",	"j",	(Function) cmd_unhide,		NULL},
-  {"unshare",	"j",	(Function) cmd_unshare,		NULL},
-  {NULL,	NULL,	NULL,				NULL}
+  {"optimise",  "j",  (Function) cmd_optimize,  NULL},
+  {"optimize",  "j",  (Function) cmd_optimize,  NULL},
+  {"stats",     "",   (Function) cmd_stats,     NULL},
+  {"unhide",    "j",  (Function) cmd_unhide,    NULL},
+  {"unshare",   "j",  (Function) cmd_unshare,   NULL},
+  {NULL,        NULL, NULL,                     NULL}
 };
 
 
@@ -1437,7 +1436,7 @@ static int files_reget(int idx, char *fn, char *nick, int resend)
       if (nick[0]) {
         malloc_strcpy(whoto, nick);
       } else {
-	malloc_strcpy(whoto, dcc[idx].nick);
+        malloc_strcpy(whoto, dcc[idx].nick);
       }
       s = nmalloc(strlen(whoto) + strlen(botnetnick) + 13);
       simple_sprintf(s, "%d:%s@%s", dcc[idx].sock, whoto, botnetnick);
@@ -1476,6 +1475,6 @@ static void files_setpwd(int idx, char *where)
     return;
   strcpy(dcc[idx].u.file->dir, s);
   set_user(&USERENTRY_DCCDIR, get_user_by_handle(userlist, dcc[idx].nick),
-	   dcc[idx].u.file->dir);
+           dcc[idx].u.file->dir);
   my_free(s);
 }
