@@ -2,11 +2,11 @@
  * filesys.c -- part of filesys.mod
  *   main file of the filesys eggdrop module
  *
- * $Id: filesys.c,v 1.47 2002/01/02 03:46:38 guppy Exp $
+ * $Id: filesys.c,v 1.61 2003/04/17 01:55:57 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -94,8 +94,7 @@ static void kill_dcc_files(int idx, void *x);
 static void out_dcc_files(int idx, char *buf, void *x);
 static char *mktempfile(char *filename);
 
-static struct dcc_table DCC_FILES =
-{
+static struct dcc_table DCC_FILES = {
   "FILES",
   DCT_MASTER | DCT_VALIDIDX | DCT_SHOWWHO | DCT_SIMUL | DCT_CANBOOT | DCT_FILES,
   eof_dcc_files,
@@ -108,9 +107,8 @@ static struct dcc_table DCC_FILES =
   out_dcc_files
 };
 
-static struct user_entry_type USERENTRY_DCCDIR =
-{
-  NULL,				/* always NULL ;) */
+static struct user_entry_type USERENTRY_DCCDIR = {
+  NULL,                         /* always NULL ;) */
   NULL,
   NULL,
   NULL,
@@ -139,7 +137,7 @@ static int check_tcl_fil(char *cmd, int idx, char *args)
 {
   int x;
   char s[5];
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN, 0, 0, 0, 0, 0 };
 
   get_user_flagrec(dcc[idx].user, &fr, dcc[idx].u.file->chat->con_chan);
   sprintf(s, "%ld", dcc[idx].sock);
@@ -147,7 +145,7 @@ static int check_tcl_fil(char *cmd, int idx, char *args)
   Tcl_SetVar(interp, "_fil2", s, 0);
   Tcl_SetVar(interp, "_fil3", args, 0);
   x = check_tcl_bind(H_fil, cmd, &fr, " $_fil1 $_fil2 $_fil3",
-		     MATCH_PARTIAL | BIND_USE_ATTR | BIND_HAS_BUILTINS);
+                     MATCH_PARTIAL | BIND_USE_ATTR | BIND_HAS_BUILTINS);
   if (x == BIND_AMBIGUOUS) {
     dprintf(idx, "Ambiguous command.\n");
     return 0;
@@ -174,16 +172,16 @@ static void dcc_files_pass(int idx, char *buf, int x)
       dprintf(idx, "Too many people are in the file system right now.\n");
       dprintf(idx, "Please try again later.\n");
       putlog(LOG_MISC, "*", "File area full: DCC chat [%s]%s", dcc[idx].nick,
-	     dcc[idx].host);
+             dcc[idx].host);
       killsock(dcc[idx].sock);
       lostdcc(idx);
       return;
     }
     dcc[idx].type = &DCC_FILES;
     if (dcc[idx].status & STAT_TELNET)
-      dprintf(idx, "\377\374\001\n");	/* turn echo back on */
+      dprintf(idx, "\377\374\001\n");   /* turn echo back on */
     putlog(LOG_FILES, "*", "File system: [%s]%s/%d", dcc[idx].nick,
-	   dcc[idx].host, dcc[idx].port);
+           dcc[idx].host, dcc[idx].port);
     if (!welcome_to_files(idx)) {
       putlog(LOG_FILES, "*", "File system broken.");
       killsock(dcc[idx].sock);
@@ -197,7 +195,7 @@ static void dcc_files_pass(int idx, char *buf, int x)
   }
   dprintf(idx, "Negative on that, Houston.\n");
   putlog(LOG_MISC, "*", "Bad password: DCC chat [%s]%s", dcc[idx].nick,
-	 dcc[idx].host);
+         dcc[idx].host);
   killsock(dcc[idx].sock);
   lostdcc(idx);
 }
@@ -219,8 +217,8 @@ static int got_files_cmd(int idx, char *msg)
 
 static void dcc_files(int idx, char *buf, int i)
 {
-  if (buf[0] &&
-      detect_dcc_flood(&dcc[idx].timeval, dcc[idx].u.file->chat, idx))
+  if (buf[0] && detect_dcc_flood(&dcc[idx].timeval, dcc[idx].u.file->chat,
+      idx))
     return;
   dcc[idx].timeval = now;
   strcpy(buf, check_tcl_filt(idx, buf));
@@ -230,17 +228,16 @@ static void dcc_files(int idx, char *buf, int i)
   if (buf[0] == ',') {
     for (i = 0; i < dcc_total; i++) {
       if ((dcc[i].type->flags & DCT_MASTER) && dcc[idx].user &&
-	  (dcc[idx].user->flags & USER_MASTER) &&
-	  ((dcc[i].type == &DCC_FILES) ||
-	   (dcc[i].u.chat->channel >= 0)) &&
-	  ((i != idx) || (dcc[idx].status & STAT_ECHO)))
-	dprintf(i, "-%s- %s\n", dcc[idx].nick, &buf[1]);
+          (dcc[idx].user->flags & USER_MASTER) &&
+          ((dcc[i].type == &DCC_FILES) || (dcc[i].u.chat->channel >= 0)) &&
+          ((i != idx) || (dcc[idx].status & STAT_ECHO)))
+        dprintf(i, "-%s- %s\n", dcc[idx].nick, &buf[1]);
     }
   } else if (got_files_cmd(idx, buf)) {
     dprintf(idx, "*** Ja mata!\n");
     flush_lines(idx, dcc[idx].u.file->chat);
     putlog(LOG_FILES, "*", "DCC user [%s]%s left file system", dcc[idx].nick,
-	   dcc[idx].host);
+           dcc[idx].host);
     set_user(&USERENTRY_DCCDIR, dcc[idx].user, dcc[idx].u.file->dir);
     if (dcc[idx].status & STAT_CHAT) {
       struct chat_info *ci;
@@ -252,15 +249,15 @@ static void dcc_files(int idx, char *buf, int i)
       dcc[idx].status &= (~STAT_CHAT);
       dcc[idx].type = &DCC_CHAT;
       if (dcc[idx].u.chat->channel >= 0) {
-	chanout_but(-1, dcc[idx].u.chat->channel,
-		    "*** %s has returned.\n", dcc[idx].nick);
-	if (dcc[idx].u.chat->channel < 100000)
-	  botnet_send_join_idx(idx, -1);
+        chanout_but(-1, dcc[idx].u.chat->channel,
+                    "*** %s has returned.\n", dcc[idx].nick);
+        if (dcc[idx].u.chat->channel < GLOBAL_CHANS)
+          botnet_send_join_idx(idx, -1);
       }
     } else {
       dprintf(idx, "Dropping connection now.\n");
       putlog(LOG_FILES, "*", "Left files: [%s]%s/%d", dcc[idx].nick,
-	     dcc[idx].host, dcc[idx].port);
+             dcc[idx].host, dcc[idx].port);
       killsock(dcc[idx].sock);
       lostdcc(idx);
     }
@@ -306,8 +303,8 @@ static int cmd_files(struct userrec *u, int idx, char *par)
   if (dccdir[0] == 0)
     dprintf(idx, "There is no file transfer area.\n");
   else if (too_many_filers()) {
-    dprintf(idx, "The maximum of %d people are in the file area right now.\n",
-	    dcc_users);
+    dprintf(idx, "The maximum of %d %s in the file area right now.\n",
+            dcc_users, (dcc_users != 1) ? "people are" : "person is");
     dprintf(idx, "Please try again later.\n");
   } else {
     if (!(atr & (USER_MASTER | USER_XFER)))
@@ -317,11 +314,10 @@ static int cmd_files(struct userrec *u, int idx, char *par)
       dprintf(idx, "Entering file system...\n");
       if (dcc[idx].u.chat->channel >= 0) {
 
-	chanout_but(-1, dcc[idx].u.chat->channel,
-		    "*** %s has left: file system\n",
-		    dcc[idx].nick);
-	if (dcc[idx].u.chat->channel < 100000)
-	  botnet_send_part_idx(idx, "file system");
+        chanout_but(-1, dcc[idx].u.chat->channel,
+                    "*** %s has left: file system\n", dcc[idx].nick);
+        if (dcc[idx].u.chat->channel < GLOBAL_CHANS)
+          botnet_send_part_idx(idx, "file system");
       }
       ci = dcc[idx].u.chat;
       dcc[idx].u.file = get_data_ptr(sizeof(struct file_info));
@@ -330,28 +326,27 @@ static int cmd_files(struct userrec *u, int idx, char *par)
       dcc[idx].type = &DCC_FILES;
       dcc[idx].status |= STAT_CHAT;
       if (!welcome_to_files(idx)) {
-	struct chat_info *ci = dcc[idx].u.file->chat;
+        struct chat_info *ci = dcc[idx].u.file->chat;
 
-	my_free(dcc[idx].u.file);
-	dcc[idx].u.chat = ci;
-	dcc[idx].type = &DCC_CHAT;
-	putlog(LOG_FILES, "*", "File system broken.");
-	if (dcc[idx].u.chat->channel >= 0) {
-	  chanout_but(-1, dcc[idx].u.chat->channel,
-		      "*** %s has returned.\n",
-		      dcc[idx].nick);
-	  if (dcc[idx].u.chat->channel < 100000)
-	    botnet_send_join_idx(idx, -1);
-	}
+        my_free(dcc[idx].u.file);
+        dcc[idx].u.chat = ci;
+        dcc[idx].type = &DCC_CHAT;
+        putlog(LOG_FILES, "*", "File system broken.");
+        if (dcc[idx].u.chat->channel >= 0) {
+          chanout_but(-1, dcc[idx].u.chat->channel,
+                      "*** %s has returned.\n", dcc[idx].nick);
+          if (dcc[idx].u.chat->channel < GLOBAL_CHANS)
+            botnet_send_join_idx(idx, -1);
+        }
       } else
-	touch_laston(u, "filearea", now);
+        touch_laston(u, "filearea", now);
     }
   }
   return 0;
 }
 
 static int _dcc_send(int idx, char *filename, char *nick, char *dir,
-		     int resend)
+                     int resend)
 {
   int x;
   char *nfn, *buf = NULL;
@@ -365,31 +360,31 @@ static int _dcc_send(int idx, char *filename, char *nick, char *dir,
   if (x == DCCSEND_FULL) {
     dprintf(idx, "Sorry, too many DCC connections.  (try again later)\n");
     putlog(LOG_FILES, "*", "DCC connections full: %sGET %s [%s]", filename,
-	   resend ? "RE" : "", dcc[idx].nick);
+           resend ? "RE" : "", dcc[idx].nick);
     return 0;
   }
   if (x == DCCSEND_NOSOCK) {
     if (reserved_port_min) {
       dprintf(idx, "All my DCC SEND ports are in use.  Try later.\n");
       putlog(LOG_FILES, "*", "DCC port in use (can't open): %sGET %s [%s]",
-	     resend ? "RE" : "", filename, dcc[idx].nick);
+             resend ? "RE" : "", filename, dcc[idx].nick);
     } else {
       dprintf(idx, "Unable to listen at a socket.\n");
       putlog(LOG_FILES, "*", "DCC socket error: %sGET %s [%s]", filename,
-	     resend ? "RE" : "", dcc[idx].nick);
+             resend ? "RE" : "", dcc[idx].nick);
     }
     return 0;
   }
   if (x == DCCSEND_BADFN) {
     dprintf(idx, "File not found ?\n");
     putlog(LOG_FILES, "*", "DCC file not found: %sGET %s [%s]", filename,
-	   resend ? "RE" : "", dcc[idx].nick);
+           resend ? "RE" : "", dcc[idx].nick);
     return 0;
   }
   if (x == DCCSEND_FEMPTY) {
     dprintf(idx, "The file is empty.  Aborted transfer.\n");
     putlog(LOG_FILES, "*", "DCC file is empty: %s [%s]", filename,
-	   dcc[idx].nick);
+           dcc[idx].nick);
     return 0;
   }
   nfn = strrchr(dir, '/');
@@ -410,7 +405,7 @@ static int _dcc_send(int idx, char *filename, char *nick, char *dir,
 
   if (egg_strcasecmp(nick, dcc[idx].nick))
     dprintf(DP_HELP, "NOTICE %s :Here is %s file from %s %s...\n", nick,
-	    resend ? "the" : "a", dcc[idx].nick, resend ? "again " : "");
+            resend ? "the" : "a", dcc[idx].nick, resend ? "again " : "");
   dprintf(idx, "%sending: %s to %s\n", resend ? "Res" : "S", nfn, nick);
   my_free(buf);
   return 1;
@@ -419,7 +414,6 @@ static int _dcc_send(int idx, char *filename, char *nick, char *dir,
 static int do_dcc_send(int idx, char *dir, char *fn, char *nick, int resend)
 {
   char *s = NULL, *s1 = NULL;
-  FILE *f;
   int x;
 
   if (nick && strlen(nick) > NICKMAX)
@@ -427,13 +421,13 @@ static int do_dcc_send(int idx, char *dir, char *fn, char *nick, int resend)
   if (dccdir[0] == 0) {
     dprintf(idx, "DCC file transfers not supported.\n");
     putlog(LOG_FILES, "*", "Refused dcc %sget %s from [%s]", resend ? "re" : "",
-	   fn, dcc[idx].nick);
+           fn, dcc[idx].nick);
     return 0;
   }
   if (strchr(fn, '/') != NULL) {
     dprintf(idx, "Filename cannot have '/' in it...\n");
     putlog(LOG_FILES, "*", "Refused dcc %sget %s from [%s]", resend ? "re" : "",
-	   fn, dcc[idx].nick);
+           fn, dcc[idx].nick);
     return 0;
   }
   if (dir[0]) {
@@ -443,15 +437,15 @@ static int do_dcc_send(int idx, char *dir, char *fn, char *nick, int resend)
     s = nmalloc(strlen(dccdir) + strlen(fn) + 1);
     sprintf(s, "%s%s", dccdir, fn);
   }
-  f = fopen(s, "r");
-  if (f == NULL) {
+
+  if (!file_readable(s)) {
     dprintf(idx, "No such file.\n");
-    putlog(LOG_FILES, "*", "Refused dcc %sget %s from [%s]", resend ? "re" : "",
-	   fn, dcc[idx].nick);
+    putlog(LOG_FILES, "*", "Refused dcc %sget %s from [%s]", resend ? "re" :
+           "", fn, dcc[idx].nick);
     my_free(s);
     return 0;
   }
-  fclose(f);
+
   if (!nick || !nick[0])
     nick = dcc[idx].nick;
   /* Already have too many transfers active for this user?  queue it */
@@ -476,8 +470,8 @@ static int do_dcc_send(int idx, char *dir, char *fn, char *nick, int resend)
     if (copyfile(s, s1) != 0) {
       dprintf(idx, "Can't make temporary copy of file!\n");
       putlog(LOG_FILES | LOG_MISC, "*",
-	     "Refused dcc %sget %s: copy to %s FAILED!",
-	     resend ? "re" : "", fn, tempdir);
+             "Refused dcc %sget %s: copy to %s FAILED!",
+             resend ? "re" : "", fn, tempdir);
       my_free(s);
       my_free(s1);
       return 0;
@@ -502,6 +496,7 @@ static int builtin_fil STDVAR
   Function F = (Function) cd;
 
   BADARGS(4, 4, " hand idx param");
+  
   idx = findanyidx(atoi(argv[2]));
   if (idx < 0 && dcc[idx].type != &DCC_FILES) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
@@ -511,7 +506,7 @@ static int builtin_fil STDVAR
     Tcl_AppendResult(irp, "break", NULL);
     return TCL_OK;
   }
-  (F)(idx, argv[3]);
+  (F) (idx, argv[3]);
   Tcl_ResetResult(irp);
   return TCL_OK;
 }
@@ -520,7 +515,7 @@ static void tout_dcc_files_pass(int i)
 {
   dprintf(i, "Timeout.\n");
   putlog(LOG_MISC, "*", "Password timeout on dcc chat: [%s]%s", dcc[i].nick,
-	 dcc[i].host);
+         dcc[i].host);
   killsock(dcc[i].sock);
   lostdcc(i);
 }
@@ -528,11 +523,11 @@ static void tout_dcc_files_pass(int i)
 static void disp_dcc_files(int idx, char *buf)
 {
   sprintf(buf, "file  flags: %c%c%c%c%c",
-	  dcc[idx].status & STAT_CHAT ? 'C' : 'c',
-	  dcc[idx].status & STAT_PARTY ? 'P' : 'p',
-	  dcc[idx].status & STAT_TELNET ? 'T' : 't',
-	  dcc[idx].status & STAT_ECHO ? 'E' : 'e',
-	  dcc[idx].status & STAT_PAGE ? 'P' : 'p');
+          dcc[idx].status & STAT_CHAT ? 'C' : 'c',
+          dcc[idx].status & STAT_PARTY ? 'P' : 'p',
+          dcc[idx].status & STAT_TELNET ? 'T' : 't',
+          dcc[idx].status & STAT_ECHO ? 'E' : 'e',
+          dcc[idx].status & STAT_PAGE ? 'P' : 'p');
 }
 
 static void disp_dcc_files_pass(int idx, char *buf)
@@ -553,7 +548,7 @@ static void eof_dcc_files(int idx)
 {
   dcc[idx].u.file->chat->con_flags = 0;
   putlog(LOG_MISC, "*", "Lost dcc connection to %s (%s/%d)", dcc[idx].nick,
-	 dcc[idx].host, dcc[idx].port);
+         dcc[idx].host, dcc[idx].port);
   killsock(dcc[idx].sock);
   lostdcc(idx);
 }
@@ -578,30 +573,26 @@ static void out_dcc_files(int idx, char *buf, void *x)
     tputs(dcc[idx].sock, buf, strlen(buf));
 }
 
-static cmd_t mydcc[] =
-{
-  {"files",		"-",	cmd_files,		NULL},
-  {NULL,		NULL,	NULL,			NULL}
+static cmd_t mydcc[] = {
+  {"files", "-",  cmd_files, NULL},
+  {NULL,    NULL, NULL,      NULL}
 };
 
-static tcl_strings mystrings[] =
-{
-  {"files-path",	dccdir,		120,	STR_DIR | STR_PROTECT},
-  {"incoming-path",	dccin,		120,	STR_DIR | STR_PROTECT},
-  {"filedb-path",	filedb_path,	120,	STR_DIR | STR_PROTECT},
-  {NULL,		NULL,		0,	0}
+static tcl_strings mystrings[] = {
+  {"files-path",    dccdir,      120, STR_DIR | STR_PROTECT},
+  {"incoming-path", dccin,       120, STR_DIR | STR_PROTECT},
+  {"filedb-path",   filedb_path, 120, STR_DIR | STR_PROTECT},
+  {NULL,            NULL,        0,                       0}
 };
 
-static tcl_ints myints[] =
-{
-  {"max-filesize",	&dcc_maxsize},
-  {"max-file-users",	&dcc_users},
-  {"upload-to-pwd",	&upload_to_cd},
-  {NULL,		NULL}
+static tcl_ints myints[] = {
+  {"max-filesize",    &dcc_maxsize},
+  {"max-file-users",    &dcc_users},
+  {"upload-to-pwd",  &upload_to_cd},
+  {NULL,                      NULL}
 };
 
-static struct dcc_table DCC_FILES_PASS =
-{
+static struct dcc_table DCC_FILES_PASS = {
   "FILES_PASS",
   0,
   eof_dcc_files,
@@ -620,7 +611,7 @@ static void filesys_dcc_send_hostresolved(int);
 /* Received a ctcp-dcc.
  */
 static void filesys_dcc_send(char *nick, char *from, struct userrec *u,
-			     char *text)
+                             char *text)
 {
   char *param, *ip, *prt, *buf = NULL, *msg;
   int atr = u ? u->flags : 0, i;
@@ -630,55 +621,50 @@ static void filesys_dcc_send(char *nick, char *from, struct userrec *u,
   strcpy(buf, text);
   param = newsplit(&msg);
   if (!(atr & USER_XFER)) {
-    putlog(LOG_FILES, "*",
-	   "Refused DCC SEND %s (no access): %s!%s", param,
-	   nick, from);
+    putlog(LOG_FILES, "*", "Refused DCC SEND %s (no access): %s!%s", param,
+           nick, from);
+    if (!quiet_reject)
+      dprintf(DP_HELP, "NOTICE %s :No access\n", nick);
   } else if (!dccin[0] && !upload_to_cd) {
-    dprintf(DP_HELP,
-	    "NOTICE %s :DCC file transfers not supported.\n", nick);
-    putlog(LOG_FILES, "*",
-	   "Refused dcc send %s from %s!%s", param, nick, from);
+    dprintf(DP_HELP, "NOTICE %s :DCC file transfers not supported.\n", nick);
+    putlog(LOG_FILES, "*", "Refused dcc send %s from %s!%s", param, nick, from);
   } else if (strchr(param, '/')) {
-    dprintf(DP_HELP,
-	    "NOTICE %s :Filename cannot have '/' in it...\n", nick);
-    putlog(LOG_FILES, "*",
-	   "Refused dcc send %s from %s!%s", param, nick, from);
+    dprintf(DP_HELP, "NOTICE %s :Filename cannot have '/' in it...\n", nick);
+    putlog(LOG_FILES, "*", "Refused dcc send %s from %s!%s", param, nick, from);
   } else {
     ip = newsplit(&msg);
     prt = newsplit(&msg);
     if (atoi(prt) < 1024 || atoi(prt) > 65535) {
       /* Invalid port */
       dprintf(DP_HELP, "NOTICE %s :%s (invalid port)\n", nick,
-	      DCC_CONNECTFAILED1);
+              DCC_CONNECTFAILED1);
       putlog(LOG_FILES, "*", "Refused dcc send %s (%s): invalid port", param,
-	     nick);
+             nick);
     } else if (atoi(msg) == 0) {
-      dprintf(DP_HELP,
-	      "NOTICE %s :Sorry, file size info must be included.\n",
-	      nick);
+      dprintf(DP_HELP, "NOTICE %s :Sorry, file size info must be included.\n",
+              nick);
       putlog(LOG_FILES, "*", "Refused dcc send %s (%s): no file size",
-	     param, nick);
+             param, nick);
     } else if (dcc_maxsize && (atoi(msg) > (dcc_maxsize * 1024))) {
       dprintf(DP_HELP, "NOTICE %s :Sorry, file too large.\n", nick);
       putlog(LOG_FILES, "*", "Refused dcc send %s (%s): file too large", param,
-	     nick);
+             nick);
     } else {
       /* This looks like a good place for a sanity check. */
       if (!sanitycheck_dcc(nick, from, ip, prt)) {
-	my_free(buf);
-	return;
+        my_free(buf);
+        return;
       }
       i = new_dcc(&DCC_DNSWAIT, sizeof(struct dns_info));
       if (i < 0) {
-	dprintf(DP_HELP, "NOTICE %s :Sorry, too many DCC connections.\n",
-		nick);
-	putlog(LOG_MISC, "*", "DCC connections full: SEND %s (%s!%s)",
-	       param, nick, from);
-	return;
+        dprintf(DP_HELP, "NOTICE %s :Sorry, too many DCC connections.\n", nick);
+        putlog(LOG_MISC, "*", "DCC connections full: SEND %s (%s!%s)", param,
+               nick, from);
+        return;
       }
       dcc[i].addr = my_atoul(ip);
       dcc[i].port = atoi(prt);
-      dcc[i].sock = (-1);
+      dcc[i].sock = -1;
       dcc[i].user = u;
       strcpy(dcc[i].nick, nick);
       strcpy(dcc[i].host, from);
@@ -728,7 +714,6 @@ static char *mktempfile(char *filename)
 
 static void filesys_dcc_send_hostresolved(int i)
 {
-  FILE *f;
   char *s1, *param, prt[100], ip[100], *tempf;
   int len = dcc[i].u.dns->ibuf, j;
 
@@ -766,28 +751,28 @@ static void filesys_dcc_send_hostresolved(int i)
     strcpy(dcc[i].u.xfer->dir, dccin);
   dcc[i].u.xfer->length = len;
   s1 = nmalloc(strlen(dcc[i].u.xfer->dir) +
-	       strlen(dcc[i].u.xfer->origname) + 1);
+               strlen(dcc[i].u.xfer->origname) + 1);
   sprintf(s1, "%s%s", dcc[i].u.xfer->dir, dcc[i].u.xfer->origname);
-  f = fopen(s1, "r");
-  my_free(s1);
-  if (f) {
-    fclose(f);
-    dprintf(DP_HELP, "NOTICE %s :File `%s' already exists.\n",
-	    dcc[i].nick, dcc[i].u.xfer->origname);
+
+  if (file_readable(s1)) {
+    dprintf(DP_HELP, "NOTICE %s :File `%s' already exists.\n", dcc[i].nick,
+            dcc[i].u.xfer->origname);
     lostdcc(i);
+    my_free(s1);
   } else {
+    my_free(s1);
     /* Check for dcc-sends in process with the same filename */
     for (j = 0; j < dcc_total; j++)
       if (j != i) {
-        if ((dcc[j].type->flags & (DCT_FILETRAN | DCT_FILESEND))
-	    == (DCT_FILETRAN | DCT_FILESEND)) {
-	  if (!strcmp(dcc[i].u.xfer->origname, dcc[j].u.xfer->origname)) {
-	    dprintf(DP_HELP, "NOTICE %s :File `%s' is already being sent.\n",
-		    dcc[i].nick, dcc[i].u.xfer->origname);
-	    lostdcc(i);
-	    return;
-	  }
-	}
+        if ((dcc[j].type->flags & (DCT_FILETRAN | DCT_FILESEND)) ==
+            (DCT_FILETRAN | DCT_FILESEND)) {
+          if (!strcmp(dcc[i].u.xfer->origname, dcc[j].u.xfer->origname)) {
+            dprintf(DP_HELP, "NOTICE %s :File `%s' is already being sent.\n",
+                    dcc[i].nick, dcc[i].u.xfer->origname);
+            lostdcc(i);
+            return;
+          }
+        }
       }
     /* Put uploads in /tmp first */
     s1 = nmalloc(strlen(tempdir) + strlen(dcc[i].u.xfer->filename) + 1);
@@ -796,27 +781,31 @@ static void filesys_dcc_send_hostresolved(int i)
     my_free(s1);
     if (dcc[i].u.xfer->f == NULL) {
       dprintf(DP_HELP,
-	      "NOTICE %s :Can't create file `%s' (temp dir error)\n",
-	      dcc[i].nick, dcc[i].u.xfer->origname);
+              "NOTICE %s :Can't create file `%s' (temp dir error)\n",
+              dcc[i].nick, dcc[i].u.xfer->origname);
       lostdcc(i);
     } else {
       dcc[i].timeval = now;
+#ifdef USE_IPV6
+      dcc[i].sock = getsock(SOCK_BINARY, getprotocol(ip));
+#else
       dcc[i].sock = getsock(SOCK_BINARY);
+#endif /* USE_IPV6 */
       if (dcc[i].sock < 0 || open_telnet_dcc(dcc[i].sock, ip, prt) < 0)
-	dcc[i].type->eof(i);
+        dcc[i].type->eof(i);
     }
   }
 }
 
-/* This only handles CHAT requests, otherwise it's handled in filesys.
+/* This only handles CHAT requests, otherwise it's handled in transfer.
  */
 static int filesys_DCC_CHAT(char *nick, char *from, char *handle,
-			    char *object, char *keyword, char *text)
+                            char *object, char *keyword, char *text)
 {
   char *param, *ip, *prt, buf[512], *msg = buf;
   int i, sock;
   struct userrec *u = get_user_by_handle(userlist, handle);
-  struct flag_record fr = {FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0};
+  struct flag_record fr = { FR_GLOBAL | FR_CHAN | FR_ANYWH, 0, 0, 0, 0, 0 };
 
   if (egg_strcasecmp(object, botname))
     return 0;
@@ -832,7 +821,7 @@ static int filesys_DCC_CHAT(char *nick, char *from, char *handle,
   if (dcc_total == max_dcc) {
     putlog(LOG_MISC, "*", DCC_TOOMANYDCCS2, "CHAT(file)", param, nick, from);
   } else if (glob_party(fr) || (!require_p && chan_op(fr)))
-    return 0;			/* Allow ctcp.so to pick up the chat */
+    return 0;                   /* Allow ctcp.so to pick up the chat */
   else if (!glob_xfer(fr)) {
     if (!quiet_reject)
       dprintf(DP_HELP, "NOTICE %s :%s\n", nick, DCC_REFUSED2);
@@ -846,21 +835,24 @@ static int filesys_DCC_CHAT(char *nick, char *from, char *handle,
   } else {
     ip = newsplit(&msg);
     prt = newsplit(&msg);
+#ifdef USE_IPV6
+    sock = getsock(0, getprotocol(ip));
+#else
     sock = getsock(0);
+#endif /* USE_IPV6 */
     if (sock < 0 || open_telnet_dcc(sock, ip, prt) < 0) {
       neterror(buf);
       if (!quiet_reject)
-        dprintf(DP_HELP, "NOTICE %s :%s (%s)\n", nick,
-	        DCC_CONNECTFAILED1, buf);
-      putlog(LOG_MISC, "*", "%s: CHAT(file) (%s!%s)", DCC_CONNECTFAILED2,
-	     nick, from);
+        dprintf(DP_HELP, "NOTICE %s :%s (%s)\n", nick, DCC_CONNECTFAILED1, buf);
+      putlog(LOG_MISC, "*", "%s: CHAT(file) (%s!%s)", DCC_CONNECTFAILED2, nick,
+             from);
       putlog(LOG_MISC, "*", "    (%s)", buf);
       killsock(sock);
     } else if (atoi(prt) < 1024 || atoi(prt) > 65535) {
       /* Invalid port */
       if (!quiet_reject)
         dprintf(DP_HELP, "NOTICE %s :%s (invalid port)\n", nick,
-	        DCC_CONNECTFAILED1);
+                DCC_CONNECTFAILED1);
       putlog(LOG_FILES, "*", "%s: %s!%s", DCC_REFUSED7, nick, from);
 
     } else {
@@ -882,10 +874,9 @@ static int filesys_DCC_CHAT(char *nick, char *from, char *handle,
   return 1;
 }
 
-static cmd_t myctcp[] =
-{
-  {"DCC",	"",	filesys_DCC_CHAT,		"files:DCC"},
-  {NULL,	NULL,	NULL,				NULL}
+static cmd_t myctcp[] = {
+  {"DCC", "",   filesys_DCC_CHAT, "files:DCC"},
+  {NULL,  NULL, NULL,                    NULL}
 };
 
 static void init_server_ctcps(char *module)
@@ -896,10 +887,9 @@ static void init_server_ctcps(char *module)
     add_builtins(H_ctcp, myctcp);
 }
 
-static cmd_t myload[] =
-{
-  {"server",	"",	(Function) init_server_ctcps,	"filesys:server"},
-  {NULL,	NULL,	NULL,				NULL}
+static cmd_t myload[] = {
+  {"server", "",   (Function) init_server_ctcps, "filesys:server"},
+  {NULL,     NULL, NULL,                                     NULL}
 };
 
 static int filesys_expmem()
@@ -909,20 +899,28 @@ static int filesys_expmem()
 
 static void filesys_report(int idx, int details)
 {
-  if (dccdir[0]) {
-    dprintf(idx, "    DCC file path: %s", dccdir);
-    if (upload_to_cd)
-      dprintf(idx, "\n        incoming: (go to the current dir)\n");
-    else if (dccin[0])
-      dprintf(idx, "\n        incoming: %s\n", dccin);
-    else
-      dprintf(idx, "    (no uploads)\n");
-    if (dcc_users)
-      dprintf(idx, "        max users is %d\n", dcc_users);
-    if ((upload_to_cd) || (dccin[0]))
-      dprintf(idx, "    DCC max file size: %dk\n", dcc_maxsize);
-  } else
-    dprintf(idx, "  (Filesystem module loaded, but no active dcc path.)\n");
+  if (details) {
+    int size = filesys_expmem();
+
+    if (dccdir[0]) {
+      dprintf(idx, "    DCC file path: %s", dccdir);
+      if (upload_to_cd)
+        dprintf(idx, "\n      Incoming: (user's current directory)\n");
+      else if (dccin[0])
+        dprintf(idx, "\n      Incoming: %s\n", dccin);
+      else
+        dprintf(idx, " (no uploads)\n");
+
+      if (dcc_users)
+        dprintf(idx, "    Max users: %d\n", dcc_users);
+      if (upload_to_cd || dccin[0])
+        dprintf(idx, "    Max upload file size: %dk\n", dcc_maxsize);
+    } else
+      dprintf(idx, "    Filesystem module loaded, but no active dcc path "
+              "exists.\n");
+    dprintf(idx, "    Using %d byte%s of memory\n", size,
+            (size != 1) ? "s" : "");
+  }
 }
 
 static char *filesys_close()
@@ -930,12 +928,13 @@ static char *filesys_close()
   int i;
   p_tcl_bind_list H_ctcp;
 
-  putlog(LOG_MISC, "*", "Unloading filesystem; killing all filesystem connections.");
+  putlog(LOG_MISC, "*", "Unloading filesystem; killing all filesystem "
+         "connections.");
   for (i = 0; i < dcc_total; i++)
     if (dcc[i].type == &DCC_FILES) {
       dprintf(i, DCC_BOOTED1);
-      dprintf(i,
-	 "You have been booted from the filesystem, module unloaded.\n");
+      dprintf(i, "You have been booted from the filesystem, module "
+              "unloaded.\n");
       killsock(dcc[i].sock);
       lostdcc(i);
     } else if (dcc[i].type == &DCC_FILES_PASS) {
@@ -960,8 +959,7 @@ static char *filesys_close()
 
 EXPORT_SCOPE char *filesys_start();
 
-static Function filesys_table[] =
-{
+static Function filesys_table[] = {
   /* 0 - 3 */
   (Function) filesys_start,
   (Function) filesys_close,
@@ -976,18 +974,18 @@ static Function filesys_table[] =
   (Function) & H_fil,
 };
 
-char *filesys_start(Function * global_funcs)
+char *filesys_start(Function *global_funcs)
 {
   global = global_funcs;
 
   module_register(MODULE_NAME, filesys_table, 2, 0);
   if (!module_depend(MODULE_NAME, "eggdrop", 106, 0)) {
     module_undepend(MODULE_NAME);
-    return "You need at least eggdrop1.6.0 to use the filesystem module.";
+    return "This module requires Eggdrop 1.6.0 or later.";
   }
   if (!(transfer_funcs = module_depend(MODULE_NAME, "transfer", 2, 0))) {
     module_undepend(MODULE_NAME);
-    return "You need the transfer module to use the filesystem module.";
+    return "This module requires transfer module 2.0 or later.";
   }
   add_tcl_commands(mytcls);
   add_tcl_strings(mystrings);
@@ -999,9 +997,9 @@ char *filesys_start(Function * global_funcs)
   add_help_reference("filesys.help");
   init_server_ctcps(0);
   my_memcpy(&USERENTRY_DCCDIR, &USERENTRY_INFO,
-	    sizeof(struct user_entry_type) - sizeof(char *));
+            sizeof(struct user_entry_type) - sizeof(char *));
 
-  USERENTRY_DCCDIR.got_share = 0;	/* We dont want it shared tho */
+  USERENTRY_DCCDIR.got_share = 0;       /* We dont want it shared tho */
   add_entry_type(&USERENTRY_DCCDIR);
   DCC_FILES_PASS.timeout_val = &password_timeout;
   add_lang_section("filesys");
