@@ -1,11 +1,11 @@
 /*
  * irc.h -- part of irc.mod
  *
- * $Id: irc.h,v 1.17 2002/01/02 03:46:39 guppy Exp $
+ * $Id: irc.h,v 1.24 2003/01/29 05:48:42 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,55 +34,61 @@
 #define check_tcl_mode(a,b,c,d,e,f) check_tcl_kickmode(a,b,c,d,e,f,H_mode)
 #define check_tcl_kick(a,b,c,d,e,f) check_tcl_kickmode(a,b,c,d,e,f,H_kick)
 
-#define REVENGE_KICK 1		/* Kicked victim	*/
-#define REVENGE_DEOP 2		/* Took op		*/
+#define REVENGE_KICK 1          /* Kicked victim        */
+#define REVENGE_DEOP 2          /* Took op              */
 
 #ifdef MAKING_IRC
 static void check_tcl_need(char *, char *);
 static void check_tcl_kickmode(char *, char *, struct userrec *, char *,
-			       char *, char *, p_tcl_bind_list);
+                               char *, char *, p_tcl_bind_list);
 static void check_tcl_joinspltrejn(char *, char *, struct userrec *, char *,
-			       p_tcl_bind_list);
+                                   p_tcl_bind_list);
 static void check_tcl_part(char *, char *, struct userrec *, char *, char *);
 static void check_tcl_signtopcnick(char *, char *, struct userrec *u, char *,
-				   char *, p_tcl_bind_list);
+                                   char *, p_tcl_bind_list);
 static void check_tcl_pubm(char *, char *, char *, char *);
 static int check_tcl_pub(char *, char *, char *, char *);
 static int me_op(struct chanset_t *);
+static int me_halfop(struct chanset_t *);
+static int me_voice(struct chanset_t *);
 static int any_ops(struct chanset_t *);
 static int hand_on_chan(struct chanset_t *, struct userrec *);
 static char *getchanmode(struct chanset_t *);
 static void flush_mode(struct chanset_t *, int);
+static void set_delay(struct chanset_t *, char *);
 
 /* reset(bans|exempts|invites) are now just macros that call resetmasks
  * in order to reduce the code duplication. <cybah>
  */
-#define resetbans(chan)	    resetmasks((chan), (chan)->channel.ban,	\
-				       (chan)->bans, global_bans, 'b')
-#define resetexempts(chan)  resetmasks((chan), (chan)->channel.exempt,	\
-				       (chan)->exempts, global_exempts, 'e')
-#define resetinvites(chan)  resetmasks((chan), (chan)->channel.invite,	\
-				       (chan)->invites, global_invites, 'I')
+#define resetbans(chan)     resetmasks((chan), (chan)->channel.ban,          \
+                                       (chan)->bans, global_bans, 'b')
+#define resetexempts(chan)  resetmasks((chan), (chan)->channel.exempt,       \
+                                       (chan)->exempts, global_exempts, 'e')
+#define resetinvites(chan)  resetmasks((chan), (chan)->channel.invite,       \
+                                       (chan)->invites, global_invites, 'I')
 
 static void reset_chan_info(struct chanset_t *);
 static void recheck_channel(struct chanset_t *, int);
 static void set_key(struct chanset_t *, char *);
 static void maybe_revenge(struct chanset_t *, char *, char *, int);
 static int detect_chan_flood(char *, char *, char *, struct chanset_t *, int,
-			     char *);
+                             char *);
 static void newmask(masklist *, char *, char *);
 static char *quickban(struct chanset_t *, char *);
 static void got_op(struct chanset_t *chan, char *nick, char *from, char *who,
- 		   struct userrec *opu, struct flag_record *opper);
+                   struct userrec *opu, struct flag_record *opper);
+static void got_halfop(struct chanset_t *chan, char *nick, char *from,
+                       char *who, struct userrec *opu,
+                       struct flag_record *opper);
 static int killmember(struct chanset_t *chan, char *nick);
 static void check_lonely_channel(struct chanset_t *chan);
 static int gotmode(char *, char *);
 
 #define newban(chan, mask, who)         newmask((chan)->channel.ban, mask, who)
 #define newexempt(chan, mask, who)      newmask((chan)->channel.exempt, mask, \
-						who)
+                                                who)
 #define newinvite(chan, mask, who)      newmask((chan)->channel.invite, mask, \
-						who)
+                                                who)
 
 #else
 /* 4 - 7 */
@@ -108,7 +114,11 @@ static int gotmode(char *, char *);
 /* 20 - 23 */
 /* check_this_ban is here. */
 /* check_this_user is here. */
+#define me_halfop ((int(*)(struct chanset_t *))irc_funcs[22])
+#define me_voice ((int(*)(struct chanset_t *))irc_funcs[23])
+/* 24 - 27 */
+#define getchanmode ((char *(*)(struct chanset_t *))irc_funcs[24])
 
-#endif				/* MAKING_IRC */
+#endif /* MAKING_IRC */
 
-#endif				/* _EGG_MOD_IRC_IRC_H */
+#endif /* _EGG_MOD_IRC_IRC_H */
