@@ -1,11 +1,11 @@
 /*
  * tclirc.c -- part of irc.mod
  *
- * $Id: tclirc.c,v 1.31 2002/01/02 03:46:39 guppy Exp $
+ * $Id: tclirc.c,v 1.43 2003/02/27 10:18:40 tothwolf Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,14 +26,16 @@
  */
 static int tcl_chanlist STDVAR
 {
+  char nuh[1024];
   int f;
   memberlist *m;
   struct chanset_t *chan;
-  struct flag_record plus = {FR_CHAN | FR_GLOBAL | FR_BOT, 0, 0, 0, 0, 0},
- 		     minus = {FR_CHAN | FR_GLOBAL | FR_BOT, 0, 0, 0, 0, 0},
-		     user = {FR_CHAN | FR_GLOBAL | FR_BOT, 0, 0, 0, 0, 0};
+  struct flag_record plus = { FR_CHAN | FR_GLOBAL | FR_BOT, 0, 0, 0, 0, 0 },
+                     minus = { FR_CHAN | FR_GLOBAL | FR_BOT, 0, 0, 0, 0, 0},
+                     user = { FR_CHAN | FR_GLOBAL | FR_BOT, 0, 0, 0, 0, 0 };
 
   BADARGS(2, 3, " channel ?flags?");
+
   chan = findchan_by_dname(argv[1]);
   if (!chan) {
     Tcl_AppendResult(irp, "invalid channel: ", argv[1], NULL);
@@ -46,20 +48,24 @@ static int tcl_chanlist STDVAR
     return TCL_OK;
   }
   break_down_flags(argv[2], &plus, &minus);
-  f = (minus.global || minus.udef_global ||
-       minus.chan || minus.udef_chan || minus.bot);
+  f = (minus.global || minus.udef_global || minus.chan || minus.udef_chan ||
+       minus.bot);
   /* Return empty set if asked for flags but flags don't exist */
-  if (!plus.global && !plus.udef_global &&
-      !plus.chan && !plus.udef_chan && !plus.bot && !f)
+  if (!plus.global &&!plus.udef_global && !plus.chan && !plus.udef_chan &&
+      !plus.bot && !f)
     return TCL_OK;
   minus.match = plus.match ^ (FR_AND | FR_OR);
 
   for (m = chan->channel.member; m && m->nick[0]; m = m->next) {
+    if (!m->user) {
+      egg_snprintf(nuh, sizeof nuh, "%s!%s", m->nick, m->userhost);
+      m->user = get_user_by_host(nuh);
+    }
     get_user_flagrec(m->user, &user, argv[1]);
     user.match = plus.match;
     if (flagrec_eq(&plus, &user)) {
       if (!f || !flagrec_eq(&minus, &user))
-	Tcl_AppendElement(irp, m->nick);
+        Tcl_AppendElement(irp, m->nick);
     }
   }
   return TCL_OK;
@@ -70,6 +76,7 @@ static int tcl_botisop STDVAR
   struct chanset_t *chan, *thechan = NULL;
 
   BADARGS(1, 2, " ?channel?");
+
   if (argc > 1) {
     chan = findchan_by_dname(argv[1]);
     thechan = chan;
@@ -78,8 +85,8 @@ static int tcl_botisop STDVAR
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
-   
+    chan = chanset;
+
   while (chan && (thechan == NULL || thechan == chan)) {
     if (me_op(chan)) {
       Tcl_AppendResult(irp, "1", NULL);
@@ -91,11 +98,39 @@ static int tcl_botisop STDVAR
   return TCL_OK;
 }
 
+static int tcl_botishalfop STDVAR
+{
+  struct chanset_t *chan, *thechan = NULL;
+
+  BADARGS(1, 2, " ?channel?");
+
+  if (argc > 1) {
+    chan = findchan_by_dname(argv[1]);
+    thechan = chan;
+    if (!thechan) {
+      Tcl_AppendResult(irp, "illegal channel: ", argv[1], NULL);
+      return TCL_ERROR;
+    }
+  } else
+    chan = chanset;
+
+  while (chan && (thechan == NULL || thechan == chan)) {
+    if (me_halfop(chan)) {
+      Tcl_AppendResult(irp, "1", NULL);
+      return TCL_OK;
+    }
+    chan = chan->next;
+  }
+  Tcl_AppendResult(irp, "0", NULL);
+  return TCL_OK;
+}
+
 static int tcl_ischanjuped STDVAR
 {
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[1], NULL);
@@ -114,6 +149,7 @@ static int tcl_botisvoice STDVAR
   memberlist *mx;
 
   BADARGS(1, 2, " ?channel?");
+
   if (argc > 1) {
     chan = findchan_by_dname(argv[1]);
     thechan = chan;
@@ -122,8 +158,8 @@ static int tcl_botisvoice STDVAR
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
-    
+    chan = chanset;
+
   while (chan && (thechan == NULL || thechan == chan)) {
     if ((mx = ismember(chan, botname)) && chan_hasvoice(mx)) {
       Tcl_AppendResult(irp, "1", NULL);
@@ -140,6 +176,7 @@ static int tcl_botonchan STDVAR
   struct chanset_t *chan, *thechan = NULL;
 
   BADARGS(1, 2, " ?channel?");
+
   if (argc > 1) {
     chan = findchan_by_dname(argv[1]);
     thechan = chan;
@@ -148,7 +185,7 @@ static int tcl_botonchan STDVAR
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
+    chan = chanset;
 
   while (chan && (thechan == NULL || thechan == chan)) {
     if (ismember(chan, botname)) {
@@ -157,7 +194,7 @@ static int tcl_botonchan STDVAR
     }
     chan = chan->next;
   }
-  Tcl_AppendResult(irp, "0", NULL); 
+  Tcl_AppendResult(irp, "0", NULL);
   return TCL_OK;
 }
 
@@ -165,8 +202,9 @@ static int tcl_isop STDVAR
 {
   struct chanset_t *chan, *thechan = NULL;
   memberlist *mx;
-      
-  BADARGS(2, 3, " ?nick channel?");
+
+  BADARGS(2, 3, " nick ?channel?");
+  
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
@@ -175,8 +213,8 @@ static int tcl_isop STDVAR
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
-  
+    chan = chanset;
+
   while (chan && (thechan == NULL || thechan == chan)) {
     if ((mx = ismember(chan, argv[1])) && chan_hasop(mx)) {
       Tcl_AppendResult(irp, "1", NULL);
@@ -188,12 +226,41 @@ static int tcl_isop STDVAR
   return TCL_OK;
 }
 
+static int tcl_ishalfop STDVAR
+{
+  struct chanset_t *chan, *thechan = NULL;
+  memberlist *mx;
+
+  BADARGS(2, 3, " nick ?channel?");
+
+  if (argc > 2) {
+    chan = findchan_by_dname(argv[2]);
+    thechan = chan;
+    if (!thechan) {
+      Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
+      return TCL_ERROR;
+    }
+  } else
+    chan = chanset;
+
+  while (chan && (thechan == NULL || thechan == chan)) {
+    if ((mx = ismember(chan, argv[1])) && chan_hashalfop(mx)) {
+      Tcl_AppendResult(irp, "1", NULL);
+      return TCL_OK;
+    }
+    chan = chan->next;
+  }
+  Tcl_AppendResult(irp, "0", NULL);
+  return TCL_OK;
+}
+
 static int tcl_isvoice STDVAR
 {
   struct chanset_t *chan, *thechan = NULL;
   memberlist *mx;
 
-  BADARGS(2, 3, " ?nick channel?");
+  BADARGS(2, 3, " nick ?channel?");
+
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
@@ -202,8 +269,8 @@ static int tcl_isvoice STDVAR
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
-    
+    chan = chanset;
+
   while (chan && (thechan == NULL || thechan == chan)) {
     if ((mx = ismember(chan, argv[1])) && chan_hasvoice(mx)) {
       Tcl_AppendResult(irp, "1", NULL);
@@ -221,6 +288,7 @@ static int tcl_wasop STDVAR
   memberlist *mx;
 
   BADARGS(3, 3, " nick channel");
+  
   chan = findchan_by_dname(argv[2]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -233,21 +301,40 @@ static int tcl_wasop STDVAR
   return TCL_OK;
 }
 
+static int tcl_washalfop STDVAR
+{
+  struct chanset_t *chan;
+  memberlist *mx;
+
+  BADARGS(3, 3, " nick channel");
+  
+  chan = findchan_by_dname(argv[2]);
+  if (chan == NULL) {
+    Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
+    return TCL_ERROR;
+  }
+  if ((mx = ismember(chan, argv[1])) && chan_washalfop(mx))
+    Tcl_AppendResult(irp, "1", NULL);
+  else
+    Tcl_AppendResult(irp, "0", NULL);
+  return TCL_OK;
+}
 
 static int tcl_onchan STDVAR
 {
   struct chanset_t *chan, *thechan = NULL;
 
   BADARGS(2, 3, " nickname ?channel?");
+
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
-    if (!thechan) { 
+    if (!thechan) {
       Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
+    chan = chanset;
 
   while (chan && (thechan == NULL || thechan == chan)) {
     if (ismember(chan, argv[1])) {
@@ -262,10 +349,12 @@ static int tcl_onchan STDVAR
 
 static int tcl_handonchan STDVAR
 {
+  char nuh[1024];
   struct chanset_t *chan, *thechan = NULL;
   memberlist *m;
 
   BADARGS(2, 3, " handle ?channel?");
+
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
@@ -274,13 +363,17 @@ static int tcl_handonchan STDVAR
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
+    chan = chanset;
 
   while (chan && (thechan == NULL || thechan == chan)) {
     for (m = chan->channel.member; m && m->nick[0]; m = m->next) {
+      if (!m->user) {
+        egg_snprintf(nuh, sizeof nuh, "%s!%s", m->nick, m->userhost);
+        m->user = get_user_by_host(nuh);
+      }
       if (m->user && !rfc_casecmp(m->user->handle, argv[1])) {
-	Tcl_AppendResult(irp, "1", NULL);
-	return TCL_OK;
+        Tcl_AppendResult(irp, "1", NULL);
+        return TCL_OK;
       }
     }
     chan = chan->next;
@@ -294,6 +387,7 @@ static int tcl_ischanban STDVAR
   struct chanset_t *chan;
 
   BADARGS(3, 3, " ban channel");
+  
   chan = findchan_by_dname(argv[2]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -311,6 +405,7 @@ static int tcl_ischanexempt STDVAR
   struct chanset_t *chan;
 
   BADARGS(3, 3, " exempt channel");
+  
   chan = findchan_by_dname(argv[2]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -328,6 +423,7 @@ static int tcl_ischaninvite STDVAR
   struct chanset_t *chan;
 
   BADARGS(3, 3, " invite channel");
+  
   chan = findchan_by_dname(argv[2]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -345,7 +441,8 @@ static int tcl_getchanhost STDVAR
   struct chanset_t *chan, *thechan = NULL;
   memberlist *m;
 
-  BADARGS(2, 3, " nickname ?channel?");	/* drummer */
+  BADARGS(2, 3, " nickname ?channel?");
+
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
@@ -353,7 +450,7 @@ static int tcl_getchanhost STDVAR
       Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
       return TCL_ERROR;
     }
-  } else 
+  } else
     chan = chanset;
 
   while (chan && (thechan == NULL || thechan == chan)) {
@@ -373,16 +470,17 @@ static int tcl_onchansplit STDVAR
   memberlist *m;
 
   BADARGS(2, 3, " nickname ?channel?");
+  
   if (argc > 2) {
-    chan = findchan_by_dname(argv[2]);   
+    chan = findchan_by_dname(argv[2]);
     thechan = chan;
     if (!thechan) {
       Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
       return TCL_ERROR;
     }
   } else
-   chan = chanset;
-  
+    chan = chanset;
+
   while (chan && (thechan == NULL || thechan == chan)) {
     m = ismember(chan, argv[1]);
     if (m && chan_issplit(m)) {
@@ -398,8 +496,10 @@ static int tcl_onchansplit STDVAR
 static int tcl_maskhost STDVAR
 {
   char new[121];
+
   BADARGS(2, 2, " nick!user@host");
-  maskhost(argv[1], new);
+   
+  maskban(argv[1], new);
   Tcl_AppendResult(irp, new, NULL);
   return TCL_OK;
 }
@@ -412,11 +512,13 @@ static int tcl_getchanidle STDVAR
   int x;
 
   BADARGS(3, 3, " nickname channel");
+
   if (!(chan = findchan_by_dname(argv[2]))) {
     Tcl_AppendResult(irp, "invalid channel: ", argv[2], NULL);
     return TCL_ERROR;
   }
   m = ismember(chan, argv[1]);
+
   if (m) {
     x = (now - (m->last)) / 60;
     simple_sprintf(s, "%d", x);
@@ -429,7 +531,8 @@ static int tcl_getchanidle STDVAR
 
 static inline int tcl_chanmasks(masklist *m, Tcl_Interp *irp)
 {
-  char *list[3], work[20], *p;
+  char work[20], *p;
+  EGG_CONST char *list[3];
 
   for (; m && m->mask && m->mask[0]; m = m->next) {
     list[0] = m->mask;
@@ -448,6 +551,7 @@ static int tcl_chanbans STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -461,6 +565,7 @@ static int tcl_chanexempts STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -474,6 +579,7 @@ static int tcl_chaninvites STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[2], NULL);
@@ -487,6 +593,7 @@ static int tcl_getchanmode STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel: ", argv[1], NULL);
@@ -503,12 +610,14 @@ static int tcl_getchanjoin STDVAR
   memberlist *m;
 
   BADARGS(3, 3, " nick channel");
+  
   chan = findchan_by_dname(argv[2]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid cahnnel: ", argv[2], NULL);
     return TCL_ERROR;
   }
   m = ismember(chan, argv[1]);
+
   if (m == NULL) {
     Tcl_AppendResult(irp, argv[1], " is not on ", argv[2], NULL);
     return TCL_ERROR;
@@ -523,13 +632,14 @@ static int tcl_channame2dname STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel-name");
+  
   chan = findchan(argv[1]);
   if (chan) {
-      Tcl_AppendResult(irp, chan->dname, NULL);
-      return TCL_OK;
+    Tcl_AppendResult(irp, chan->dname, NULL);
+    return TCL_OK;
   } else {
-      Tcl_AppendResult(irp, "invalid channel-name: ", argv[1], NULL);
-      return TCL_ERROR;
+    Tcl_AppendResult(irp, "invalid channel-name: ", argv[1], NULL);
+    return TCL_ERROR;
   }
 }
 
@@ -538,22 +648,23 @@ static int tcl_chandname2name STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel-dname");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan) {
-      Tcl_AppendResult(irp, chan->name, NULL);
-      return TCL_OK;
+    Tcl_AppendResult(irp, chan->name, NULL);
+    return TCL_OK;
   } else {
-      Tcl_AppendResult(irp, "invalid channel-dname: ", argv[1], NULL);
-      return TCL_ERROR;
+    Tcl_AppendResult(irp, "invalid channel-dname: ", argv[1], NULL);
+    return TCL_ERROR;
   }
 }
 
-/* flushmode <chan> */
 static int tcl_flushmode STDVAR
 {
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel: ", argv[1], NULL);
@@ -569,12 +680,14 @@ static int tcl_pushmode STDVAR
   char plus, mode;
 
   BADARGS(3, 4, " channel mode ?arg?");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel: ", argv[1], NULL);
     return TCL_ERROR;
   }
   plus = argv[2][0];
+
   mode = argv[2][1];
   if ((plus != '+') && (plus != '-')) {
     mode = plus;
@@ -592,6 +705,7 @@ static int tcl_resetbans STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel ", argv[1], NULL);
@@ -606,6 +720,7 @@ static int tcl_resetexempts STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel ", argv[1], NULL);
@@ -620,6 +735,7 @@ static int tcl_resetinvites STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel ", argv[1], NULL);
@@ -634,6 +750,7 @@ static int tcl_resetchan STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel ", argv[1], NULL);
@@ -648,6 +765,7 @@ static int tcl_topic STDVAR
   struct chanset_t *chan;
 
   BADARGS(2, 2, " channel");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "invalid channel ", argv[1], NULL);
@@ -659,10 +777,12 @@ static int tcl_topic STDVAR
 
 static int tcl_hand2nick STDVAR
 {
+  char nuh[1024];
   memberlist *m;
   struct chanset_t *chan, *thechan = NULL;
 
-  BADARGS(2, 3, " handle ?channel?");	/* drummer */
+  BADARGS(2, 3, " handle ?channel?");
+
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
@@ -675,11 +795,16 @@ static int tcl_hand2nick STDVAR
 
   while (chan && (thechan == NULL || thechan == chan)) {
     for (m = chan->channel.member; m && m->nick[0]; m = m->next) {
-      if (m->user && !rfc_casecmp(m->user->handle, argv[1])) {
-	  Tcl_AppendResult(irp, m->nick, NULL);
-	  return TCL_OK;
-	}
+      if (!m->user && !m->tried_getuser) {
+        egg_snprintf(nuh, sizeof nuh, "%s!%s", m->nick, m->userhost);
+        m->tried_getuser = 1;
+        m->user = get_user_by_host(nuh);
       }
+      if (m->user && !rfc_casecmp(m->user->handle, argv[1])) {
+        Tcl_AppendResult(irp, m->nick, NULL);
+        return TCL_OK;
+      }
+    }
     chan = chan->next;
   }
   return TCL_OK;
@@ -687,10 +812,12 @@ static int tcl_hand2nick STDVAR
 
 static int tcl_nick2hand STDVAR
 {
+  char nuh[1024];
   memberlist *m;
   struct chanset_t *chan, *thechan = NULL;
 
-  BADARGS(2, 3, " nick ?channel?");	/* drummer */
+  BADARGS(2, 3, " nick ?channel?");
+
   if (argc > 2) {
     chan = findchan_by_dname(argv[2]);
     thechan = chan;
@@ -704,18 +831,18 @@ static int tcl_nick2hand STDVAR
   while (chan && (thechan == NULL || thechan == chan)) {
     m = ismember(chan, argv[1]);
     if (m) {
+      if (!m->user) {
+        egg_snprintf(nuh, sizeof nuh, "%s!%s", m->nick, m->userhost);
+        m->user = get_user_by_host(nuh);
+      }
       Tcl_AppendResult(irp, m->user ? m->user->handle : "*", NULL);
       return TCL_OK;
     }
     chan = chan->next;
   }
-  Tcl_AppendResult(irp, "*", NULL);
   return TCL_OK;
 }
 
-/* Sends an optimal number of kicks per command (as defined by kick_method)
- * to the server, simialer to kick_all.
- */
 static int tcl_putkick STDVAR
 {
   struct chanset_t *chan;
@@ -724,6 +851,7 @@ static int tcl_putkick STDVAR
   memberlist *m;
 
   BADARGS(3, 4, " channel nick?s? ?comment?");
+  
   chan = findchan_by_dname(argv[1]);
   if (chan == NULL) {
     Tcl_AppendResult(irp, "illegal channel: ", argv[1], NULL);
@@ -733,29 +861,33 @@ static int tcl_putkick STDVAR
     comment = argv[3];
   else
     comment = "";
-  if (!me_op(chan)) {
-    Tcl_AppendResult(irp, "need op", NULL);
+  if (!me_op(chan) && !me_halfop(chan)) {
+    Tcl_AppendResult(irp, "need op or halfop", NULL);
     return TCL_ERROR;
   }
 
   kicknick[0] = 0;
   p = argv[2];
   /* Loop through all given nicks */
-  while(p) {
+  while (p) {
     nick = p;
-    p = strchr(nick, ',');	/* Search for beginning of next nick */
+    p = strchr(nick, ',');      /* Search for beginning of next nick */
     if (p) {
       *p = 0;
       p++;
     }
 
     m = ismember(chan, nick);
+    if (!me_op(chan) && !(me_halfop(chan) && !chan_hasop(m))) {
+      Tcl_AppendResult(irp, "need op", NULL);
+      return TCL_ERROR;
+    }
     if (!m)
-      continue;			/* Skip non-existant nicks */
-    m->flags |= SENTKICK;	/* Mark as pending kick */
+      continue;                 /* Skip non-existant nicks */
+    m->flags |= SENTKICK;       /* Mark as pending kick */
     if (kicknick[0])
       strcat(kicknick, ",");
-    strcat(kicknick, nick);	/* Add to local queue */
+    strcat(kicknick, nick);     /* Add to local queue */
     k++;
 
     /* Check if we should send the kick command yet */
@@ -772,41 +904,43 @@ static int tcl_putkick STDVAR
   return TCL_OK;
 }
 
-static tcl_cmds tclchan_cmds[] =
-{
-  {"chanlist",		tcl_chanlist},
-  {"botisop",		tcl_botisop},
-  {"botisvoice",	tcl_botisvoice},
-  {"isop",		tcl_isop},
-  {"wasop",		tcl_wasop},
-  {"isvoice",		tcl_isvoice},
-  {"onchan",		tcl_onchan},
-  {"handonchan",	tcl_handonchan},
-  {"ischanban",		tcl_ischanban},
-  {"ischanexempt",	tcl_ischanexempt},
-  {"ischaninvite",	tcl_ischaninvite},
-  {"ischanjuped",	tcl_ischanjuped},
-  {"getchanhost",	tcl_getchanhost},
-  {"onchansplit",	tcl_onchansplit},
-  {"maskhost",		tcl_maskhost},
-  {"getchanidle",	tcl_getchanidle},
-  {"chanbans",		tcl_chanbans},
-  {"chanexempts",	tcl_chanexempts},
-  {"chaninvites",	tcl_chaninvites},
-  {"hand2nick",		tcl_hand2nick},
-  {"nick2hand",		tcl_nick2hand},
-  {"getchanmode",	tcl_getchanmode},
-  {"getchanjoin",	tcl_getchanjoin},
-  {"flushmode",		tcl_flushmode},
-  {"pushmode",		tcl_pushmode},
-  {"resetbans",		tcl_resetbans},
-  {"resetexempts",	tcl_resetexempts},
-  {"resetinvites",	tcl_resetinvites},
-  {"resetchan",		tcl_resetchan},
-  {"topic",		tcl_topic},
-  {"botonchan",		tcl_botonchan},
-  {"putkick",		tcl_putkick},
-  {"channame2dname",	tcl_channame2dname},
-  {"chandname2name",	tcl_chandname2name},
-  {NULL,		NULL}
+static tcl_cmds tclchan_cmds[] = {
+  {"chanlist",       tcl_chanlist},
+  {"botisop",        tcl_botisop},
+  {"botishalfop",    tcl_botishalfop},
+  {"botisvoice",     tcl_botisvoice},
+  {"isop",           tcl_isop},
+  {"wasop",          tcl_wasop},
+  {"ishalfop",       tcl_ishalfop},
+  {"washalfop",      tcl_washalfop},
+  {"isvoice",        tcl_isvoice},
+  {"onchan",         tcl_onchan},
+  {"handonchan",     tcl_handonchan},
+  {"ischanban",      tcl_ischanban},
+  {"ischanexempt",   tcl_ischanexempt},
+  {"ischaninvite",   tcl_ischaninvite},
+  {"ischanjuped",    tcl_ischanjuped},
+  {"getchanhost",    tcl_getchanhost},
+  {"onchansplit",    tcl_onchansplit},
+  {"maskhost",       tcl_maskhost},
+  {"getchanidle",    tcl_getchanidle},
+  {"chanbans",       tcl_chanbans},
+  {"chanexempts",    tcl_chanexempts},
+  {"chaninvites",    tcl_chaninvites},
+  {"hand2nick",      tcl_hand2nick},
+  {"nick2hand",      tcl_nick2hand},
+  {"getchanmode",    tcl_getchanmode},
+  {"getchanjoin",    tcl_getchanjoin},
+  {"flushmode",      tcl_flushmode},
+  {"pushmode",       tcl_pushmode},
+  {"resetbans",      tcl_resetbans},
+  {"resetexempts",   tcl_resetexempts},
+  {"resetinvites",   tcl_resetinvites},
+  {"resetchan",      tcl_resetchan},
+  {"topic",          tcl_topic},
+  {"botonchan",      tcl_botonchan},
+  {"putkick",        tcl_putkick},
+  {"channame2dname", tcl_channame2dname},
+  {"chandname2name", tcl_chandname2name},
+  {NULL,             NULL}
 };
