@@ -10,10 +10,10 @@
  * 1.2     1997-08-20      Minor fixes. [BB]
  * 1.2a    1997-08-24      Minor fixes. [BB]
  *
- * $Id: seen.c,v 1.24 2002/01/02 03:46:39 guppy Exp $
+ * $Id: seen.c,v 1.32 2003/03/08 04:29:44 wcc Exp $
  */
 /*
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,7 +73,20 @@
 #define MODULE_NAME "seen"
 #define MAKING_SEEN
 
-#include <time.h>
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#ifdef TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# ifdef HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
 
 #include "src/mod/module.h"
 #include "src/users.h"
@@ -92,33 +105,30 @@ typedef struct {
   char *text;
 } trig_data;
 
-static trig_data trigdata[] =
-{
-  {"god",	"Let's not get into a religious discussion, %s"},
-  {"jesus",	"Let's not get into a religious discussion, %s"},
-  {"shit",	"Here's looking at you, %s"},
-  {"yourself",	"Yeah, whenever I look in a mirror..."},
-  {NULL,	"You found me, %s!"},
-  {"elvis",	"Last time I was on the moon man."},
-  {NULL,	NULL}
+static trig_data trigdata[] = {
+  {"god",      "Let's not get into a religious discussion, %s"},
+  {"jesus",    "Let's not get into a religious discussion, %s"},
+  {"shit",                         "Here's looking at you, %s"},
+  {"yourself",          "Yeah, whenever I look in a mirror..."},
+  {NULL, "                                  You found me, %s!"},
+  {"elvis",                 "Last time I was on the moon man."},
+  {NULL,                                                  NULL}
 };
 
 static int seen_expmem()
 {
-  int size = 0;
-
-  return size;
+  return 0;
 }
 
 /* PUB `seen' trigger. */
 static int pub_seen(char *nick, char *host, char *hand,
-		    char *channel, char *text)
+                    char *channel, char *text)
 {
-  char prefix[50];
+  char prefix[91];              /* sizeof(name) + strlen("PRIVMSG  :") */
   struct chanset_t *chan = findchan_by_dname(channel);
 
   if ((chan != NULL) && channel_seen(chan)) {
-    sprintf(prefix, "PRIVMSG %s :", chan->name);
+    egg_snprintf(prefix, sizeof prefix, "PRIVMSG %s :", chan->name);
     do_seen(DP_HELP, prefix, nick, hand, chan->dname, text);
   }
   return 0;
@@ -146,7 +156,7 @@ static int dcc_seen(struct userrec *u, int idx, char *par)
 }
 
 static void do_seen(int idx, char *prefix, char *nick, char *hand,
-		    char *channel, char *text)
+                    char *channel, char *text)
 {
   char stuff[512];
   char word1[512], word2[512];
@@ -171,19 +181,18 @@ static void do_seen(int idx, char *prefix, char *nick, char *hand,
   /* Was ANYONE specified */
   if (!text[0]) {
     dprintf(idx, "%sUm, %s, it might help if you ask me about _someone_...\n",
-	    prefix, nick);
+            prefix, nick);
     return;
   }
   wordshift(word1, text);
   oix = strchr(word1, '\'');
   /* Have we got a NICK's target? */
   if (oix == word1)
-    return;			/* Skip anything starting with ' */
-  if (oix && *oix &&
-      ((oix[1] && (oix[1] == 's' || oix[1] == 'S') && !oix[2]) ||
-       (!oix[1] &&
-	(oix[-1] == 's' || oix[-1] == 'z' || oix[-1] == 'x' ||
-	 oix[-1] == 'S' || oix[-1] == 'Z' || oix[-1] == 'X')))) {
+    return;                     /* Skip anything starting with ' */
+  if (oix && *oix && ((oix[1] && (oix[1] == 's' || oix[1] == 'S') &&
+      !oix[2]) || (!oix[1] && (oix[-1] == 's' || oix[-1] == 'z' ||
+      oix[-1] == 'x' || oix[-1] == 'S' || oix[-1] == 'Z' ||
+      oix[-1] == 'X')))) {
     strncpy(object, word1, oix - word1);
     object[oix - word1] = 0;
     wordshift(word1, text);
@@ -195,56 +204,56 @@ static void do_seen(int idx, char *prefix, char *nick, char *hand,
     if (!urec) {
       chan = chanset;
       while (chan) {
-	onchan = 0;
-	m = ismember(chan, object);
-	if (m) {
-	  onchan = 1;
-	  sprintf(stuff, "%s!%s", object, m->userhost);
-	  urec = get_user_by_host(stuff);
-	  if (!urec || !egg_strcasecmp(object, urec->handle))
-	    break;
-	  strcat(whoredirect, object);
-	  strcat(whoredirect, " is ");
-	  strcat(whoredirect, urec->handle);
-	  strcat(whoredirect, ", and ");
-	  strcpy(object, urec->handle);
-	  break;
-	}
-	chan = chan->next;
+        onchan = 0;
+        m = ismember(chan, object);
+        if (m) {
+          onchan = 1;
+          sprintf(stuff, "%s!%s", object, m->userhost);
+          urec = get_user_by_host(stuff);
+          if (!urec || !egg_strcasecmp(object, urec->handle))
+            break;
+          strcat(whoredirect, object);
+          strcat(whoredirect, " is ");
+          strcat(whoredirect, urec->handle);
+          strcat(whoredirect, ", and ");
+          strcpy(object, urec->handle);
+          break;
+        }
+        chan = chan->next;
       }
       if (!onchan) {
-	dprintf(idx, "%sI don't think I know who %s is, %s.\n",
-		prefix, object, nick);
-	return;
+        dprintf(idx, "%sI don't think I know who %s is, %s.\n",
+                prefix, object, nick);
+        return;
       }
     }
     if (!egg_strcasecmp(word1, "bf") || !egg_strcasecmp(word1, "boyfriend")) {
       strcpy(whotarget, getxtra(object, "BF"));
       if (whotarget[0]) {
-	sprintf(whoredirect, "%s boyfriend is %s, and ",
-		fixnick(object), whotarget);
-	goto targetcont;
+        sprintf(whoredirect, "%s boyfriend is %s, and ",
+                fixnick(object), whotarget);
+        goto targetcont;
       }
       dprintf(idx,
-	      "%sI don't know who %s boyfriend is, %s.\n",
-	      prefix, fixnick(object), nick);
+              "%sI don't know who %s boyfriend is, %s.\n",
+              prefix, fixnick(object), nick);
       return;
     }
     if (!egg_strcasecmp(word1, "gf") || !egg_strcasecmp(word1, "girlfriend")) {
       strcpy(whotarget, getxtra(object, "GF"));
       if (whotarget[0]) {
-	sprintf(whoredirect, "%s girlfriend is %s, and ",
-		fixnick(object), whotarget);
-	goto targetcont;
+        sprintf(whoredirect, "%s girlfriend is %s, and ",
+                fixnick(object), whotarget);
+        goto targetcont;
       }
       dprintf(idx,
-	      "%sI don't know who %s girlfriend is, %s.\n",
-	      prefix, fixnick(object), nick);
+              "%sI don't know who %s girlfriend is, %s.\n",
+              prefix, fixnick(object), nick);
       return;
     }
     dprintf(idx,
-	  "%sWhy are you bothering me with questions about %s %s, %s?\n",
-	    prefix, fixnick(object), word1, nick);
+            "%sWhy are you bothering me with questions about %s %s, %s?\n",
+            prefix, fixnick(object), word1, nick);
     return;
   }
   /* Keyword "my" */
@@ -257,40 +266,35 @@ static void do_seen(int idx, char *prefix, char *nick, char *hand,
     /* Do I even KNOW the requestor? */
     if (hand[0] == '*' || !hand[0]) {
       dprintf(idx,
-	      "%sI don't know you, %s, so I don't know about your %s.\n",
-	      prefix, nick, word1);
+              "%sI don't know you, %s, so I don't know about your %s.\n",
+              prefix, nick, word1);
       return;
     }
     /* "my boyfriend" */
     if (!egg_strcasecmp(word1, "boyfriend") || !egg_strcasecmp(word1, "bf")) {
       strcpy(whotarget, getxtra(hand, "BF"));
       if (whotarget[0]) {
-	sprintf(whoredirect, "%s, your boyfriend is %s, and ",
-		nick, whotarget);
+        sprintf(whoredirect, "%s, your boyfriend is %s, and ", nick, whotarget);
       } else {
-	dprintf(idx,
-		"%sI didn't know you had a boyfriend, %s\n",
-		prefix, nick);
-	return;
+        dprintf(idx, "%sI didn't know you had a boyfriend, %s\n", prefix, nick);
+        return;
       }
     }
     /* "my girlfriend" */
     else if (!egg_strcasecmp(word1, "girlfriend") ||
-	      !egg_strcasecmp(word1, "gf")) {
+             !egg_strcasecmp(word1, "gf")) {
       strcpy(whotarget, getxtra(hand, "GF"));
       if (whotarget[0]) {
-	sprintf(whoredirect, "%s, your girlfriend is %s, and ",
-		nick, whotarget);
+        sprintf(whoredirect, "%s, your girlfriend is %s, and ",
+                nick, whotarget);
       } else {
-	dprintf(idx,
-		"%sI didn't know you had a girlfriend, %s\n",
-		prefix, nick);
-	return;
+        dprintf(idx, "%sI didn't know you had a girlfriend, %s\n", prefix,
+                nick);
+        return;
       }
     } else {
-      dprintf(idx,
-	      "%sI don't know anything about your %s, %s.\n",
-	      prefix, word1, nick);
+      dprintf(idx, "%sI don't know anything about your %s, %s.\n", prefix,
+              word1, nick);
       return;
     }
   }
@@ -300,32 +304,31 @@ static void do_seen(int idx, char *prefix, char *nick, char *hand,
     /* "your admin" */
     if (!egg_strcasecmp(word1, "owner") || !egg_strcasecmp(word1, "admin")) {
       if (admin[0]) {
-	strcpy(word2, admin);
-	wordshift(whotarget, word2);
-	strcat(whoredirect, "My owner is ");
-	strcat(whoredirect, whotarget);
-	strcat(whoredirect, ", and ");
-	if (!egg_strcasecmp(whotarget, hand)) {
-	  strcat(whoredirect, "that's YOU");
-	  if (!egg_strcasecmp(hand, nick)) {
-	    strcat(whoredirect, "!!!");
-	  } else {
-	    strcat(whoredirect, ", ");
-	    strcat(whoredirect, nick);
-	    strcat(whoredirect, "!");
-	  }
-	  dprintf(idx, "%s%s\n", prefix, whoredirect);
-	  return;
-	}
-      } else {			/* owner variable munged or not set */
-	dprintf(idx,
-		"%sI don't seem to recall who my owner is right now...\n",
-		prefix);
-	return;
+        strcpy(word2, admin);
+        wordshift(whotarget, word2);
+        strcat(whoredirect, "My owner is ");
+        strcat(whoredirect, whotarget);
+        strcat(whoredirect, ", and ");
+        if (!egg_strcasecmp(whotarget, hand)) {
+          strcat(whoredirect, "that's YOU");
+          if (!egg_strcasecmp(hand, nick))
+            strcat(whoredirect, "!!!");
+          else {
+            strcat(whoredirect, ", ");
+            strcat(whoredirect, nick);
+            strcat(whoredirect, "!");
+          }
+          dprintf(idx, "%s%s\n", prefix, whoredirect);
+          return;
+        }
+      } else {                    /* owner variable munged or not set */
+        dprintf(idx,
+                "%sI don't seem to recall who my owner is right now...\n",
+                prefix);
+        return;
       }
-    } else {			/* no "your" target specified */
-      dprintf(idx, "%sLet's not get personal, %s.\n",
-	      prefix, nick);
+    } else {                      /* no "your" target specified */
+      dprintf(idx, "%sLet's not get personal, %s.\n", prefix, nick);
       return;
     }
   }
@@ -343,7 +346,7 @@ targetcont:
   /* Looking for ones own nick? */
   if (!rfc_casecmp(nick, whotarget)) {
     dprintf(idx, "%s%sLooking for yourself, eh %s?\n",
-	    prefix, whoredirect, nick);
+            prefix, whoredirect, nick);
     return;
   }
   /* Check if nick is on a channel */
@@ -355,7 +358,7 @@ targetcont:
       sprintf(word1, "%s!%s", whotarget, m->userhost);
       urec = get_user_by_host(word1);
       if (!urec || !egg_strcasecmp(whotarget, urec->handle))
-	break;
+        break;
       strcat(whoredirect, whotarget);
       strcat(whoredirect, " is ");
       strcat(whoredirect, urec->handle);
@@ -370,18 +373,18 @@ targetcont:
     while (chan) {
       m = chan->channel.member;
       while (m && m->nick[0]) {
-	sprintf(word2, "%s!%s", m->nick, m->userhost);
-	urec = get_user_by_host(word2);
-	if (urec && !egg_strcasecmp(urec->handle, whotarget)) {
-	  onchan = 1;
-	  strcat(whoredirect, whotarget);
-	  strcat(whoredirect, " is ");
-	  strcat(whoredirect, m->nick);
-	  strcat(whoredirect, ", and ");
-	  strcpy(whotarget, m->nick);
-	  break;
-	}
-	m = m->next;
+        sprintf(word2, "%s!%s", m->nick, m->userhost);
+        urec = get_user_by_host(word2);
+        if (urec && !egg_strcasecmp(urec->handle, whotarget)) {
+          onchan = 1;
+          strcat(whoredirect, whotarget);
+          strcat(whoredirect, " is ");
+          strcat(whoredirect, m->nick);
+          strcat(whoredirect, ", and ");
+          strcpy(whotarget, m->nick);
+          break;
+        }
+        m = m->next;
       }
       chan = chan->next;
     }
@@ -392,14 +395,14 @@ targetcont:
     m = ismember(chan, whotarget);
     if (m && chan_issplit(m)) {
       dprintf(idx, "%s%s%s was just here, but got netsplit.\n",
-	      prefix, whoredirect, whotarget);
+              prefix, whoredirect, whotarget);
       return;
     }
   }
   /* Check if the target IS on the channel */
   if (chan && m) {
     dprintf(idx, "%s%s%s is on the channel right now!\n",
-	    prefix, whoredirect, whotarget);
+            prefix, whoredirect, whotarget);
     return;
   }
   /* Target not on this channel.   Check other channels */
@@ -408,14 +411,14 @@ targetcont:
     m = ismember(chan, whotarget);
     if (m && chan_issplit(m)) {
       dprintf(idx,
-	      "%s%s%s was just on %s, but got netsplit.\n",
-	      prefix, whoredirect, whotarget, chan->dname);
+              "%s%s%s was just on %s, but got netsplit.\n",
+              prefix, whoredirect, whotarget, chan->dname);
       return;
     }
     if (m) {
       dprintf(idx,
-	      "%s%s%s is on %s right now!\n",
-	      prefix, whoredirect, whotarget, chan->dname);
+              "%s%s%s is on %s right now!\n",
+              prefix, whoredirect, whotarget, chan->dname);
       return;
     }
     chan = chan->next;
@@ -426,7 +429,7 @@ targetcont:
   /* No match, then bail out */
   if (!urec) {
     dprintf(idx, "%s%sI don't know who %s is.\n",
-	    prefix, whoredirect, whotarget);
+            prefix, whoredirect, whotarget);
     return;
   }
   /* We had a userlist match to a handle */
@@ -434,18 +437,18 @@ targetcont:
   for (i = 0; i < dcc_total; i++) {
     if (dcc[i].type->flags & DCT_CHAT) {
       if (!egg_strcasecmp(whotarget, dcc[i].nick)) {
-	if (!rfc_casecmp(channel, dcc[i].u.chat->con_chan) &&
-	    dcc[i].u.chat->con_flags & LOG_PUBLIC) {
-	  strcat(whoredirect, whotarget);
-	  strcat(whoredirect,
-	   " is 'observing' this channel right now from my party line!");
-	  dprintf(idx, "%s%s\n", prefix, whoredirect);
-	} else {
-	  dprintf(idx,
-		  "%s%s%s is linked to me via DCC CHAT right now!\n",
-		  prefix, whoredirect, whotarget);
-	}
-	return;
+        if (!rfc_casecmp(channel, dcc[i].u.chat->con_chan) &&
+            dcc[i].u.chat->con_flags & LOG_PUBLIC) {
+          strcat(whoredirect, whotarget);
+          strcat(whoredirect,
+                 " is 'observing' this channel right now from my party line!");
+          dprintf(idx, "%s%s\n", prefix, whoredirect);
+        } else {
+          dprintf(idx,
+                  "%s%s%s is linked to me via DCC CHAT right now!\n",
+                  prefix, whoredirect, whotarget);
+        }
+        return;
       }
     }
   }
@@ -456,18 +459,18 @@ targetcont:
   else
     for (cr = urec->chanrec; cr; cr = cr->next) {
       if (!rfc_casecmp(cr->channel, channel)) {
-	if (cr->laston) {
-	  laston = cr->laston;
-	  lastonplace = channel;
-	  break;
-	}
+        if (cr->laston) {
+          laston = cr->laston;
+          lastonplace = channel;
+          break;
+        }
       }
     }
   if (!cr) {
     li = get_user(&USERENTRY_LASTON, urec);
     if (!li || !li->lastonplace || !li->lastonplace[0]) {
       dprintf(idx, "%s%sI've never seen %s around.\n",
-	      prefix, whoredirect, whotarget);
+              prefix, whoredirect, whotarget);
       return;
     }
     lastonplace = li->lastonplace;
@@ -478,17 +481,17 @@ targetcont:
   work = now - laston;
   if (work >= 86400) {
     sprintf(word2, "%lu day%s, ", work / 86400,
-	    ((work / 86400) == 1) ? "" : "s");
+            ((work / 86400) == 1) ? "" : "s");
     work = work % 86400;
   }
   if (work >= 3600) {
     sprintf(word2 + strlen(word2), "%lu hour%s, ", work / 3600,
-	    ((work / 3600) == 1) ? "" : "s");
+            ((work / 3600) == 1) ? "" : "s");
     work = work % 3600;
   }
   if (work >= 60) {
     sprintf(word2 + strlen(word2), "%lu minute%s, ", work / 60,
-	    ((work / 60) == 1) ? "" : "s");
+            ((work / 60) == 1) ? "" : "s");
   }
   if (!word2[0] && (work < 60)) {
     strcpy(word2, "just moments ago!!");
@@ -504,7 +507,7 @@ targetcont:
   else
     strcpy(word1, "seen");
   dprintf(idx, "%s%s%s was last %s %s\n",
-	  prefix, whoredirect, whotarget, word1, word2);
+          prefix, whoredirect, whotarget, word1, word2);
 }
 
 static char fixit[512];
@@ -551,16 +554,16 @@ static char *getxtra(char *hand, char *field)
     ue = find_user_entry(&USERENTRY_XTRA, urec);
     if (ue)
       for (xk = ue->u.extra; xk; xk = xk->next)
-	if (xk->key && !egg_strcasecmp(xk->key, field)) {
-	  if (xk->data[0] == '{' && xk->data[strlen(xk->data) - 1] == '}' &&
-	      strlen(xk->data) > 2) {
-	    strncpy(fixit, &xk->data[1], strlen(xk->data) - 2);
-	    fixit[strlen(xk->data) - 2] = 0;
-	    return fixit;
-	  } else {
-	    return xk->data;
-	  }
-	}
+        if (xk->key && !egg_strcasecmp(xk->key, field)) {
+          if (xk->data[0] == '{' && xk->data[strlen(xk->data) - 1] == '}' &&
+              strlen(xk->data) > 2) {
+            strncpy(fixit, &xk->data[1], strlen(xk->data) - 2);
+            fixit[strlen(xk->data) - 2] = 0;
+            return fixit;
+          } else {
+            return xk->data;
+          }
+        }
   }
   return "";
 }
@@ -579,27 +582,28 @@ static void wordshift(char *first, char *rest)
 /* Report on current seen info for .modulestat. */
 static void seen_report(int idx, int details)
 {
-  if (details)
-    dprintf(idx, "    seen.so - PUB, DCC and MSG \"seen\" commands.\n");
+  if (details) {
+    int size = seen_expmem();
+
+    dprintf(idx, "    Using %d byte%s of memory\n", size,
+            (size != 1) ? "s" : "");
+  }
 }
 
 /* PUB channel builtin commands. */
-static cmd_t seen_pub[] =
-{
-  {"seen",	"",	pub_seen,	NULL},
-  {NULL,	NULL,	NULL,		NULL}
+static cmd_t seen_pub[] = {
+  {"seen", "",    pub_seen, NULL},
+  {NULL,   NULL, NULL,      NULL}
 };
 
-static cmd_t seen_dcc[] =
-{
-  {"seen",	"",	dcc_seen, 	NULL},
-  {NULL,	NULL,	NULL,		NULL}
+static cmd_t seen_dcc[] = {
+  {"seen", "",   dcc_seen, NULL},
+  {NULL,   NULL, NULL,     NULL}
 };
 
-static cmd_t seen_msg[] =
-{
-  {"seen",	"",	msg_seen,	NULL},
-  {NULL,	NULL,	NULL,		NULL}
+static cmd_t seen_msg[] = {
+  {"seen", "",   msg_seen, NULL},
+  {NULL,   NULL, NULL,     NULL}
 };
 
 static int server_seen_setup(char *mod)
@@ -620,11 +624,10 @@ static int irc_seen_setup(char *mod)
   return 0;
 }
 
-static cmd_t seen_load[] =
-{
-  {"server",	"",	server_seen_setup,	NULL},
-  {"irc",	"",	irc_seen_setup,		NULL},
-  {NULL,	NULL,	NULL,			NULL}
+static cmd_t seen_load[] = {
+  {"server", "",   server_seen_setup, NULL},
+  {"irc",    "",   irc_seen_setup,    NULL},
+  {NULL,     NULL, NULL,              NULL}
 };
 
 static char *seen_close()
@@ -644,22 +647,21 @@ static char *seen_close()
 
 EXPORT_SCOPE char *seen_start();
 
-static Function seen_table[] =
-{
+static Function seen_table[] = {
   (Function) seen_start,
   (Function) seen_close,
   (Function) seen_expmem,
   (Function) seen_report,
 };
 
-char *seen_start(Function * egg_func_table)
+char *seen_start(Function *egg_func_table)
 {
   global = egg_func_table;
 
   module_register(MODULE_NAME, seen_table, 2, 0);
   if (!module_depend(MODULE_NAME, "eggdrop", 106, 0)) {
     module_undepend(MODULE_NAME);
-    return "This module needs eggdrop1.6.0 or later";
+    return "This module requires Eggdrop 1.6.0 or later.";
   }
   add_builtins(H_load, seen_load);
   add_builtins(H_dcc, seen_dcc);
