@@ -2,11 +2,11 @@
  * cmdsserv.c -- part of server.mod
  *   handles commands from a user via dcc that cause server interaction
  *
- * $Id: cmdsserv.c,v 1.12 2002/01/02 03:46:40 guppy Exp $
+ * $Id: cmdsserv.c,v 1.19 2003/03/16 04:49:14 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,23 +31,22 @@ static void cmd_servers(struct userrec *u, int idx, char *par)
 
   putlog(LOG_CMDS, "*", "#%s# servers", dcc[idx].nick);
   if (!x) {
-    dprintf(idx, "No servers.\n");
+    dprintf(idx, "There are no servers in the server list.\n");
   } else {
     dprintf(idx, "Server list:\n");
     i = 0;
     for (; x; x = x->next) {
-      if (x->realname)
-	egg_snprintf(s, sizeof s, "  %s:%d (%s) %s", x->name,
-                     x->port ? x->port : default_port, x->realname,
+      if ((i == curserv) && realservername)
+        egg_snprintf(s, sizeof s, "  %s:%d (%s) <- I am here", x->name,
+                     x->port ? x->port : default_port, realservername);
+      else
+        egg_snprintf(s, sizeof s, "  %s:%d %s", x->name,
+                     x->port ? x->port : default_port,
                      (i == curserv) ? "<- I am here" : "");
-      else 
-        egg_snprintf(s, sizeof s, "  %s:%d %s", x->name, 
-		     x->port ? x->port : default_port, 
-		     (i == curserv) ? "<- I am here" : "");
       dprintf(idx, "%s\n", s);
       i++;
     }
-    dprintf(idx, "End of server list.\n"); 
+    dprintf(idx, "End of server list.\n");
   }
 }
 
@@ -76,7 +75,7 @@ static void cmd_jump(struct userrec *u, int idx, char *par)
     if (!port)
       port = default_port;
     putlog(LOG_CMDS, "*", "#%s# jump %s %d %s", dcc[idx].nick, other,
-	   port, par);
+           port, par);
     strncpyz(newserver, other, sizeof newserver);
     newserverport = port;
     strncpyz(newserverpass, par, sizeof newserverpass);
@@ -89,7 +88,7 @@ static void cmd_jump(struct userrec *u, int idx, char *par)
 
 static void cmd_clearqueue(struct userrec *u, int idx, char *par)
 {
-  int	msgs;
+  int msgs;
 
   if (!par[0]) {
     dprintf(idx, "Usage: clearqueue <mode|server|help|all>\n");
@@ -101,26 +100,30 @@ static void cmd_clearqueue(struct userrec *u, int idx, char *par)
     msgq_clear(&mq);
     msgq_clear(&hq);
     double_warned = burst = 0;
-    dprintf(idx, "Removed %d msgs from all queues\n", msgs);
+    dprintf(idx, "Removed %d message%s from all queues.\n", msgs,
+            (msgs != 1) ? "s" : "");
   } else if (!egg_strcasecmp(par, "mode")) {
     msgs = modeq.tot;
     msgq_clear(&modeq);
     if (mq.tot == 0)
       burst = 0;
     double_warned = 0;
-    dprintf(idx, "Removed %d msgs from the %s queue\n", msgs, "mode");
+    dprintf(idx, "Removed %d message%s from the mode queue.\n", msgs,
+            (msgs != 1) ? "s" : "");
   } else if (!egg_strcasecmp(par, "help")) {
     msgs = hq.tot;
     msgq_clear(&hq);
     double_warned = 0;
-    dprintf(idx, "Removed %d msgs from the %s queue\n", msgs, "help");
+    dprintf(idx, "Removed %d message%s from the help queue.\n", msgs,
+            (msgs != 1) ? "s" : "");
   } else if (!egg_strcasecmp(par, "server")) {
     msgs = mq.tot;
     msgq_clear(&mq);
     if (modeq.tot == 0)
       burst = 0;
     double_warned = 0;
-    dprintf(idx, "Removed %d msgs from the %s queue\n", msgs, "server");
+    dprintf(idx, "Removed %d message%s from the server queue.\n", msgs,
+            (msgs != 1) ? "s" : "");
   } else {
     dprintf(idx, "Usage: clearqueue <mode|server|help|all>\n");
     return;
@@ -128,16 +131,10 @@ static void cmd_clearqueue(struct userrec *u, int idx, char *par)
   putlog(LOG_CMDS, "*", "#%s# clearqueue %s", dcc[idx].nick, par);
 }
 
-/* Function call should be:
- *   int cmd_whatever(idx,"parameters");
- *
- * As with msg commands, function is responsible for any logging.
- */
-static cmd_t C_dcc_serv[] =
-{
-  {"dump",		"m",	(Function) cmd_dump,		NULL},
-  {"jump",		"m",	(Function) cmd_jump,		NULL},
-  {"servers",		"o",	(Function) cmd_servers,		NULL},
-  {"clearqueue",	"m",	(Function) cmd_clearqueue,	NULL},
-  {NULL,		NULL,	NULL,				NULL}
+static cmd_t C_dcc_serv[] = {
+  {"dump",       "m",  (Function) cmd_dump,       NULL},
+  {"jump",       "m",  (Function) cmd_jump,       NULL},
+  {"servers",    "o",  (Function) cmd_servers,    NULL},
+  {"clearqueue", "m",  (Function) cmd_clearqueue, NULL},
+  {NULL,         NULL, NULL,                      NULL}
 };
