@@ -2,13 +2,13 @@
  * woobie.c -- part of woobie.mod
  *   nonsensical command to exemplify module programming
  *
- * Originally written by ButchBub	  15 July     1997
- * Comments by Fabian Knittel		  29 December 1999
+ * Originally written by ButchBub         15 July     1997
+ * Comments by Fabian Knittel             29 December 1999
  *
- * $Id: woobie.c,v 1.16 2002/01/02 03:46:41 guppy Exp $
+ * $Id: woobie.c,v 1.21 2003/03/08 04:29:44 wcc Exp $
  */
 /*
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -70,12 +70,12 @@ static int cmd_woobie(struct userrec *u, int idx, char *par)
  */
 static void woobie_report(int idx, int details)
 {
-  int size;
+  if (details) {
+    int size = woobie_expmem();
 
-  Context;
-  size = woobie_expmem();
-  if (details)
-    dprintf(idx, "    0 woobies using %d bytes\n", size);
+    dprintf(idx, "    Using %d byte%s of memory\n", size,
+            (size != 1) ? "s" : "");
+  }
 }
 
 /* Note: The tcl-name is automatically created if you set it to NULL. In
@@ -87,11 +87,10 @@ static void woobie_report(int idx, int details)
  *       This is only useful for stackable binding tables (and H_dcc isn't
  *       stackable).
  */
-static cmd_t mydcc[] =
-{
-  /* command	flags	function	tcl-name */
-  {"woobie",	"",	cmd_woobie,	NULL},
-  {NULL,	NULL,	NULL,		NULL}		/* Mark end. */
+static cmd_t mydcc[] = {
+  /* command  flags  function     tcl-name */
+  {"woobie",  "",    cmd_woobie,  NULL},
+  {NULL,      NULL,  NULL,        NULL}  /* Mark end. */
 };
 
 static char *woobie_close()
@@ -113,8 +112,7 @@ EXPORT_SCOPE char *woobie_start();
  * The first four have to be defined (you may define them as NULL), as
  * they are checked by eggdrop core.
  */
-static Function woobie_table[] =
-{
+static Function woobie_table[] = {
   (Function) woobie_start,
   (Function) woobie_close,
   (Function) woobie_expmem,
@@ -139,7 +137,7 @@ char *woobie_start(Function *global_funcs)
 
   if (!module_depend(MODULE_NAME, "eggdrop", 106, 0)) {
     module_undepend(MODULE_NAME);
-    return "This module requires eggdrop1.6.0 or later";
+    return "This module requires Eggdrop 1.6.0 or later.";
   }
 
   /* Add command table to bind list H_dcc, responsible for dcc commands.
