@@ -2,11 +2,11 @@
  * tcldcc.c -- handles:
  *   Tcl stubs for the dcc commands
  *
- * $Id: tcldcc.c,v 1.33 2002/01/02 03:46:36 guppy Exp $
+ * $Id: tcldcc.c,v 1.47 2003/04/17 01:55:57 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,22 +27,23 @@
 #include "tandem.h"
 #include "modules.h"
 
-extern Tcl_Interp	*interp;
-extern tcl_timer_t	*timer,
-			*utimer;
-extern struct dcc_t	*dcc;
-extern int		 dcc_total, backgrd, parties, make_userfile,
-			 do_restart, remote_boots, max_dcc;
-extern char		 botnetnick[];
-extern party_t		*party;
-extern tand_t		*tandbot;
-extern time_t		 now;
-
-/* Traffic stuff. */
-extern unsigned long otraffic_irc, otraffic_irc_today, itraffic_irc, itraffic_irc_today, otraffic_bn, otraffic_bn_today, itraffic_bn, itraffic_bn_today, otraffic_dcc, otraffic_dcc_today, itraffic_dcc, itraffic_dcc_today, otraffic_trans, otraffic_trans_today, itraffic_trans, itraffic_trans_today, otraffic_unknown, otraffic_unknown_today, itraffic_unknown, itraffic_unknown_today;
-
-int			 enable_simul = 0;
-static struct portmap	*root = NULL;
+extern Tcl_Interp *interp;
+extern tcl_timer_t *timer, *utimer;
+extern struct dcc_t *dcc;
+extern char botnetnick[];
+extern int dcc_total, backgrd, parties, make_userfile, do_restart, max_dcc,
+           remote_boots;
+extern party_t *party;
+extern tand_t *tandbot;
+extern time_t now;
+extern unsigned long otraffic_irc, otraffic_irc_today, itraffic_irc,
+                     itraffic_irc_today, otraffic_bn, otraffic_bn_today,
+                     itraffic_bn, itraffic_bn_today, otraffic_dcc,
+                     otraffic_dcc_today, itraffic_dcc, itraffic_dcc_today,
+                     otraffic_trans, otraffic_trans_today, itraffic_trans,
+                     itraffic_trans_today, otraffic_unknown, itraffic_unknown,
+                     otraffic_unknown_today, itraffic_unknown_today;
+static struct portmap *root = NULL;
 
 
 int expmem_tcldcc(void)
@@ -56,13 +57,12 @@ int expmem_tcldcc(void)
   return tot;
 }
 
-/***********************************************************************/
-
 static int tcl_putdcc STDVAR
 {
   int i, j;
 
   BADARGS(3, 3, " idx text");
+
   i = atoi(argv[1]);
   j = findidx(i);
   if (j < 0) {
@@ -70,25 +70,25 @@ static int tcl_putdcc STDVAR
     return TCL_ERROR;
   }
   dumplots(-i, "", argv[2]);
+
   return TCL_OK;
 }
 
-/* Allows tcl scripts to send out raw data. Can be used for fast server
- * write (idx=0)
+/* Allows tcl scripts to send out raw data. Can be used for fast server write.
+ * The server idx is 0.
  *
- * usage:
- * 	putdccraw <idx> <size> <rawdata>
- * example:
- * 	putdccraw 6 13 "eggdrop rulz\n"
+ * Usage: putdccraw <idx> <size> <rawdata>
  *
- * (added by drummer@sophia.jpte.hu)
+ * Example: putdccraw 6 13 "eggdrop rulz\n"
+ *
+ * Added by <drummer@sophia.jpte.hu>.
  */
-
 static int tcl_putdccraw STDVAR
 {
   int i, j = 0, z;
 
   BADARGS(4, 4, " idx size text");
+
   z = atoi(argv[1]);
   for (i = 0; i < dcc_total; i++) {
     if (!z && !strcmp(dcc[i].nick, "(server)")) {
@@ -109,33 +109,34 @@ static int tcl_putdccraw STDVAR
 
 static int tcl_dccsimul STDVAR
 {
+  int idx;
+
   BADARGS(3, 3, " idx command");
-  if (enable_simul) {
-    int idx = findidx(atoi(argv[1]));
+  
+  idx = findidx(atoi(argv[1]));
+  if (idx >= 0 && (dcc[idx].type->flags & DCT_SIMUL)) {
+    int l = strlen(argv[2]);
 
-    if (idx >= 0 && (dcc[idx].type->flags & DCT_SIMUL)) {
-      int l = strlen(argv[2]);
-
-      if (l > 510) {
-	l = 510;
-	argv[2][510] = 0;	/* Restrict length of cmd */
-      }
-      if (dcc[idx].type && dcc[idx].type->activity) {
-	dcc[idx].type->activity(idx, argv[2], l);
-	return TCL_OK;
-      }
-    } else
-      Tcl_AppendResult(irp, "invalid idx", NULL);
+    if (l > 510) {
+      l = 510;
+      argv[2][510] = 0;        /* Restrict length of cmd */
+    }
+    if (dcc[idx].type && dcc[idx].type->activity) {
+      dcc[idx].type->activity(idx, argv[2], l);
+      return TCL_OK;
+    }
   } else
-    Tcl_AppendResult(irp, "simul disabled", NULL);
+      Tcl_AppendResult(irp, "invalid idx", NULL);
   return TCL_ERROR;
 }
 
+
 static int tcl_dccbroadcast STDVAR
 {
   char msg[401];
 
   BADARGS(2, 2, " message");
+
   strncpyz(msg, argv[1], sizeof msg);
   chatout("*** %s\n", msg);
   botnet_send_chat(-1, botnetnick, msg);
@@ -148,6 +149,7 @@ static int tcl_hand2idx STDVAR
   char s[11];
 
   BADARGS(2, 2, " nickname");
+
   for (i = 0; i < dcc_total; i++)
     if ((dcc[i].type->flags & DCT_SIMUL) &&
         !egg_strcasecmp(argv[1], dcc[i].nick)) {
@@ -165,16 +167,19 @@ static int tcl_getchan STDVAR
   int idx;
 
   BADARGS(2, 2, " idx");
+
   idx = findidx(atoi(argv[1]));
-  if (idx < 0 ||
-      (dcc[idx].type != &DCC_CHAT && dcc[idx].type != &DCC_SCRIPT)) {
+  if (idx < 0 || (dcc[idx].type != &DCC_CHAT &&
+      dcc[idx].type != &DCC_SCRIPT)) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
+
   if (dcc[idx].type == &DCC_SCRIPT)
     egg_snprintf(s, sizeof s, "%d", dcc[idx].u.script->u.chat->channel);
   else
     egg_snprintf(s, sizeof s, "%d", dcc[idx].u.chat->channel);
+
   Tcl_AppendResult(irp, s, NULL);
   return TCL_OK;
 }
@@ -185,29 +190,30 @@ static int tcl_setchan STDVAR
   module_entry *me;
 
   BADARGS(3, 3, " idx channel");
+
   idx = findidx(atoi(argv[1]));
-  if (idx < 0 ||
-      (dcc[idx].type != &DCC_CHAT && dcc[idx].type != &DCC_SCRIPT)) {
+  if (idx < 0 || (dcc[idx].type != &DCC_CHAT &&
+      dcc[idx].type != &DCC_SCRIPT)) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
   if (argv[2][0] < '0' || argv[2][0] > '9') {
     if (!strcmp(argv[2], "-1") || !egg_strcasecmp(argv[2], "off"))
-      chan = (-1);
+      chan = -1;
     else {
       Tcl_SetVar(irp, "chan", argv[2], 0);
       if (Tcl_VarEval(irp, "assoc ", "$chan", NULL) != TCL_OK ||
-	  !interp->result[0]) {
-	Tcl_AppendResult(irp, "channel name is invalid", NULL);
-	return TCL_ERROR;
+          !interp->result[0]) {
+        Tcl_AppendResult(irp, "channel name is invalid", NULL);
+        return TCL_ERROR;
       }
       chan = atoi(interp->result);
     }
   } else
     chan = atoi(argv[2]);
   if ((chan < -1) || (chan > 199999)) {
-    Tcl_AppendResult(irp, "channel out of range; must be -1 thru 199999",
-		     NULL);
+    Tcl_AppendResult(irp, "channel out of range; must be -1 through 199999",
+                     NULL);
     return TCL_ERROR;
   }
   if (dcc[idx].type == &DCC_SCRIPT)
@@ -217,15 +223,15 @@ static int tcl_setchan STDVAR
 
     if (dcc[idx].u.chat->channel >= 0) {
       if ((chan >= GLOBAL_CHANS) && (oldchan < GLOBAL_CHANS))
-	botnet_send_part_idx(idx, "*script*");
+        botnet_send_part_idx(idx, "*script*");
       check_tcl_chpt(botnetnick, dcc[idx].nick, dcc[idx].sock,
-		     dcc[idx].u.chat->channel);
+                     dcc[idx].u.chat->channel);
     }
     dcc[idx].u.chat->channel = chan;
     if (chan < GLOBAL_CHANS)
       botnet_send_join_idx(idx, oldchan);
     check_tcl_chjn(botnetnick, dcc[idx].nick, chan, geticon(idx),
-		   dcc[idx].sock, dcc[idx].host);
+                   dcc[idx].sock, dcc[idx].host);
   }
   /* Console autosave. */
   if ((me = module_find("console", 1, 1))) {
@@ -242,13 +248,14 @@ static int tcl_dccputchan STDVAR
   char msg[401];
 
   BADARGS(3, 3, " channel message");
+
   chan = atoi(argv[1]);
   if ((chan < 0) || (chan > 199999)) {
-    Tcl_AppendResult(irp, "channel out of range; must be 0 thru 199999",
-		     NULL);
+    Tcl_AppendResult(irp, "channel out of range; must be 0 through 199999", NULL);
     return TCL_ERROR;
   }
   strncpyz(msg, argv[2], sizeof msg);
+
   chanout_but(-1, chan, "*** %s\n", argv[2]);
   botnet_send_chan(-1, botnetnick, NULL, chan, argv[2]);
   check_tcl_bcst(botnetnick, chan, argv[2]);
@@ -261,44 +268,45 @@ static int tcl_console STDVAR
   module_entry *me;
 
   BADARGS(2, 4, " idx ?channel? ?console-modes?");
+
   i = findidx(atoi(argv[1]));
   if (i < 0 || dcc[i].type != &DCC_CHAT) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
   pls = 1;
+
   for (arg = 2; arg < argc; arg++) {
     if (argv[arg][0] && ((strchr(CHANMETA, argv[arg][0]) != NULL) ||
-	(argv[arg][0] == '*'))) {
+        (argv[arg][0] == '*'))) {
       if ((argv[arg][0] != '*') && (!findchan_by_dname(argv[arg]))) {
-        /* If we dont find the channel, and it starts with a +... assume it
-         * should be the console flags to set.
-         */
-        if (argv[arg][0]=='+')
+        /* If we dont find the channel, and it starts with a +, assume it
+         * should be the console flags to set. */
+        if (argv[arg][0] == '+')
           goto do_console_flags;
-	Tcl_AppendResult(irp, "invalid channel", NULL);
-	return TCL_ERROR;
+        Tcl_AppendResult(irp, "invalid channel", NULL);
+        return TCL_ERROR;
       }
       strncpyz(dcc[i].u.chat->con_chan, argv[arg], 81);
     } else {
       if ((argv[arg][0] != '+') && (argv[arg][0] != '-'))
-	dcc[i].u.chat->con_flags = 0;
-      do_console_flags:
+        dcc[i].u.chat->con_flags = 0;
+    do_console_flags:
       for (j = 0; j < strlen(argv[arg]); j++) {
-	if (argv[arg][j] == '+')
-	  pls = 1;
-	else if (argv[arg][j] == '-')
-	  pls = (-1);
-	else {
-	  char s[2];
+        if (argv[arg][j] == '+')
+          pls = 1;
+        else if (argv[arg][j] == '-')
+          pls = -1;
+        else {
+          char s[2];
 
-	  s[0] = argv[arg][j];
-	  s[1] = 0;
-	  if (pls == 1)
-	    dcc[i].u.chat->con_flags |= logmodes(s);
-	  else
-	    dcc[i].u.chat->con_flags &= ~logmodes(s);
-	}
+          s[0] = argv[arg][j];
+          s[1] = 0;
+          if (pls == 1)
+            dcc[i].u.chat->con_flags |= logmodes(s);
+          else
+            dcc[i].u.chat->con_flags &= ~logmodes(s);
+        }
       }
     }
   }
@@ -319,29 +327,31 @@ static int tcl_strip STDVAR
   module_entry *me;
 
   BADARGS(2, 4, " idx ?strip-flags?");
+  
   i = findidx(atoi(argv[1]));
   if (i < 0 || dcc[i].type != &DCC_CHAT) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
   pls = 1;
+
   for (arg = 2; arg < argc; arg++) {
     if ((argv[arg][0] != '+') && (argv[arg][0] != '-'))
       dcc[i].u.chat->strip_flags = 0;
     for (j = 0; j < strlen(argv[arg]); j++) {
       if (argv[arg][j] == '+')
-	pls = 1;
+        pls = 1;
       else if (argv[arg][j] == '-')
-	pls = (-1);
+        pls = -1;
       else {
-	char s[2];
+        char s[2];
 
-	s[0] = argv[arg][j];
-	s[1] = 0;
-	if (pls == 1)
-	  dcc[i].u.chat->strip_flags |= stripmodes(s);
-	else
-	  dcc[i].u.chat->strip_flags &= ~stripmodes(s);
+        s[0] = argv[arg][j];
+        s[1] = 0;
+        if (pls == 1)
+          dcc[i].u.chat->strip_flags |= stripmodes(s);
+        else
+          dcc[i].u.chat->strip_flags &= ~stripmodes(s);
       }
     }
   }
@@ -361,6 +371,7 @@ static int tcl_echo STDVAR
   module_entry *me;
 
   BADARGS(2, 3, " idx ?status?");
+
   i = findidx(atoi(argv[1]));
   if (i < 0 || dcc[i].type != &DCC_CHAT) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
@@ -392,6 +403,7 @@ static int tcl_page STDVAR
   module_entry *me;
 
   BADARGS(2, 3, " idx ?status?");
+
   i = findidx(atoi(argv[1]));
   if (i < 0 || dcc[i].type != &DCC_CHAT) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
@@ -427,6 +439,7 @@ static int tcl_control STDVAR
   void *hold;
 
   BADARGS(3, 3, " idx command");
+  
   idx = findidx(atoi(argv[1]));
   if (idx < 0) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
@@ -435,9 +448,9 @@ static int tcl_control STDVAR
   if (dcc[idx].type->flags & DCT_CHAT) {
     if (dcc[idx].u.chat->channel >= 0) {
       chanout_but(idx, dcc[idx].u.chat->channel, "*** %s has gone.\n",
-		  dcc[idx].nick);
+                  dcc[idx].nick);
       check_tcl_chpt(botnetnick, dcc[idx].nick, dcc[idx].sock,
-		     dcc[idx].u.chat->channel);
+                     dcc[idx].u.chat->channel);
       botnet_send_part_idx(idx, "gone");
     }
     check_tcl_chof(dcc[idx].nick, dcc[idx].sock);
@@ -448,7 +461,7 @@ static int tcl_control STDVAR
   dcc[idx].u.script->type = dcc[idx].type;
   dcc[idx].type = &DCC_SCRIPT;
   /* Do not buffer data anymore. All received and stored data is passed
-     over to the dcc functions from now on.  */
+   * over to the dcc functions from now on.  */
   sockoptions(dcc[idx].sock, EGG_OPTION_UNSET, SOCK_BUFFER);
   strncpyz(dcc[idx].u.script->command, argv[2], 120);
   return TCL_OK;
@@ -459,11 +472,12 @@ static int tcl_valididx STDVAR
   int idx;
 
   BADARGS(2, 2, " idx");
+
   idx = findidx(atoi(argv[1]));
   if (idx < 0 || !(dcc[idx].type->flags & DCT_VALIDIDX))
-     Tcl_AppendResult(irp, "0", NULL);
+    Tcl_AppendResult(irp, "0", NULL);
   else
-     Tcl_AppendResult(irp, "1", NULL);
+    Tcl_AppendResult(irp, "1", NULL);
    return TCL_OK;
 }
 
@@ -472,28 +486,30 @@ static int tcl_killdcc STDVAR
   int idx;
 
   BADARGS(2, 3, " idx ?reason?");
+
   idx = findidx(atoi(argv[1]));
   if (idx < 0) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
-  /* Don't kill terminal socket */
-  if ((dcc[idx].sock == STDOUT) && !backgrd)
+
+  if ((dcc[idx].sock == STDOUT) && !backgrd) /* Don't kill terminal socket */
     return TCL_OK;
-  /* Make sure 'whom' info is updated for other bots */
-  if (dcc[idx].type->flags & DCT_CHAT) {
+
+  
+  if (dcc[idx].type->flags & DCT_CHAT) { /* Make sure 'whom' info is updated */
     chanout_but(idx, dcc[idx].u.chat->channel, "*** %s has left the %s%s%s\n",
-		dcc[idx].nick, dcc[idx].u.chat ? "channel" : "partyline",
-		argc == 3 ? ": " : "", argc == 3 ? argv[2] : "");
+                dcc[idx].nick, dcc[idx].u.chat ? "channel" : "partyline",
+                argc == 3 ? ": " : "", argc == 3 ? argv[2] : "");
     botnet_send_part_idx(idx, argc == 3 ? argv[2] : "");
     if ((dcc[idx].u.chat->channel >= 0) &&
-	(dcc[idx].u.chat->channel < GLOBAL_CHANS))
+        (dcc[idx].u.chat->channel < GLOBAL_CHANS))
       check_tcl_chpt(botnetnick, dcc[idx].nick, dcc[idx].sock,
-		     dcc[idx].u.chat->channel);
+                     dcc[idx].u.chat->channel);
     check_tcl_chof(dcc[idx].nick, dcc[idx].sock);
-    /* Notice is sent to the party line, the script can add a reason. */
   }
   killsock(dcc[idx].sock);
+  killtransfer(idx);
   lostdcc(idx);
   return TCL_OK;
 }
@@ -504,12 +520,14 @@ static int tcl_putbot STDVAR
   char msg[401];
 
   BADARGS(3, 3, " botnick message");
+  
   i = nextbot(argv[1]);
   if (i < 0) {
-    Tcl_AppendResult(irp, "bot is not in the botnet", NULL);
+    Tcl_AppendResult(irp, "bot is not on the botnet", NULL);
     return TCL_ERROR;
   }
   strncpyz(msg, argv[2], sizeof msg);
+
   botnet_send_zapf(i, botnetnick, argv[1], msg);
   return TCL_OK;
 }
@@ -519,6 +537,7 @@ static int tcl_putallbots STDVAR
   char msg[401];
 
   BADARGS(2, 2, " message");
+
   strncpyz(msg, argv[1], sizeof msg);
   botnet_send_zapf_broad(-1, botnetnick, NULL, msg);
   return TCL_OK;
@@ -529,11 +548,13 @@ static int tcl_idx2hand STDVAR
   int idx;
 
   BADARGS(2, 2, " idx");
+  
   idx = findidx(atoi(argv[1]));
   if (idx < 0) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
+
   Tcl_AppendResult(irp, dcc[idx].nick, NULL);
   return TCL_OK;
 }
@@ -543,12 +564,13 @@ static int tcl_islinked STDVAR
   int i;
 
   BADARGS(2, 2, " bot");
+  
   i = nextbot(argv[1]);
   if (i < 0)
-     Tcl_AppendResult(irp, "0", NULL);
+    Tcl_AppendResult(irp, "0", NULL);
   else
-     Tcl_AppendResult(irp, "1", NULL);
-   return TCL_OK;
+    Tcl_AppendResult(irp, "1", NULL);
+  return TCL_OK;
 }
 
 static int tcl_bots STDVAR
@@ -556,18 +578,20 @@ static int tcl_bots STDVAR
   tand_t *bot;
 
   BADARGS(1, 1, "");
+
   for (bot = tandbot; bot; bot = bot->next)
-     Tcl_AppendElement(irp, bot->bot);
-   return TCL_OK;
+    Tcl_AppendElement(irp, bot->bot);
+  return TCL_OK;
 }
 
 static int tcl_botlist STDVAR
 {
+  char *p, sh[2], string[20];
+  EGG_CONST char *list[4];
   tand_t *bot;
-  char *list[4], *p;
-  char sh[2], string[20];
 
   BADARGS(1, 1, "");
+
   sh[1] = 0;
   list[3] = sh;
   list[2] = string;
@@ -583,28 +607,25 @@ static int tcl_botlist STDVAR
   return TCL_OK;
 }
 
-/* list of { idx nick host type {other}  timestamp}
- */
 static int tcl_dcclist STDVAR
 {
   int i;
-  char idxstr[10];
-  char timestamp[11];
-  char *list[6], *p;
-  char other[160];
+  char *p, idxstr[10], timestamp[11], other[160];
+  EGG_CONST char *list[6];
 
   BADARGS(1, 2, " ?type?");
+
   for (i = 0; i < dcc_total; i++) {
-    if (argc == 1 ||
-	((argc == 2) && (dcc[i].type && !egg_strcasecmp(dcc[i].type->name, argv[1])))) {
+    if (argc == 1 || ((argc == 2) && (dcc[i].type &&
+        !egg_strcasecmp(dcc[i].type->name, argv[1])))) {
       egg_snprintf(idxstr, sizeof idxstr, "%ld", dcc[i].sock);
       egg_snprintf(timestamp, sizeof timestamp, "%ld", dcc[i].timeval);
       if (dcc[i].type && dcc[i].type->display)
-	dcc[i].type->display(i, other);
+        dcc[i].type->display(i, other);
       else {
-	egg_snprintf(other, sizeof other, "?:%lX  !! ERROR !!",
-		     (long) dcc[i].type);
-	break;
+        egg_snprintf(other, sizeof other, "?:%lX  !! ERROR !!",
+                     (long) dcc[i].type);
+        break;
       }
       list[0] = idxstr;
       list[1] = dcc[i].nick;
@@ -620,52 +641,52 @@ static int tcl_dcclist STDVAR
   return TCL_OK;
 }
 
-/* list of { nick bot host flag idletime awaymsg [channel]}
- */
 static int tcl_whom STDVAR
 {
-  char c[2], idle[11], work[20], *list[7], *p;
   int chan, i;
+  char c[2], idle[11], work[20], *p;
+  EGG_CONST char *list[7];
 
   BADARGS(2, 2, " chan");
+
   if (argv[1][0] == '*')
-     chan = -1;
+    chan = -1;
   else {
     if ((argv[1][0] < '0') || (argv[1][0] > '9')) {
       Tcl_SetVar(interp, "chan", argv[1], 0);
       if ((Tcl_VarEval(interp, "assoc ", "$chan", NULL) != TCL_OK) ||
-	  !interp->result[0]) {
-	Tcl_AppendResult(irp, "channel name is invalid", NULL);
-	return TCL_ERROR;
+          !interp->result[0]) {
+        Tcl_AppendResult(irp, "channel name is invalid", NULL);
+        return TCL_ERROR;
       }
       chan = atoi(interp->result);
     } else
       chan = atoi(argv[1]);
     if ((chan < 0) || (chan > 199999)) {
-      Tcl_AppendResult(irp, "channel out of range; must be 0 thru 199999",
-		       NULL);
+      Tcl_AppendResult(irp, "channel out of range; must be 0 through 199999",
+                       NULL);
       return TCL_ERROR;
     }
   }
   for (i = 0; i < dcc_total; i++)
     if (dcc[i].type == &DCC_CHAT) {
       if (dcc[i].u.chat->channel == chan || chan == -1) {
-	c[0] = geticon(i);
-	c[1] = 0;
-	egg_snprintf(idle, sizeof idle, "%lu", (now - dcc[i].timeval) / 60);
-	list[0] = dcc[i].nick;
-	list[1] = botnetnick;
-	list[2] = dcc[i].host;
-	list[3] = c;
-	list[4] = idle;
-	list[5] = dcc[i].u.chat->away ? dcc[i].u.chat->away : "";
-	if (chan == -1) {
-	  egg_snprintf(work, sizeof work, "%d", dcc[i].u.chat->channel);
-	  list[6] = work;
-	}
-	p = Tcl_Merge((chan == -1) ? 7 : 6, list);
-	Tcl_AppendElement(irp, p);
-	Tcl_Free((char *) p);
+        c[0] = geticon(i);
+        c[1] = 0;
+        egg_snprintf(idle, sizeof idle, "%lu", (now - dcc[i].timeval) / 60);
+        list[0] = dcc[i].nick;
+        list[1] = botnetnick;
+        list[2] = dcc[i].host;
+        list[3] = c;
+        list[4] = idle;
+        list[5] = dcc[i].u.chat->away ? dcc[i].u.chat->away : "";
+        if (chan == -1) {
+          egg_snprintf(work, sizeof work, "%d", dcc[i].u.chat->channel);
+          list[6] = work;
+        }
+        p = Tcl_Merge((chan == -1) ? 7 : 6, list);
+        Tcl_AppendElement(irp, p);
+        Tcl_Free((char *) p);
       }
     }
   for (i = 0; i < parties; i++) {
@@ -673,9 +694,9 @@ static int tcl_whom STDVAR
       c[0] = party[i].flag;
       c[1] = 0;
       if (party[i].timer == 0L)
-	strcpy(idle, "0");
+        strcpy(idle, "0");
       else
-	egg_snprintf(idle, sizeof idle, "%lu", (now - party[i].timer) / 60);
+        egg_snprintf(idle, sizeof idle, "%lu", (now - party[i].timer) / 60);
       list[0] = party[i].nick;
       list[1] = party[i].bot;
       list[2] = party[i].from ? party[i].from : "";
@@ -683,8 +704,8 @@ static int tcl_whom STDVAR
       list[4] = idle;
       list[5] = party[i].status & PLSTAT_AWAY ? party[i].away : "";
       if (chan == -1) {
-	egg_snprintf(work, sizeof work, "%d", party[i].chan);
-	list[6] = work;
+        egg_snprintf(work, sizeof work, "%d", party[i].chan);
+        list[6] = work;
       }
       p = Tcl_Merge((chan == -1) ? 7 : 6, list);
       Tcl_AppendElement(irp, p);
@@ -699,6 +720,7 @@ static int tcl_dccused STDVAR
   char s[20];
 
   BADARGS(1, 1, "");
+
   egg_snprintf(s, sizeof s, "%d", dcc_total);
   Tcl_AppendResult(irp, s, NULL);
   return TCL_OK;
@@ -706,16 +728,18 @@ static int tcl_dccused STDVAR
 
 static int tcl_getdccidle STDVAR
 {
-  int  x, idx;
+  int x, idx;
   char s[21];
 
   BADARGS(2, 2, " idx");
+  
   idx = findidx(atoi(argv[1]));
   if (idx < 0) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
   x = (now - dcc[idx].timeval);
+
   egg_snprintf(s, sizeof s, "%d", x);
   Tcl_AppendElement(irp, s);
   return TCL_OK;
@@ -726,6 +750,7 @@ static int tcl_getdccaway STDVAR
   int idx;
 
   BADARGS(2, 2, " idx");
+  
   idx = findidx(atol(argv[1]));
   if (idx < 0 || dcc[idx].type != &DCC_CHAT) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
@@ -733,6 +758,7 @@ static int tcl_getdccaway STDVAR
   }
   if (dcc[idx].u.chat->away == NULL)
     return TCL_OK;
+
   Tcl_AppendResult(irp, dcc[idx].u.chat->away, NULL);
   return TCL_OK;
 }
@@ -742,18 +768,17 @@ static int tcl_setdccaway STDVAR
   int idx;
 
   BADARGS(3, 3, " idx message");
+  
   idx = findidx(atol(argv[1]));
   if (idx < 0 || dcc[idx].type != &DCC_CHAT) {
     Tcl_AppendResult(irp, "invalid idx", NULL);
     return TCL_ERROR;
   }
   if (!argv[2][0]) {
-    /* un-away */
     if (dcc[idx].u.chat->away != NULL)
       not_away(idx);
     return TCL_OK;
   }
-  /* away */
   set_away(idx, argv[2]);
   return TCL_OK;
 }
@@ -764,6 +789,7 @@ static int tcl_link STDVAR
   char bot[HANDLEN + 1], bot2[HANDLEN + 1];
 
   BADARGS(2, 3, " ?via-bot? bot");
+
   strncpyz(bot, argv[1], sizeof bot);
   if (argc == 3) {
     x = 1;
@@ -774,7 +800,8 @@ static int tcl_link STDVAR
     else
       botnet_send_link(i, botnetnick, bot, bot2);
   } else
-     x = botlink("", -2, bot);
+    x = botlink("", -2, bot);
+
   egg_snprintf(bot, sizeof bot, "%d", x);
   Tcl_AppendResult(irp, bot, NULL);
   return TCL_OK;
@@ -786,18 +813,20 @@ static int tcl_unlink STDVAR
   char bot[HANDLEN + 1];
 
   BADARGS(2, 3, " bot ?comment?");
+  
   strncpyz(bot, argv[1], sizeof bot);
   i = nextbot(bot);
   if (i < 0)
-     x = 0;
+    x = 0;
   else {
     x = 1;
     if (!egg_strcasecmp(bot, dcc[i].nick))
-      x = botunlink(-2, bot, argv[2]);
+      x = botunlink(-2, bot, argv[2], botnetnick);
     else
       botnet_send_unlink(i, botnetnick, lastbot(bot), bot, argv[2]);
   }
   egg_snprintf(bot, sizeof bot, "%d", x);
+
   Tcl_AppendResult(irp, bot, NULL);
   return TCL_OK;
 }
@@ -808,11 +837,17 @@ static int tcl_connect STDVAR
   char s[81];
 
   BADARGS(3, 3, " hostname port");
+  
   if (dcc_total == max_dcc) {
     Tcl_AppendResult(irp, "out of dcc table space", NULL);
     return TCL_ERROR;
   }
+#ifdef USE_IPV6
+  sock = getsock(0, getprotocol(argv[1]));
+#else
   sock = getsock(0);
+#endif /* USE_IPV6 */
+
   if (sock < 0) {
     Tcl_AppendResult(irp, MISC_NOFREESOCK, NULL);
     return TCL_ERROR;
@@ -820,14 +855,13 @@ static int tcl_connect STDVAR
   z = open_telnet_raw(sock, argv[1], atoi(argv[2]));
   if (z < 0) {
     killsock(sock);
-    if (z == (-2))
+    if (z == -2)
       strncpyz(s, "DNS lookup failed", sizeof s);
     else
       neterror(s);
     Tcl_AppendResult(irp, s, NULL);
     return TCL_ERROR;
   }
-  /* Well well well... it worked! */
   i = new_dcc(&DCC_SOCKET, 0);
   dcc[i].sock = sock;
   dcc[i].port = atoi(argv[2]);
@@ -846,26 +880,27 @@ static int tcl_connect STDVAR
  */
 static int tcl_listen STDVAR
 {
-  int i, j, idx = (-1), port, realport;
+  int i, j, idx = -1, port, realport;
   char s[11];
   struct portmap *pmap = NULL, *pold = NULL;
 
   BADARGS(3, 5, " port type ?mask?/?proc ?flag??");
+  
   port = realport = atoi(argv[1]);
   for (pmap = root; pmap; pold = pmap, pmap = pmap->next)
     if (pmap->realport == port) {
       port = pmap->mappedto;
       break;
-    }
+  }
   for (i = 0; i < dcc_total; i++)
     if ((dcc[i].type == &DCC_TELNET) && (dcc[i].port == port))
       idx = i;
   if (!egg_strcasecmp(argv[2], "off")) {
     if (pmap) {
       if (pold)
-	pold->next = pmap->next;
+        pold->next = pmap->next;
       else
-	root = pmap->next;
+        root = pmap->next;
       nfree(pmap);
     }
     /* Remove */
@@ -885,11 +920,18 @@ static int tcl_listen STDVAR
     }
     /* Try to grab port */
     j = port + 20;
-    i = (-1);
+    i = -1;
     while (port < j && i < 0) {
+#ifdef USE_IPV6
+      /* dum de dum, listen needs an af_def option, on linux this will listen on
+       * both ipv6 and ipv4 
+       */
+      i = open_listen_by_af(&port, AF_INET6);
+#else
       i = open_listen(&port);
+#endif /* USE_IPV6 */
       if (i == -1)
-	port++;
+        port++;
       else if (i == -2)
         break;
     }
@@ -897,11 +939,16 @@ static int tcl_listen STDVAR
       Tcl_AppendResult(irp, "Couldn't grab nearby port", NULL);
       return TCL_ERROR;
     } else if (i == -2) {
-      Tcl_AppendResult(irp, "Couldn't assign the requested IP. Please make sure 'my-ip' is set properly.", NULL);
+      Tcl_AppendResult(irp, "Couldn't assign the requested IP. Please make "
+                       "sure 'my-ip' is set properly.", NULL);
       return TCL_ERROR;
     }
     idx = new_dcc(&DCC_TELNET, 0);
+#ifdef USE_IPV6
+    dcc[idx].addr = 0x00000000; /* it's not big enough to hold '0xffffffffffffffffffffffffffffffff' =P */
+#else
     dcc[idx].addr = iptolong(getmyip());
+#endif /* USE_IPV6 */
     dcc[idx].port = port;
     dcc[idx].sock = i;
     dcc[idx].timeval = now;
@@ -917,11 +964,11 @@ static int tcl_listen STDVAR
     }
     if (argc == 5) {
       if (strcmp(argv[4], "pub")) {
-	Tcl_AppendResult(irp, "unknown flag: ", argv[4], ". allowed flags: pub",
-		         NULL);
-	killsock(dcc[idx].sock);
-	lostdcc(idx);
-	return TCL_ERROR;
+        Tcl_AppendResult(irp, "unknown flag: ", argv[4], ". allowed flags: pub",
+                         NULL);
+        killsock(dcc[idx].sock);
+        lostdcc(idx);
+        return TCL_ERROR;
       }
       dcc[idx].status = LSTN_PUBLIC;
     }
@@ -939,14 +986,14 @@ static int tcl_listen STDVAR
     strcpy(dcc[idx].nick, "(telnet)");
   if (!dcc[idx].nick[0]) {
     Tcl_AppendResult(irp, "illegal listen type: must be one of ",
-		     "bots, users, all, off, script", NULL);
+                     "bots, users, all, off, script", NULL);
     killsock(dcc[idx].sock);
     dcc_total--;
     return TCL_ERROR;
   }
-  if (argc == 4) {
+  if (argc == 4)
     strncpyz(dcc[idx].host, argv[3], UHOSTMAX);
-  } else
+  else
     strcpy(dcc[idx].host, "*");
   egg_snprintf(s, sizeof s, "%d", port);
   Tcl_AppendResult(irp, s, NULL);
@@ -967,6 +1014,7 @@ static int tcl_boot STDVAR
   int i, ok = 0;
 
   BADARGS(2, 3, " user@bot ?reason?");
+  
   strncpyz(who, argv[1], sizeof who);
 
   if (strchr(who, '@') != NULL) {
@@ -975,15 +1023,15 @@ static int tcl_boot STDVAR
     splitc(whonick, who, '@');
     whonick[HANDLEN] = 0;
     if (!egg_strcasecmp(who, botnetnick))
-       strncpyz(who, whonick, sizeof who);
+      strncpyz(who, whonick, sizeof who);
     else if (remote_boots > 0) {
       i = nextbot(who);
       if (i < 0)
-	return TCL_OK;
-      botnet_send_reject(i, botnetnick, NULL, whonick, who, argv[2] ? argv[2] : "");
-    } else {
+        return TCL_OK;
+      botnet_send_reject(i, botnetnick, NULL, whonick, who,
+                         argv[2] ? argv[2] : "");
+    } else
       return TCL_OK;
-    }
   }
   for (i = 0; i < dcc_total; i++)
     if (!ok && (dcc[i].type->flags & DCT_CANBOOT) &&
@@ -997,11 +1045,13 @@ static int tcl_boot STDVAR
 static int tcl_rehash STDVAR
 {
   BADARGS(1, 1, " ");
+
   if (make_userfile) {
     putlog(LOG_MISC, "*", USERF_NONEEDNEW);
     make_userfile = 0;
   }
   write_userfile(-1);
+
   putlog(LOG_MISC, "*", USERF_REHASHING);
   do_restart = -2;
   return TCL_OK;
@@ -1010,6 +1060,7 @@ static int tcl_rehash STDVAR
 static int tcl_restart STDVAR
 {
   BADARGS(1, 1, " ");
+
   if (!backgrd) {
     Tcl_AppendResult(interp, "You can't restart a -n bot", NULL);
     return TCL_ERROR;
@@ -1034,81 +1085,87 @@ static int tcl_traffic STDVAR
 
   /* IRC traffic */
   sprintf(buf, "irc %ld %ld %ld %ld", itraffic_irc_today, itraffic_irc +
-	  itraffic_irc_today, otraffic_irc_today, otraffic_irc + otraffic_irc_today);
-  Tcl_AppendElement(irp, buf);  
+          itraffic_irc_today, otraffic_irc_today,
+          otraffic_irc + otraffic_irc_today);
+  Tcl_AppendElement(irp, buf);
 
   /* Botnet traffic */
   sprintf(buf, "botnet %ld %ld %ld %ld", itraffic_bn_today, itraffic_bn +
-          itraffic_bn_today, otraffic_bn_today, otraffic_bn + otraffic_bn_today);
+          itraffic_bn_today, otraffic_bn_today,
+          otraffic_bn + otraffic_bn_today);
   Tcl_AppendElement(irp, buf);
 
   /* Partyline */
-  sprintf(buf, "partyline %ld %ld %ld %ld", itraffic_dcc_today, itraffic_dcc +  
-          itraffic_dcc_today, otraffic_dcc_today, otraffic_dcc + otraffic_dcc_today);    
+  sprintf(buf, "partyline %ld %ld %ld %ld", itraffic_dcc_today, itraffic_dcc +
+          itraffic_dcc_today, otraffic_dcc_today,
+          otraffic_dcc + otraffic_dcc_today);
   Tcl_AppendElement(irp, buf);
 
   /* Transfer */
-  sprintf(buf, "transfer %ld %ld %ld %ld", itraffic_trans_today, itraffic_trans +  
-          itraffic_trans_today, otraffic_trans_today, otraffic_trans + otraffic_trans_today);    
+  sprintf(buf, "transfer %ld %ld %ld %ld", itraffic_trans_today,
+          itraffic_trans + itraffic_trans_today, otraffic_trans_today,
+          otraffic_trans + otraffic_trans_today);
   Tcl_AppendElement(irp, buf);
 
   /* Misc traffic */
-  sprintf(buf, "misc %ld %ld %ld %ld", itraffic_unknown_today, itraffic_unknown +  
-          itraffic_unknown_today, otraffic_unknown_today, otraffic_unknown + 
-	  otraffic_unknown_today);    
+  sprintf(buf, "misc %ld %ld %ld %ld", itraffic_unknown_today,
+          itraffic_unknown + itraffic_unknown_today, otraffic_unknown_today,
+          otraffic_unknown + otraffic_unknown_today);
   Tcl_AppendElement(irp, buf);
 
   /* Totals */
-  in_total_today = itraffic_irc_today + itraffic_bn_today + itraffic_dcc_today + 
-		itraffic_trans_today + itraffic_unknown_today,
-  in_total = in_total_today + itraffic_irc + itraffic_bn + itraffic_dcc + 
-	      itraffic_trans + itraffic_unknown;
-  out_total_today = otraffic_irc_today + otraffic_bn_today + otraffic_dcc_today +
-                itraffic_trans_today + otraffic_unknown_today,
+  in_total_today = itraffic_irc_today + itraffic_bn_today +
+                   itraffic_dcc_today + itraffic_trans_today +
+                   itraffic_unknown_today;
+  in_total = in_total_today + itraffic_irc + itraffic_bn + itraffic_dcc +
+             itraffic_trans + itraffic_unknown;
+  out_total_today = otraffic_irc_today + otraffic_bn_today +
+                    otraffic_dcc_today + itraffic_trans_today +
+                    otraffic_unknown_today;
   out_total = out_total_today + otraffic_irc + otraffic_bn + otraffic_dcc +
-              otraffic_trans + otraffic_unknown;	  
-  sprintf(buf, "total %ld %ld %ld %ld", in_total_today, in_total, out_total_today, out_total);
+              otraffic_trans + otraffic_unknown;
+  sprintf(buf, "total %ld %ld %ld %ld", in_total_today, in_total,
+          out_total_today, out_total);
   Tcl_AppendElement(irp, buf);
-  return(TCL_OK);
+  return TCL_OK;
 }
 
-tcl_cmds tcldcc_cmds[] =
-{
-  {"putdcc",		tcl_putdcc},
-  {"putdccraw",		tcl_putdccraw},
-  {"putidx",		tcl_putdcc},
-  {"dccsimul",		tcl_dccsimul},
-  {"dccbroadcast",	tcl_dccbroadcast},
-  {"hand2idx",		tcl_hand2idx},
-  {"getchan",		tcl_getchan},
-  {"setchan",		tcl_setchan},
-  {"dccputchan",	tcl_dccputchan},
-  {"console",		tcl_console},
-  {"strip",		tcl_strip},
-  {"echo",		tcl_echo},
-  {"page",		tcl_page},
-  {"control",		tcl_control},
-  {"valididx",		tcl_valididx},
-  {"killdcc",		tcl_killdcc},
-  {"putbot",		tcl_putbot},
-  {"putallbots",	tcl_putallbots},
-  {"idx2hand",		tcl_idx2hand},
-  {"bots",		tcl_bots},
-  {"botlist",		tcl_botlist},
-  {"dcclist",		tcl_dcclist},
-  {"whom",		tcl_whom},
-  {"dccused",		tcl_dccused},
-  {"getdccidle",	tcl_getdccidle},
-  {"getdccaway",	tcl_getdccaway},
-  {"setdccaway",	tcl_setdccaway},
-  {"islinked",		tcl_islinked},
-  {"link",		tcl_link},
-  {"unlink",		tcl_unlink},
-  {"connect",		tcl_connect},
-  {"listen",		tcl_listen},
-  {"boot",		tcl_boot},
-  {"rehash",		tcl_rehash},
-  {"restart",		tcl_restart},
-  {"traffic",		tcl_traffic},
-  {NULL,		NULL}
+tcl_cmds tcldcc_cmds[] = {
+  {"putdcc",             tcl_putdcc},
+  {"putdccraw",       tcl_putdccraw},
+  {"putidx",             tcl_putdcc},
+  {"dccsimul",         tcl_dccsimul},
+  {"dccbroadcast", tcl_dccbroadcast},
+  {"hand2idx",         tcl_hand2idx},
+  {"getchan",           tcl_getchan},
+  {"setchan",           tcl_setchan},
+  {"dccputchan",     tcl_dccputchan},
+  {"console",           tcl_console},
+  {"strip",               tcl_strip},
+  {"echo",                 tcl_echo},
+  {"page",                 tcl_page},
+  {"control",           tcl_control},
+  {"valididx",         tcl_valididx},
+  {"killdcc",           tcl_killdcc},
+  {"putbot",             tcl_putbot},
+  {"putallbots",     tcl_putallbots},
+  {"idx2hand",         tcl_idx2hand},
+  {"bots",                 tcl_bots},
+  {"botlist",           tcl_botlist},
+  {"dcclist",           tcl_dcclist},
+  {"whom",                 tcl_whom},
+  {"dccused",           tcl_dccused},
+  {"getdccidle",     tcl_getdccidle},
+  {"getdccaway",     tcl_getdccaway},
+  {"setdccaway",     tcl_setdccaway},
+  {"islinked",         tcl_islinked},
+  {"link",                 tcl_link},
+  {"unlink",             tcl_unlink},
+  {"connect",           tcl_connect},
+  {"listen",             tcl_listen},
+  {"boot",                 tcl_boot},
+  {"rehash",             tcl_rehash},
+  {"restart",           tcl_restart},
+  {"traffic",           tcl_traffic},
+  {NULL,                       NULL}
 };
